<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail Archive plugin             |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/plugin-archive/
*/

$labels['buttontext'] = 'アーカイブ';
$labels['buttontitle'] = 'このメッセージをアーカイブ';
$labels['archived'] = 'アーカイブしました。';
$labels['archivedreload'] = 'アーカイブしました。ページを再読み込みすると、新しいアーカイブのフォルダーを表示します。';
$labels['archiveerror'] = 'アーカイブできないメッセージがありました';
$labels['archivefolder'] = 'アーカイブ';
$labels['settingstitle'] = 'アーカイブ';
$labels['archivetype'] = 'アーカイブを分割: ';
$labels['archivetypeyear'] = '年 (例: アーカイブ/2012)';
$labels['archivetypemonth'] = '月 (例: アーカイブ/2012/06)';
$labels['archivetypetbmonth'] = '月 - Thunderbird互換 (例: アーカイブ/2012/2012-06)';
$labels['archivetypefolder'] = '元のフォルダー';
$labels['archivetypefolderyear'] = '年と元のフォルダー (例: アーカイブ/2012/...)';
$labels['archivetypefoldermonth'] = '年、月と元のフォルダー (例: アーカイブ/2012/06/...)';
$labels['archivetypesender'] = '電子メールの送信者';
$labels['unkownsender'] = '不明';
$labels['readonarchive'] = 'アーカイブでメッセージを既読に設定';
