<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail client                     |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/messages/
*/

$messages['errortitle']  = 'Xatolik yuzaga keldi!';
$messages['loginfailed']  = 'Kirish amalga oshirilmadi.';
$messages['cookiesdisabled'] = 'Brauzeringiz kukilarni qabul qilmayapti.';
$messages['sessionerror'] = 'Sizning sessiyangizda xatolik mavjud yoki muddati tugagan.';
$messages['storageerror'] = 'Xotira serveriga bog‘lanib bo‘lmadi.';
$messages['servererror'] = 'Serverda xatoliik!';
$messages['servererrormsg'] = 'Serverda xatolik: $msg';
$messages['accountlocked'] = 'Kirishga urinishlar soni ko‘p bo‘ldi. Keyinroq urinib ko‘ring.';
$messages['connerror'] = 'Ulanishda xato (server bilan bog‘lanib bo‘lmadi)!';
$messages['dberror'] = 'Ma’lumotlar ombori bilan xatolik yuz berdi!';
$messages['windowopenerror'] = 'Popup oynalar bloklangan!';
$messages['requesttimedout'] = 'So‘rovni kutish vaqti tugadi';
$messages['errorreadonly'] = 'Amal bajariimadi. Papka faqat o‘qish uchun.';
$messages['errornoperm'] = 'Amalni bajarib bo‘lmadi. Ruxsat berilmagan.';
$messages['erroroverquota'] = 'Amalni bajarib bo‘lmadi. Bo‘sh joy qolmagan.';
$messages['erroroverquotadelete'] = 'Bo‘sh joy qolmagan. SHIFT+DEL ni bosib, xabarni o‘chirib tashlang.';
$messages['invalidrequest'] = 'Noto‘g‘ri so‘rov! Ma’lumot saqlanmadi.';
$messages['invalidhost'] = 'Server nomi noto‘g‘ri.';
$messages['nomessagesfound'] = 'Bu pochta qutisida xabarlar topilmadi.';
$messages['mailboxempty'] = 'Pochta qutisi bo‘sh';
$messages['nomessages'] = 'Xabarlar yo‘q';
$messages['refreshing'] = 'Yangilanmoqda...';
$messages['loading'] = 'Iltimos, kuting…';
$messages['uploading'] = 'Fayl yuklanmoqda...';
$messages['attaching'] = 'Fayl ilova qilinmoqda...';
$messages['uploadingmany'] = 'Fayllar yuklanmoqda...';
$messages['loadingdata'] = 'Ma’lumotlar yuklanmoqda...';
$messages['checkingmail'] = 'Yangi xatlar tekshirilmoqda...';
$messages['sendingmessage'] = 'Xat yuborilmoqda…';
$messages['messagesent'] = 'Xat muvaffaqiyatli yuborildi.';
$messages['savingmessage'] = 'Xat saqlanmoqda…';
$messages['messagesaved'] = 'Xat Qoralamalarga saqlandi.';
$messages['successfullysaved'] = 'Muvaffaqiyatli saqlandi.';
$messages['savingresponse'] = 'Javob matni saqlanmoqda...';
$messages['deleteresponseconfirm'] = 'Siz rostdan ham bu javob xatini o‘chirmoqchimisiz?';
$messages['addedsuccessfully'] = 'Manzillar kitobiga kontakt qo‘shildi.';
$messages['contactexists'] = 'Bu e-mail manzilga ega kontakt mavjud.';
$messages['contactnameexists'] = 'Bu nomdagi kontakt mavjud.';
$messages['blockedimages'] = 'Xavfsizlik yuzasidan rasmlarni yuklash bloklangan.';
$messages['encryptedmessage'] = 'Xat shifrlangan va ko‘rsatib bo`lmaydi. Server administratoriga murojaat eting.';
$messages['externalmessagedecryption'] = 'Bu shifrlangan xabar, uni brauzeringiz kengaytmasi orqali ochishingiz mumkin.';
$messages['nopubkeyfor'] = '$email uchun amaldagi ochiq kalit topilmadi';
$messages['nopubkeyforsender'] = 'Sizning jo‘natuvchi ekanligingizni tasdiqlash uchun amaldagi ochiq kalit mavjud emas. Siz faqat qabul qiluvchilar uchun shifrlashni istaysizmi?';
$messages['encryptnoattachments'] = 'Yuklab bo‘lingan ilovalarni shifrlab bo‘lmaydi. Iltimos ularni shifrash tahrirlovchisiga qayta yuklang';
$messages['searchpubkeyservers'] = 'Mavjud bo‘lmagan kalitlar uchun ochiq kalitlar serverini qidirishni istaysizmi?';
$messages['encryptpubkeysfound'] = 'Quyidagi ochiq kalitlar topildi:';
$messages['nocontactsfound'] = 'Kontaktlar topilmadi.';
$messages['contactnotfound'] = 'Kerakli kontakt topilmadi.';
$messages['sendingfailed'] = 'Xatni jo`natish amalga oshirilmadi.';
$messages['senttooquickly'] = 'Siz xat jo‘natishdan avval $sec sekund kutishingiz kerak.';
$messages['errorsavingsent'] = 'Jo‘natilayotgan xatni saqlashda xatolik yuz berdi.';
$messages['errorsaving'] = 'Saqlash jarayonida xatolik yuz berdi.';
$messages['errormoving'] = 'Xat(lar)ni ko‘chirishda xatolik yuz berdi.';
$messages['errorcopying'] = 'Xat(lar)dan nusxa olishda xatolik yuz berdi.';
$messages['errordeleting'] = 'Xat(lar)ni o‘chirishda xatolik yuz berdi.';
$messages['errormarking'] = 'Xat(lar)ni belgilashda xatolik yuz berdi.';
$messages['deletecontactconfirm']  = 'Siz rostdan ham tanlangan kontakt(lar)ni o‘chirmoqchimisiz?';
$messages['deletegroupconfirm']  = 'Siz rostdan ham tanlangan guruhni o‘chirmoqchimisiz?';
$messages['deletemessagesconfirm'] = 'Siz rostdan ham tanlangan xat(lar)ni o‘chirmoqchimisiz?';
$messages['deletefolderconfirm']  = 'Siz rostdan ham bu papkani o‘chirmoqchimisiz?';
$messages['purgefolderconfirm']  = 'Siz rostdan ham mazkur papkadagi barcha xatlarni o‘chirmoqchimisiz?';
$messages['contactdeleting'] = 'Kontakt(lar) o‘chirilmoqda...';
$messages['groupdeleting'] = 'Guruh o‘chirilmoqda...';
$messages['folderdeleting'] = 'Papka o‘chirilmoqda...';
$messages['foldermoving'] = 'Papka ko‘chirilmoqda...';
$messages['foldersubscribing'] = 'Papkaga obuna bo‘lish';
$messages['folderunsubscribing'] = 'Papkaga obunani bekor qilish';
$messages['formincomplete'] = 'Forma to‘liq to‘ldirilmadi.';
$messages['noemailwarning'] = 'Iltimos, to‘g‘ri elektron pochta manzilini kiriting.';
$messages['nonamewarning']  = 'Iltimos, Ismni kiriting.';
$messages['nopagesizewarning'] = 'Iltimos, sahifa o‘lchamini kiriting.';
$messages['nosenderwarning'] = 'Iltimos, jo‘natuvchi elektron manzilini kirting.';
$messages['norecipientwarning'] = 'Iltimos, kamida bir dona qabul qiluvchini kiriting.';
$messages['disclosedrecipwarning'] = 'Barcha qabul qiluvchilar boshqalarning elektron manzilini ko‘ra olishadi, buni oldini olish va ularning shaxiy daxlsizligini ta’minlash uchun BCC maydonidan foydalaning.';
$messages['disclosedreciptitle'] = 'Tashqi qabul qiluvchilar juda ko‘p.';
$messages['nosubjectwarning']  = '"Mavzu" maydoni to‘ldirilmagan. Uni to‘ldirishni istaysizmi?';
$messages['nosubjecttitle']  = 'Mavzusiz';
$messages['nobodywarning'] = 'Xatni matnsiz jo‘natmoqchimisiz?';
$messages['notsentwarning'] = 'Xat jo‘natilmadi va saqlanmagan o‘zgartirishlarga ega. Siz bu o‘zgarishlarni bekor qilishni istaysizmi?';
$messages['restoresavedcomposedata'] = 'Avval $date da yaratilgan biroq, jo‘natilmagan $subject\n mavzudagi xat mavjud.Bu xatni qayta tiklashni istaysizmi?';
$messages['nosearchname'] = 'Iltimos, Ism yoki elektron pochta manzilini kiriting.';
$messages['notuploadedwarning'] = 'Barcha ilovalar hali yuklanmadi, Iltimos kuting yoki yuklashni bekor qiling.';
$messages['searchsuccessful'] = '$nr ta xat topildi.';
$messages['contactsearchsuccessful'] = '$nr ta kontaktlar topildi.';
$messages['searchnomatch'] = 'Hech narsa topilmadi.';
$messages['searching'] = 'Qidirilmoqda...';
$messages['checking'] = 'Tekshirilmoqda...';
$messages['stillsearching'] = 'Hali ham qidirilmoqda...';
$messages['nospellerrors'] = 'Imlo xatolar topilmadi.';
$messages['folderdeleted'] = 'Papka muvaffaqqiyatli o‘chirildi.';
$messages['foldersubscribed'] = 'Papkaga obuna muvaffaqqiyatli o‘rnatildi.';
$messages['folderunsubscribed'] = 'Papkaga obuna bekor qilindi.';
$messages['deletedsuccessfully'] = 'O‘chirildi.';
$messages['converting'] = 'Formatlashni o‘chirish...';
$messages['messageopenerror'] = 'Serverdan xatni yuklash amalga oshirilmadi.';
$messages['filelinkerror'] = 'Ilovani qo‘shish amalga oshirilmadi.';
$messages['fileuploaderror'] = 'Faylni yuklashda xatolik yuz berdi.';
$messages['filesizeerror'] = 'Yuklanayotgan fayl o‘lchami maksimal $size o‘lchamdan katta.';
$messages['filecounterror'] = 'Siz bir vaqtda $count ta fayl jo‘nata olasiz.';
$messages['msgsizeerror'] = 'Faylni yuklash amalga oshirilmadi. Xating maksimal o‘lchami ($size) dan oshgan.';
$messages['copysuccess'] = '$nr ta kontaktdan nusxa olish muvaffaqqiyatli amalga oshirildi.';
$messages['movesuccess'] = '$nr ta kontakt muvaffaqqiyatli ko‘chirildi.';
$messages['copyerror'] = 'Kontaktlardan nusxa olinmadi.';
$messages['moveerror'] = 'Kontaktlar ko‘chirilmadi.';
$messages['sourceisreadonly'] = 'Mazkur manzillar manbaasi faqat o‘qish uchun.';
$messages['errorsavingcontact'] = 'Kontakt manzillari saqlanmadi,';
$messages['movingmessage'] = 'Xat(lar)ni ko‘chirish...';
$messages['copyingmessage'] = 'Xat(lar)dan nusxa olish...';
$messages['copyingcontact'] = 'Kontakt(lar)dan nusxa olish ...';
$messages['movingcontact'] = 'Kontakt(lar)ni ko‘chirish...';
$messages['deletingmessage'] = 'Xat(lar)ni o‘chirish...';
$messages['markingmessage'] = 'Xat(lar)ni belgilash....';
$messages['addingmember'] = 'Kontakt(lar)ni guruhga qo‘shish...';
$messages['removingmember'] = 'Kontakt(lar)ni guruhdan o‘chirish';
$messages['receiptsent'] = 'O‘qilganlik haqida eslatma muvaffaqqiyatli jo‘natildi.';
$messages['errorsendingreceipt'] = 'O‘qilganlik haqida eslatma muvaffaqqiyatli jo‘natilmadi.';
$messages['deleteidentityconfirm'] = 'Siz rostdan ham buni o‘chirmoqchimisiz?';
$messages['nodeletelastidentity'] = 'Siz buni o‘chira olmaysiz, bu sizdagi oxirgi profil.';
$messages['forbiddencharacter'] = 'Papka nomida ruxsat etilmagan simvol mavjud.';
$messages['selectimportfile'] = 'Yuklash uchun faylni tanlang.';
$messages['addresswriterror'] = 'Tanlangan manzillar kitobida yozish uchun imkon yo‘q.';
$messages['contactaddedtogroup'] = 'Kontaktlar guruhga qo‘shildi.';
$messages['contactremovedfromgroup'] = 'Kontaktlar guruhdan o‘chirildi.';
$messages['nogroupassignmentschanged'] = 'Guruhlar bo‘yicha taqsimlash o‘zgarmadi.';
$messages['importwait'] = 'Import qilinmoqda, iltimos kuting...';
$messages['importformaterror'] = 'Import amalga oshmadi. Yuklanayotgan fayl no’malum ma’lumotlar formatiga ega.';
$messages['importconfirm'] = '<b> $inserted kontaktlar import qilindi</b>';
$messages['importconfirmskipped'] = '<b> $skipped  mavjud yozuvlar o‘tkazib yuborildi</b>';
$messages['importmessagesuccess'] = '$nr ta xat import qilindi.';
$messages['importmessageerror'] = 'Import muvaffaqqiyatsiz amalga oshdi. Yuklanayotgan fayl xat fayli yoki pochta qutisi fayli emas.';
$messages['opnotpermitted'] = 'Harakat ta’qiqlangan!';
$messages['nofromaddress'] = 'Tanlangan profilda e-mail manzili yetishmayapti.';
$messages['editorwarning'] = 'Tahrirchini almashtirishda matn farmatida yo‘qolishlar kuzatilishi mumkin. Davom ettirishni istaysizmi?';
$messages['httpreceivedencrypterror'] = 'Serverda jiddiy xatolik kuzatildi. Zudlik bilan administratorga murojaat eting. <b>Sizning xatingizni jo‘natishning imkoni yo\'q </b>';
$messages['smtpconnerror'] = 'SMTP xatolik ($code): Serverga ulanish muvaffaqqiyatsiz.';
$messages['smtpautherror'] = 'SMTP xatolik ($code): Autentifikatsiya muvaffaqqiyatsiz amalga oshdi.';
$messages['smtpfromerror'] = 'SMTP Xatolik($code): "$from" ($msg) jo‘natuvchini belgilash amalga oshmadi. ';
$messages['smtptoerror'] = 'SMTP Xatolik($code): "$from" ($msg) qabul qiluvchini belgilash amalga oshmadi. ';
$messages['smtprecipientserror'] = 'Qabul qiluvchilar ro‘yxatini qayta ishlash amalga oshirilmadi.';
$messages['smtperror'] = 'SMTP xatolik: $msg';
$messages['emailformaterror'] = 'Noto‘g‘ri elektron manzil: $email';
$messages['toomanyrecipients'] = 'Qabul qiluvchilar soni ko‘p/ Qabul qiluvchilar sonini $max ga qadar kamaytiring.';
$messages['maxgroupmembersreached'] = 'Guruh a’zolari soni maksimal $max qiymatdan ortiq.';
$messages['internalerror'] = 'ichki xatolik kuzatildi. Iltimos, qaytadan urinib ko‘ring.';
$messages['contactdelerror'] = 'Kontakt(lar)ni o‘chirish amalga oshirilmadi.';
$messages['contactdeleted'] = 'Kontakt(lar) o‘chirildi.';
$messages['contactrestoreerror'] = 'O‘chirilgan kontakt(lar) qayta tiklanmadi.';
$messages['contactrestored'] = 'Kontakt(lar) qayta tiklandi.';
$messages['groupdeleted'] = 'Guruh o‘chirildi.';
$messages['grouprenamed'] = 'Guruh qayta nomlandi.';
$messages['groupcreated'] = 'Guruh yaratildi.';
$messages['savedsearchdeleted'] = 'Saqlangan izlash so‘rovi o‘chirildi.';
$messages['savedsearchdeleteerror'] = 'Saqlangan izlash so‘rovini o‘chirish amalga oshmadi.';
$messages['savedsearchcreated'] = 'Saqlangan izlash so‘rovi muvaffaqqiyatli yaratildi.';
$messages['savedsearchcreateerror'] = 'Saqlangan izlash so‘rovi yaratilmadi.';
$messages['messagedeleted'] = 'Xat(lar) o‘chirildi.';
$messages['messagemoved'] = 'Xat(lar) ko‘chirildi.';
$messages['messagemovedtotrash'] = 'Xat(lar) savatga jo‘natildi.';
$messages['messagecopied'] = 'Xat(lar)dan nusxa olindi.';
$messages['messagemarked'] = 'Xat(lar)ga belgi qo‘yildi.';
$messages['autocompletechars'] = 'Avto to‘ldirish uchun kamida $min ta simvol kiriting.';
$messages['autocompletemore'] = 'Qidiruv so‘rovi ko\'plab yozuvlarni topdi. Iltimos so‘rovni aniqlashtiring.';
$messages['namecannotbeempty'] = 'Nom bo‘sh bo‘lmasligi lozim.';
$messages['nametoolong'] = 'Nom juda uzun.';
$messages['namedotforbidden'] = 'Papka nomi nuqta bilan boshlanmasligi kerak.';
$messages['folderupdated'] = 'Papka yangilandi.';
$messages['foldercreated'] = 'Papka yaratildi.';
$messages['invalidimageformat'] = 'Rasm formati noto‘g‘ri';
$messages['mispellingsfound'] = 'Xatda imlo xatolar mavjud.';
$messages['parentnotwritable'] = 'Tanlangan asos papkada boshqa papka yaratish/ko‘chirishni imkoni yo‘q. Ruxsat berilmaganl';
$messages['messagetoobig'] = 'Xat qismi qayta ishlash uchun juda katta.';
$messages['noscriptwarning'] = 'DIQQAT: Veb pochtaning mazkur xizmati javascriptni talab etadi. Uni ishlatish uchun brauzeringizda javascriptni qo‘llalb-quvvatlashni faollashtirishingiz lozim.';
$messages['messageissent'] = 'Xat jo‘natildi, biroq hali saqlanmadi. Uni hozir saqlashni istaysizmi?';
$messages['errnotfound'] = 'Fayl topilmadi';
$messages['errnotfoundexplain'] = 'So‘ralgan resurs topilmadi!';
$messages['errfailedrequest'] = 'Muvaffaqqiyatsiz so‘rov';
$messages['errauthorizationfailed'] = 'Muvaffaqqiyatsiz avtorizatsiya';
$messages['errunauthorizedexplain'] = 'Siz bu xizmatga kirish huquqiga ega ekanligingizni tekshirish amalga oshirilmadi.';
$messages['errrequestcheckfailed'] = 'Tekshiruv so‘rovi muvaffaqiyatsiz';
$messages['errcsrfprotectionexplain'] = "Sizning xavfsizligingizni ta’minlash maqsadida bu resursga kirish CSRF dan himoyalangan.\n Agar siz buni ko‘rayotgan bo‘lsangiz, siz veb dasturdan chiqishdan avval tizimni tark etmadingiz,\n\n Davom ettirish uchun inson harakati talab etiladi.";
$messages['errcontactserveradmin'] = 'Server administratoriga murojaat eting.';
$messages['clicktoresumesession'] = 'Avvalgi sessiyani davom ettirish uchn bu yerni bosing';
$messages['errcomposesession'] = 'Xatni yozish seansida xatolik';
$messages['errcomposesessionexplain'] = 'So‘ralgan xatni yozish seansi topilmadi.';
$messages['clicktocompose'] = 'Yangi xat yozish uchun bu yerni bosing';
