<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail Managesieve plugin         |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/plugin-managesieve/
*/


$labels['filters'] = 'Filtres';
$labels['managefilters'] = 'Gérer les filtres de courriels entrants';
$labels['filtername'] = 'Nom du filtre';
$labels['newfilter'] = 'Nouveau filtre';
$labels['filteradd'] = 'Ajouter un filtre';
$labels['filterdel'] = 'Supprimer le filtre';
$labels['rules'] = 'Règles';
$labels['actions'] = 'Actions';
$labels['scope'] = 'Portée';
$labels['moveup'] = 'Monter';
$labels['movedown'] = 'Descendre';
$labels['filterallof'] = 'correspondant à toutes les règles suivantes';
$labels['filteranyof'] = 'valident au moins une des conditions suivantes';
$labels['filterany'] = 'tous les courriels';
$labels['filtercontains'] = 'contient';
$labels['filternotcontains'] = 'ne contient pas';
$labels['filteris'] = 'est égal à';
$labels['filterisnot'] = 'est différent de';
$labels['filterexists'] = 'existe';
$labels['filternotexists'] = 'n’existe pas';
$labels['filtermatches'] = 'correspond à l’expression';
$labels['filternotmatches'] = 'ne correspond pas à l’expression';
$labels['filterregex'] = 'correspond à l’expression rationnelle';
$labels['filternotregex'] = 'ne correspond pas à l’expression rationnelle';
$labels['filterunder'] = 'plus petit que';
$labels['filterover'] = 'plus grand que';
$labels['mime'] = 'MIME :';
$labels['mimepart'] = 'Partie MIME :';
$labels['mime-message'] = 'message';
$labels['mime-anychild'] = 'tout';
$labels['mime-type'] = 'type';
$labels['mime-subtype'] = 'sous-type';
$labels['mime-contenttype'] = 'type de contenu';
$labels['mime-param'] = 'paramètre';
$labels['addrule'] = 'Ajouter une règle';
$labels['delrule'] = 'Supprimer une règle';
$labels['messagemoveto'] = 'Déplacer le courriel vers';
$labels['messageredirect'] = 'Rediriger le courriel vers';
$labels['messagecopyto'] = 'Copier le courriel vers';
$labels['messagesendcopy'] = 'Envoyer une copie du courriel à';
$labels['messagereply'] = 'Répondre avec le courriel';
$labels['messagedelete'] = 'Supprimer le courriel';
$labels['messagediscard'] = 'Rejeter avec le courriel';
$labels['messagekeep'] = 'Conserver le courriel dans la boîte de réception';
$labels['messagesrules'] = 'Pour les courriels entrants :';
$labels['messagesactions'] = '…exécuter les actions suivantes :';
$labels['add'] = 'Ajouter';
$labels['del'] = 'Supprimer';
$labels['sender'] = 'Expéditeur';
$labels['recipient'] = 'Destinataire';
$labels['vacationaddr'] = 'Mes adresses courriel :';
$labels['vacationdays'] = 'Fréquence d’envoi des courriels (en jours) :';
$labels['vacationinterval'] = 'Fréquence d’envoi des courriels :';
$labels['vacationreason'] = 'Corps du courriel (raison de l’absence) :';
$labels['vacationfrom'] = 'Adresse de réponse de l’expéditeur :';
$labels['vacationsubject'] = 'Objet du courriel :';
$labels['days'] = 'jours';
$labels['seconds'] = 'secondes';
$labels['rulestop'] = 'Arrêter l’évaluation des règles';
$labels['enable'] = 'Activer/désactiver';
$labels['filterset'] = 'Jeu de filtres';
$labels['filtersets'] = 'Jeux de filtres';
$labels['filtersetadd'] = 'Ajouter un jeu de filtres';
$labels['filtersetdel'] = 'Supprimer le jeu de filtres';
$labels['filtersetact'] = 'Activer le jeu de filtres actuel';
$labels['filtersetdeact'] = 'Désactiver le jeu de filtres actuel';
$labels['filterseteditraw'] = 'Modifier le jeu de filtres';
$labels['filtersetswitch'] = 'Activer, désactiver un jeu de filtres';
$labels['filterdef'] = 'Définition du filtre';
$labels['filtersetname'] = 'Nom du jeu de filtres';
$labels['newfilterset'] = 'Nouveau jeu de filtres';
$labels['active'] = 'activer';
$labels['none'] = 'aucun';
$labels['fromset'] = 'à partir du jeu';
$labels['fromfile'] = 'à partir du fichier';
$labels['filterdisabled'] = 'Filtre désactivé';
$labels['filterenabled'] = 'Le filtre est activé';
$labels['countisgreaterthan'] = 'total supérieur à';
$labels['countisgreaterthanequal'] = 'total supérieur ou égal à';
$labels['countislessthan'] = 'total inférieur à';
$labels['countislessthanequal'] = 'total inférieur ou égal à';
$labels['countequals'] = 'total égal à';
$labels['countnotequals'] = 'le nombre n’est pas égal à';
$labels['valueisgreaterthan'] = 'valeur supérieure à';
$labels['valueisgreaterthanequal'] = 'valeur supérieure ou égale à';
$labels['valueislessthan'] = 'valeur inférieure à';
$labels['valueislessthanequal'] = 'valeur inférieure ou égale à';
$labels['valueequals'] = 'valeur égale à';
$labels['valuenotequals'] = 'la valeur n’est pas égale à';
$labels['setflags'] = 'Définir les drapeaux pour le courriel';
$labels['addflags'] = 'Ajouter les drapeaux au courriel';
$labels['removeflags'] = 'Supprimer les drapeaux du courriel';
$labels['flagread'] = 'Lu';
$labels['flagdeleted'] = 'Supprimé';
$labels['flaganswered'] = 'Réponse envoyée';
$labels['flagflagged'] = 'Signalé';
$labels['flagdraft'] = 'Brouillon';
$labels['addheader'] = 'Ajouter un en-tête au courriel';
$labels['deleteheader'] = 'Supprimer l’en-tête du courriel';
$labels['headername'] = 'Nom de l’en-tête';
$labels['headervalue'] = 'Valeur de l’en-tête';
$labels['headerpos'] = 'Position de l’en-tête';
$labels['headeratstart'] = 'au début';
$labels['headeratend'] = 'à la fin';
$labels['headeroccurrence'] = 'Occurrence/position de l’en-tête';
$labels['headerfromstart'] = 'du début';
$labels['headerfromend'] = 'de la fin';
$labels['headerpatterns'] = 'Schémas de valeur d’en-tête';
$labels['headermatchtype'] = 'type de concordance :';
$labels['setvariable'] = 'Définir une variable';
$labels['setvarname'] = 'Nom de la variable :';
$labels['setvarvalue'] = 'Valeur de la variable :';
$labels['setvarmodifiers'] = 'Modificateurs :';
$labels['varlower'] = 'minuscule';
$labels['varupper'] = 'majuscule';
$labels['varlowerfirst'] = 'premier caractère en minuscule';
$labels['varupperfirst'] = 'premier caractère en majuscule';
$labels['varquotewildcard'] = 'citer les caractères spéciaux';
$labels['varlength'] = 'longueur';
$labels['varencodeurl'] = 'pourcentage encodé (pour les URL)';
$labels['notify'] = 'Envoyer la notification';
$labels['notifytarget'] = 'Cible de la notification :';
$labels['notifymessage'] = 'Courriel de notification (facultatif) :';
$labels['notifyoptions'] = 'Options de notification (facultatif) :';
$labels['notifyfrom'] = 'Expéditeur de la notification (facultatif) :';
$labels['notifyimportance'] = 'Importance :';
$labels['notifyimportancelow'] = 'faible';
$labels['notifyimportancenormal'] = 'normale';
$labels['notifyimportancehigh'] = 'haute';
$labels['notifymethodmailto'] = 'Courriel';
$labels['notifymethodtel'] = 'Téléphone';
$labels['notifymethodsms'] = 'Texto';
$labels['filtercreate'] = 'Créer un filtre';
$labels['usedata'] = 'Utiliser les données suivantes dans le filtre :';
$labels['nextstep'] = 'Étape suivante';
$labels['...'] = '…';
$labels['string'] = 'Chaîne';
$labels['currdate'] = 'Date actuelle';
$labels['datetest'] = 'Date';
$labels['dateheader'] = 'en-tête :';
$labels['year'] = 'année';
$labels['month'] = 'mois';
$labels['day'] = 'jour';
$labels['date'] = 'date (aaaa-mm-jj)';
$labels['julian'] = 'date (julien)';
$labels['hour'] = 'heure';
$labels['minute'] = 'minute';
$labels['second'] = 'seconde';
$labels['time'] = 'heure (hh:mm:ss)';
$labels['iso8601'] = 'date (ISO8601)';
$labels['std11'] = 'date (RFC2822)';
$labels['zone'] = 'fuseau horaire';
$labels['weekday'] = 'jour de la semaine (0 à 6)';
$labels['advancedopts'] = 'Options avancées';
$labels['body'] = 'Corps';
$labels['address'] = 'adresse';
$labels['envelope'] = 'enveloppe';
$labels['modifier'] = 'modificateur :';
$labels['text'] = 'texte';
$labels['undecoded'] = 'non décodé (brut)';
$labels['contenttype'] = 'type de contenu';
$labels['modtype'] = 'type :';
$labels['allparts'] = 'tout';
$labels['domain'] = 'domaine';
$labels['localpart'] = 'partie locale';
$labels['user'] = 'utilisateur';
$labels['detail'] = 'détail';
$labels['comparator'] = 'comparateur :';
$labels['default'] = 'par défaut';
$labels['octet'] = 'strict (octet)';
$labels['asciicasemap'] = 'insensible à la casse (ascii-casemap)';
$labels['asciinumeric'] = 'numérique (ascii-numeric)';
$labels['index'] = 'index :';
$labels['indexlast'] = 'à l’envers';
$labels['spamtest'] = 'Le niveau de pourriel';
$labels['spamtestisgreaterthan'] = 'est supérieur à';
$labels['spamtestisgreaterthanequal'] = 'est supérieur ou égal à';
$labels['spamtestislessthan'] = 'est inférieur à';
$labels['spamtestislessthanequal'] = 'est inférieur ou égal à';
$labels['spamtestequals'] = 'est égal à';
$labels['spamtestnotequals'] = 'est différent de';
$labels['spamtestisunknown'] = 'est inconnu';
$labels['vacation'] = 'Avis d’absence';
$labels['vacation.reply'] = 'Courriel de réponse';
$labels['vacation.advanced'] = 'Paramètres avancés';
$labels['vacation.from'] = 'Adresse de réponse de l’expéditeur';
$labels['vacation.subject'] = 'Objet';
$labels['vacation.body'] = 'Corps';
$labels['vacation.start'] = 'Début';
$labels['vacation.end'] = 'Fin';
$labels['vacation.status'] = 'État';
$labels['vacation.on'] = 'Marche';
$labels['vacation.off'] = 'Arrêt';
$labels['vacation.addresses'] = 'Mes adresses courriel';
$labels['vacation.interval'] = 'Plage de réponse';
$labels['vacation.after'] = 'Mettre la règle d’avis d’absence après';
$labels['vacation.saving'] = 'Enregistrement des données…';
$labels['vacation.action'] = 'Action pour courriel entrant';
$labels['vacation.keep'] = 'Garder';
$labels['vacation.discard'] = 'Rejeter';
$labels['vacation.redirect'] = 'Réacheminer à';
$labels['vacation.copy'] = 'Envoyer une copie à';
$labels['forward'] = 'Transfert';
$labels['forward.redirect'] = 'Réacheminer à';
$labels['forward.copy'] = 'Envoyer une copie à';
$labels['forward.on'] = 'Marche';
$labels['forward.off'] = 'Arrêt';
$labels['forward.status'] = 'État :';
$labels['forward.action'] = 'Pour les courriels entrants, exécuter l’action suivante :';
$labels['forward.saving'] = 'Enregistrement des données…';
$labels['filladdresses'] = 'Remplir avec toutes mes adresses';
$labels['arialabelfiltersetactions'] = 'Actions des jeux de filtrage';
$labels['arialabelfilteractions'] = 'Actions de filtrage';
$labels['arialabelfilterform'] = 'Propriété du filtrage';
$labels['ariasummaryfilterslist'] = 'Liste des filtres';
$labels['ariasummaryfiltersetslist'] = 'Liste des jeux de filtrage';
$labels['filterstitle'] = 'Modifier les filtres de courriels entrants';
$labels['vacationtitle'] = 'Modifier la règle d’absence du bureau';
$labels['forwardtitle'] = 'Modifier la règle de transfert des courriels';
$labels['message'] = 'Message';
$labels['duplicate'] = 'est un doublon';
$labels['notduplicate'] = 'n’est pas un doublon';
$labels['duplicate.handle'] = 'descripteur :';
$labels['duplicate.header'] = 'en-tête :';
$labels['duplicate.uniqueid'] = 'identifiant :';
$labels['duplicate.seconds'] = 'temporisation (secondes) :';
$labels['duplicate.last'] = 'par rapport à la dernière exécution';
$messages['filterunknownerror'] = 'Erreur de serveur inconnue';
$messages['filterconnerror'] = 'La connexion au serveur n’aboutit pas.';
$messages['filterdeleteerror'] = 'Impossible de supprimer le filtre. Une erreur de serveur est survenue.';
$messages['filterdeleted'] = 'Le filtre a été supprimé avec succès.';
$messages['filtersaved'] = 'Le filtre a été enregistré avec succès.';
$messages['filtersaveerror'] = 'Impossible d’enregistrer le filtre. Une erreur de serveur est survenue.';
$messages['filterformerror'] = 'Le formulaire de filtrage contient des erreurs.';
$messages['filterdeleteconfirm'] = 'Voulez-vous vraiment supprimer le filtre sélectionné ?';
$messages['ruledeleteconfirm'] = 'Voulez-vous vraiment supprimer la règle sélectionnée ?';
$messages['actiondeleteconfirm'] = 'Voulez-vous vraiment supprimer l’action sélectionnée ?';
$messages['forbiddenchars'] = 'Caractères interdits dans le champ';
$messages['cannotbeempty'] = 'Le champ ne peut pas être vide';
$messages['ruleexist'] = 'Un filtre existe déjà avec ce nom.';
$messages['setactivateerror'] = 'Impossible d’activer le jeu de filtres sélectionné. Une erreur de serveur est survenue.';
$messages['setdeactivateerror'] = 'Impossible de désactiver le jeu de filtres sélectionné. Une erreur de serveur est survenue.';
$messages['setdeleteerror'] = 'Impossible de supprimer le jeu de filtres sélectionné. Une erreur de serveur est survenue.';
$messages['setactivated'] = 'Le jeu de filtres a été activé avec succès.';
$messages['setdeactivated'] = 'Le jeu de filtres a été désactivé avec succès.';
$messages['setdeleted'] = 'Le jeu de filtres a été supprimé avec succès.';
$messages['setupdated'] = 'Le jeu de filtres a été mis à jour avec succès.';
$messages['setdeleteconfirm'] = 'Voulez vous vraiment supprimer le jeu de filtres sélectionné ?';
$messages['setcreateerror'] = 'Impossible de créer un jeu de filtres. Une erreur de serveur est survenue.';
$messages['setcreated'] = 'Le jeu de filtres a été créé avec succès.';
$messages['activateerror'] = 'Impossible d’activer les filtres sélectionnés. Une erreur de serveur est survenue.';
$messages['deactivateerror'] = 'Impossible de désactiver les filtres sélectionnés. Une erreur de serveur est survenue.';
$messages['deactivated'] = 'Filtres désactivés avec succès.';
$messages['activated'] = 'Filtres activés avec succès.';
$messages['moved'] = 'Filtre déplacé avec succès.';
$messages['moveerror'] = 'Impossible de déplacer le filtre sélectionné. Une erreur de serveur est survenue.';
$messages['nametoolong'] = 'Nom trop long.';
$messages['namereserved'] = 'Nom réservé.';
$messages['setexist'] = 'Le jeu existe déjà.';
$messages['nodata'] = 'Au moins un élément doit être sélectionné.';
$messages['invaliddateformat'] = 'Format de date ou d’une partie de la date invalide';
$messages['saveerror'] = 'Impossible d’enregistrer les données. Une erreur du serveur est survenue.';
$messages['vacationsaved'] = 'Les données d’avis d’absence ont été enregistrées avec succès.';
$messages['forwardsaved'] = 'Les données de transfert ont été enregistrées avec succès.';
$messages['emptyvacationbody'] = 'Le corps du courriel de vacances est requis';
$messages['duplicate.conflict.err'] = 'L’en-tête et l’identifiant unique ne sont pas permis.';
$messages['disabledaction'] = 'L’action n’est pas permise.';
$messages['lastindexempty'] = 'L’index est requis en comptant de la fin';
$messages['noflagset'] = 'Au moins un drapeau doit être sélectionné.';
