<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail ACL plugin                 |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/plugin-acl/
*/

$labels['sharing'] = 'Utdelning';
$labels['myrights'] = 'Åtkomsträttigheter';
$labels['username'] = 'Användare:';
$labels['advanced'] = 'Avancerat läge';
$labels['add'] = 'Lägg till';
$labels['newuser'] = 'Lägg till';
$labels['editperms'] = 'Ändra rättigheter';
$labels['actions'] = 'Hantera åtkomsträttigheter...';
$labels['anyone'] = 'Alla användare (vem som helst)';
$labels['anonymous'] = 'Gäster (anonyma)';
$labels['identifier'] = 'Identifikation';
$labels['acll'] = 'Uppslagning';
$labels['aclr'] = 'Läs meddelanden';
$labels['acls'] = 'Behåll status Läst';
$labels['aclw'] = 'Skriv flaggor';
$labels['acli'] = 'Infoga (kopiera in)';
$labels['aclp'] = 'Posta';
$labels['aclc'] = 'Skapa undermappar';
$labels['aclk'] = 'Skapa undermappar';
$labels['acld'] = 'Ta bort meddelanden';
$labels['aclt'] = 'Ta bort meddelanden';
$labels['acle'] = 'Utplåna';
$labels['aclx'] = 'Ta bort mapp';
$labels['acla'] = 'Administrera';
$labels['acln'] = 'Kommentera meddelanden';
$labels['aclfull'] = 'Full kontroll';
$labels['aclother'] = 'Övrig';
$labels['aclread'] = 'Läs';
$labels['aclwrite'] = 'Skriv';
$labels['acldelete'] = 'Ta bort';
$labels['shortacll'] = 'Uppslagning';
$labels['shortaclr'] = 'Läs';
$labels['shortacls'] = 'Behåll';
$labels['shortaclw'] = 'Skriv';
$labels['shortacli'] = 'Infoga';
$labels['shortaclp'] = 'Posta';
$labels['shortaclc'] = 'Skapa';
$labels['shortaclk'] = 'Skapa';
$labels['shortacld'] = 'Ta bort';
$labels['shortaclt'] = 'Ta bort';
$labels['shortacle'] = 'Utplåna';
$labels['shortaclx'] = 'Ta bort mapp';
$labels['shortacla'] = 'Administrera';
$labels['shortacln'] = 'Kommentera';
$labels['shortaclother'] = 'Övrig';
$labels['shortaclread'] = 'Läs';
$labels['shortaclwrite'] = 'Skriv';
$labels['shortacldelete'] = 'Ta bort';
$labels['longacll'] = 'Mappen är synlig i listor och den kan prenumereras på';
$labels['longaclr'] = 'Mappen kan öppnas för läsning';
$labels['longacls'] = 'Meddelandeflagga Läst kan ändras';
$labels['longaclw'] = 'Meddelandeflaggor och nyckelord kan ändras, undantaget Läst och Borttagen';
$labels['longacli'] = 'Meddelanden kan skrivas eller kopieras till mappen';
$labels['longaclp'] = 'Meddelanden kan postas till denna mapp';
$labels['longaclc'] = 'Mappar kan skapas (eller ges annat namn) direkt i denna mapp';
$labels['longaclk'] = 'Mappar kan skapas (eller ges annat namn) direkt i denna mapp';
$labels['longacld'] = 'Meddelandeflagga Borttaget kan ändras';
$labels['longaclt'] = 'Meddelandeflagga Borttaget kan ändras';
$labels['longacle'] = 'Meddelanden kan utplånas';
$labels['longaclx'] = 'Mappen kan tas bort eller ges annat namn';
$labels['longacla'] = 'Mappens åtkomsträttigheter kan ändras';
$labels['longacln'] = 'Delad information om meddelanden (kommentarer) kan ändras';
$labels['longaclfull'] = 'Full kontroll inklusive mappadministration';
$labels['longaclread'] = 'Mappen kan öppnas för läsning';
$labels['longaclwrite'] = 'Meddelanden kan markeras, skrivas eller kopieras till mappen';
$labels['longacldelete'] = 'Meddelanden kan tas bort';
$labels['longaclother'] = 'Övriga åtkomsträttigheter';
$labels['ariasummaryacltable'] = 'Lista med åtkomsträttigheter';
$labels['arialabelaclactions'] = 'Hantera listor';
$labels['arialabelaclform'] = 'Formulär för åtkomsträttigheter';
$messages['deleting'] = 'Tar bort åtkomsträttigheter...';
$messages['saving'] = 'Sparar åtkomsträttigheter...';
$messages['updatesuccess'] = 'Åtkomsträttigheterna är ändrade';
$messages['deletesuccess'] = 'Åtkomsträttigheterna är borttagna';
$messages['createsuccess'] = 'Åtkomsträttigheterna är tillagda';
$messages['updateerror'] = 'Åtkomsträttigheterna kunde inte ändras';
$messages['deleteerror'] = 'Åtkomsträttigheterna kunde inte tas bort';
$messages['createerror'] = 'Åtkomsträttigheterna kunde inte läggas till';
$messages['deleteconfirm'] = 'Vill du verkligen ta bort åtkomsträttigheterna för markerade användare?';
$messages['norights'] = 'Inga åtkomsträttigheter angavs!';
$messages['nouser'] = 'Inget användarnamn angavs!';
