<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail client                     |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/messages/
*/

$messages['errortitle']  = 'Սխա՛լ';
$messages['loginfailed']  = 'Մուտքը ձախողվեց';
$messages['cookiesdisabled'] = 'Сookies–ների ապահովվումը բացակայում է';
$messages['sessionerror'] = 'Անվավեր կամ ժամկետանց սեսիա';
$messages['storageerror'] = 'IMAP սերվերի հետ կապը ձախողվեց';
$messages['servererror'] = 'Սերվերի սխա՛լ';
$messages['servererrormsg'] = 'Սերվերի սխալ` $msg';
$messages['dberror'] = 'Տվյալների շտեմարանի սխա՛լ';
$messages['requesttimedout'] = 'Հարցման թույլատրելի ժամանակը սպառվեց';
$messages['errorreadonly'] = 'Գործողությունը անհնար է։ Պանակը միայն ընթերցման համար է։';
$messages['errornoperm'] = 'Գործողության կատարման իրավունքը մերժված է։';
$messages['invalidrequest'] = 'Սխալ հարցում, ապարդյուն։';
$messages['nomessagesfound'] = 'Այս փոստարկղում նամակներ չկան';
$messages['loading'] = 'Բեռնում...';
$messages['uploading'] = 'Ֆայլի վերբեռնում…';
$messages['uploadingmany'] = 'Վերբեռնվում են ֆայլերը…';
$messages['loadingdata'] = 'Տվյալների բեռնավորում…';
$messages['checkingmail'] = 'Նոր նամակների ստուգում…';
$messages['sendingmessage'] = 'Նամակի ուղարկում…';
$messages['messagesent'] = 'Նամակն ուղարկված է';
$messages['savingmessage'] = 'Նամակի գրանցում…';
$messages['messagesaved'] = 'Նամակը գրանցվեց որպես սևագիր';
$messages['successfullysaved'] = 'Գրանցված է';
$messages['addedsuccessfully'] = 'Հասցեն ավելացված է';
$messages['contactnameexists'] = 'Նույն անունով արդեն անձ գոյություն ունի։';
$messages['blockedimages'] = 'Ձեր անվտանգության համար, այս նամակի արտաքին նկարներն բեռնված չեն';
$messages['encryptedmessage'] = 'Ներողություն, այս նամակը կոդավորված է';
$messages['nocontactsfound'] = 'Հասցեներ չկան';
$messages['contactnotfound'] = 'Որոնվող հասցեն չգտնվեց';
$messages['sendingfailed'] = 'Նամակի ուղարկումը ձախողվեց';
$messages['senttooquickly'] = 'Խնդրում ենք սպասել $sec վարկյան մինչ այս նամակն ուղարկելը';
$messages['errormoving'] = 'Նամակի տեղափոխման ձախողում';
$messages['errorcopying'] = 'Հաղորդագրության պատճենումը ձախողվեց։';
$messages['errordeleting'] = 'Նամակի ջնջման ձախողում';
$messages['errormarking'] = 'Հաղորդագրության նշումը ձախողվեց։';
$messages['deletecontactconfirm']  = 'Ուզու՞մ էք ջնջել նշված անձերին';
$messages['deletegroupconfirm']  = 'Դուք իսկապե՞ս ուզում եք ջնջել նշված խումբը։';
$messages['deletemessagesconfirm'] = 'Ուզու՞մ էք ջնջել նշված նամակները';
$messages['deletefolderconfirm']  = 'Ուզու՞մ էք ջնջել այս դարակը';
$messages['purgefolderconfirm']  = 'Ուզու՞մ էք ջնջել այս դարակի բոլոր նամակները';
$messages['contactdeleting'] = 'Անձի ջնջում…';
$messages['groupdeleting'] = 'Խմբի ջնջում…';
$messages['folderdeleting'] = 'Դարակը ջնջվում է…';
$messages['foldermoving'] = 'Դարակը տեղափոխվում է…';
$messages['foldersubscribing'] = 'Պանակի բաժանորդագրում…';
$messages['folderunsubscribing'] = 'Պանակի ապաբաժանորդագրում…';
$messages['formincomplete'] = 'Ձևը թերի է լրացված';
$messages['noemailwarning'] = 'Մուտքագրեք ճիշտ էլ. հասցե';
$messages['nonamewarning']  = 'Մուտքագրեք անուն';
$messages['nopagesizewarning'] = 'Մուտքագրեք էջի չափս';
$messages['norecipientwarning'] = 'Մուտքագրեք նվազագույնը մեկ հասցեատեր';
$messages['nosubjectwarning']  = 'Վերնագիր բացակայում է, ցանկանո՞ւմ եք լրացնել';
$messages['nobodywarning'] = 'Ուղարկե՞լ այս նամակը դատարկ';
$messages['nosearchname'] = 'Մուտքագրեք հասցեատեր կամ էլ. հասցե';
$messages['notuploadedwarning'] = 'Ոչ բոլոր կցված նյութերն են վերբեռնվել։ Սպասեք կամ ընդհատեք վերբեռնումը։';
$messages['searchsuccessful'] = 'Գտնվեց $nr նամակ';
$messages['contactsearchsuccessful'] = 'Գտնվել է $nr անձ։';
$messages['searchnomatch'] = 'Համապատասխան նամակներ չգտնվեցին';
$messages['searching'] = 'Որոնում...';
$messages['checking'] = 'Ստուգում…';
$messages['nospellerrors'] = 'Ուղագրական սխալներ չկան';
$messages['folderdeleted'] = 'Դարակը ջնջվեց';
$messages['foldersubscribed'] = 'Պանակին բաժանորդագրումը հաջողվեց։';
$messages['folderunsubscribed'] = 'Պանակից ապաբաժանորդագրումը հաջողվեց։';
$messages['deletedsuccessfully'] = 'Ջնջված է';
$messages['converting'] = 'Նամակի ձևավորման հեռացում…';
$messages['messageopenerror'] = 'Նամակի բեռնվումը սերվերից ձախողվեց';
$messages['fileuploaderror'] = 'Ֆայլի կցումն ձախողվեց';
$messages['filesizeerror'] = 'Ֆայլի չափը գերազանցում է մաքսիմալը՝ $size';
$messages['sourceisreadonly'] = 'Այս հասցեն պաշտպանված է';
$messages['errorsavingcontact'] = 'Հասցեի գրանցումն ձախողվեց';
$messages['movingmessage'] = 'Նամակը տեղափոխվում է…';
$messages['copyingmessage'] = 'Հաղորդագրությունների պատճենում…';
$messages['copyingcontact'] = 'Անձանց պատճենում…';
$messages['deletingmessage'] = 'Հաղորդագրությունների ջնջում…';
$messages['markingmessage'] = 'Հաղորդագրությունների նշում…';
$messages['addingmember'] = 'Անձանց ավելացում խմբին…';
$messages['removingmember'] = 'Անձանց հեռացում խմբից…';
$messages['receiptsent'] = 'Նամակի ընթերցման ծանուցագիրն ուղարկված է';
$messages['errorsendingreceipt'] = 'Ծանուցագրի ուղարկումը ձախողվեց';
$messages['deleteidentityconfirm'] = 'Դուք իսկապե՞ս ուզում եք ջնջել այս ինքնությունը։';
$messages['nodeletelastidentity'] = 'Անհնար է ջնջել վերջին տարբերակը';
$messages['forbiddencharacter'] = 'Դարակի անունը պարունակում է անթույլատրելի նշան';
$messages['selectimportfile'] = 'Ընտրեք ուղարկվող ֆայլը';
$messages['addresswriterror'] = 'Ընտրված հասցեագիրքը ենթակա չէ փոփոխման';
$messages['contactaddedtogroup'] = 'Անձինք բարեհաջող ավելացվեցին խմբին։';
$messages['contactremovedfromgroup'] = 'Անձինք բարեհաջող հանվեցին խմբից։';
$messages['importwait'] = 'Ներկրումն ընթացքի մեջ է...';
$messages['importconfirm'] = '$inserted նոր ներկրված հասցեներ, $skipped արդեն առկա հասցեներ՝ <p><em>$names</em></p>';
$messages['importconfirmskipped'] = '<b>Բաց թողնվեց $skipped առկա գրառում</b>';
$messages['opnotpermitted'] = 'Գործողությունը անթույլատրելի է։';
$messages['httpreceivedencrypterror'] = 'Համակարգի լարքի սխալ։ Դիմեք համակարգը սպասարկող անձնակազմին։ <b>Ձեր նամակը ուղարկված չէ։</b>';
$messages['smtpconnerror'] = 'SMTP սխալ ($code)` Սերվերի հետ կապը ձախողվեց։';
$messages['smtpautherror'] = 'SMTP սխալ ($code)` Նույնականացումը ձախողվեց։';
$messages['smtpfromerror'] = 'SMTP սխալ ($code)` Որպես "$from" ($msg) հաղորդագրությունը ուղարկելը ձախողվեց։';
$messages['smtptoerror'] = 'SMTP սխալ ($code)` Հաղորդագրության ստացող "$to"-ին ($msg) ավելացնելը ձախողվեց։';
$messages['smtprecipientserror'] = 'SMTP սխալ` ստացողների ցուցակի ընթերցման ձախողում։';
$messages['smtperror'] = 'SMTP սխալ` $msg';
$messages['toomanyrecipients'] = 'Ստացողների քանակը չափազանց մեծ է։ Նվազեցրեք մինչև $max-ը։';
$messages['maxgroupmembersreached'] = 'Խմբի անդամների քանաքը գերազանցում է թույլատրելի $max-ը։';
$messages['contactdelerror'] = 'Անձանց ջնջումը ձախողվեց։';
$messages['contactdeleted'] = 'Անձանց ջնջումը հաջողվեց։';
$messages['contactrestoreerror'] = 'Ջնջված անձանց վերականգնումը ձախողվեց։';
$messages['contactrestored'] = 'Ջնջված անձանց վերականգնումը հաջողվեց։';
$messages['groupdeleted'] = 'Խումբը ջնջվեց։';
$messages['grouprenamed'] = 'Խումբը վերանվանվեց։';
$messages['groupcreated'] = 'Խումբը ստեղծվեց։';
$messages['savedsearchdeleted'] = 'Պահպանված որոնումը ջնջվեց։';
$messages['savedsearchdeleteerror'] = 'Պահպանված որոնման ջնջումը ձախողվեց։';
$messages['savedsearchcreated'] = 'Որոնումը պահպանվեց։';
$messages['savedsearchcreateerror'] = 'Պահպանված որոնման ստեղծումը ձախողվեց։';
$messages['messagedeleted'] = 'Հաղորդագրությունները ջնջվեցին։';
$messages['messagemoved'] = 'Հաղորդագրությունները տեղափոխվեցին։';
$messages['messagecopied'] = 'Հաղորդագրությունները պատճենվեցին։';
$messages['messagemarked'] = 'Հաղորդագրությունները նշվեցին։';
$messages['autocompletechars'] = 'Ավտոլրացման համար ներմուծեք առնվազն $min նիշ։';
$messages['autocompletemore'] = 'Գտնված են համապատասխանող գրառումներ, ներմուծեք հավելյալ նիշեր։';
$messages['namecannotbeempty'] = 'Անունը դատարկ չի կարող լինել։';
$messages['nametoolong'] = 'Անունը չափազանց երկար է։';
$messages['folderupdated'] = 'Պանակը թարմացվեց։';
$messages['foldercreated'] = 'Պանակը ստեղծվեց։';
$messages['invalidimageformat'] = 'Պատկերի սխալ ձևաչափ։';
$messages['mispellingsfound'] = 'Հաղորդագրության մեջ կան տառասխալներ։';
$messages['parentnotwritable'] = 'Նշված պանակի մեջ պանակի ստեղծումը կամ տեղափոխումը անհնար է անբավարար իրավունքների պատճառով։';
$messages['messagetoobig'] = 'Հաղորդագրության մասը չափազանց մեծ է սպասարկման համար։';
