<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail client                     |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/labels/
*/


$labels['welcome'] = 'Добредојдовте во $product';
$labels['username'] = 'Корисничко име';
$labels['password'] = 'Лозинка';
$labels['server'] = 'Сервер';
$labels['login'] = 'Најава';
$labels['logout'] = 'Одјава';
$labels['mail'] = 'Е-пошта';
$labels['settings'] = 'Нагодувања';
$labels['addressbook'] = 'Именик';
$labels['inbox'] = 'Примени';
$labels['drafts'] = 'Непратени';
$labels['sent'] = 'Пратени';
$labels['trash'] = 'Корпа';
$labels['junk'] = 'Ѓубре';
$labels['show_real_foldernames'] = 'Прикажи ги вистинските имиња за специјалните папки ';
$labels['subject'] = 'Наслов';
$labels['from'] = 'Од';
$labels['sender'] = 'Праќач';
$labels['to'] = 'Примач';
$labels['cc'] = 'Копирај';
$labels['bcc'] = 'Bcc';
$labels['replyto'] = 'Препрати на';
$labels['followupto'] = 'Проследи до';
$labels['date'] = 'Датум';
$labels['size'] = 'Големина';
$labels['priority'] = 'Приоритет';
$labels['organization'] = 'Организација';
$labels['readstatus'] = 'Прочитај статус ';
$labels['listoptions'] = 'Опции на листа...';
$labels['mailboxlist'] = 'Папки';
$labels['messagesfromto'] = 'Писма од $from до $to од $count';
$labels['threadsfromto'] = 'Теми $од до $до на $брои';
$labels['messagenrof'] = 'Писмо $nr од $count';
$labels['fromtoshort'] = '$од - $до на $брои';
$labels['copy'] = 'Копирај';
$labels['move'] = 'Премести';
$labels['moveto'] = 'Премести во...';
$labels['copyto'] = 'Копирај во ...';
$labels['download'] = 'Преземи';
$labels['open'] = 'Отвори';
$labels['showattachment'] = 'Прикажи';
$labels['showanyway'] = 'Прикажи го во секој случај';
$labels['filename'] = 'Име на податотеката';
$labels['filesize'] = 'Големина на податотеката';
$labels['addtoaddressbook'] = 'Додај во именик';
$labels['sun'] = 'Нед';
$labels['mon'] = 'Пон';
$labels['tue'] = 'Вто';
$labels['wed'] = 'Сре';
$labels['thu'] = 'Чет';
$labels['fri'] = 'Пет';
$labels['sat'] = 'Саб';
$labels['sunday'] = 'Недела';
$labels['monday'] = 'Понеделник';
$labels['tuesday'] = 'Вторник';
$labels['wednesday'] = 'Среда';
$labels['thursday'] = 'Четврток';
$labels['friday'] = 'Петок';
$labels['saturday'] = 'Сабота';
$labels['jan'] = 'Јан';
$labels['feb'] = 'Фев';
$labels['mar'] = 'Мар';
$labels['apr'] = 'Апр';
$labels['may'] = 'Мај';
$labels['jun'] = 'Јун';
$labels['jul'] = 'Јул';
$labels['aug'] = 'Авг';
$labels['sep'] = 'Сеп';
$labels['oct'] = 'Окт';
$labels['nov'] = 'Ное';
$labels['dec'] = 'Дек';
$labels['longjan'] = 'Јануари';
$labels['longfeb'] = 'Февруари';
$labels['longmar'] = 'Март';
$labels['longapr'] = 'Април';
$labels['longmay'] = 'Мај';
$labels['longjun'] = 'Јуни';
$labels['longjul'] = 'Јули';
$labels['longaug'] = 'Август';
$labels['longsep'] = 'Септември';
$labels['longoct'] = 'Октомври';
$labels['longnov'] = 'Ноември';
$labels['longdec'] = 'Декември';
$labels['today'] = 'Денес';
$labels['refresh'] = 'Освежи';
$labels['checkmail'] = 'Провери пошта';
$labels['compose'] = 'Пиши ново писмо';
$labels['writenewmessage'] = 'Ново писмо';
$labels['reply'] = 'Врати ';
$labels['replytomessage'] = 'Одговори на испраќачот';
$labels['replytoallmessage'] = 'Одговори на испраќачот и сите примачи';
$labels['replyall'] = 'Одговори на сите';
$labels['replylist'] = 'Листа за одговарање';
$labels['forward'] = 'Препрати ';
$labels['forwardinline'] = 'Препрати во линија ';
$labels['forwardattachment'] = 'Препрати како ';
$labels['forwardmessage'] = 'Препрати писмо';
$labels['deletemessage'] = 'Избриши писмо';
$labels['movemessagetotrash'] = 'Премести ги писмата во Корпа';
$labels['printmessage'] = 'Испечати писмо';
$labels['previousmessage'] = 'Прикажи го претходното писмо';
$labels['firstmessage'] = 'Прикажи го првото писмо';
$labels['nextmessage'] = 'Прикажи го следното писмо';
$labels['lastmessage'] = 'Прикажи го последното писмо';
$labels['backtolist'] = 'Назад кон листа на писма';
$labels['viewsource'] = 'Покажи го изворот на писмото';
$labels['mark'] = 'Означи ';
$labels['markmessages'] = 'Обележи ги писмата';
$labels['markread'] = 'Како прочитани';
$labels['markunread'] = 'Како непрочитани';
$labels['markflagged'] = 'Како обележано';
$labels['markunflagged'] = 'Како необележано';
$labels['moreactions'] = 'Повекје акции...';
$labels['markallread'] = 'Означи ги сите како прочитани ';
$labels['folders-cur'] = 'Означи ја само папката ';
$labels['folders-sub'] = 'Означи ја папката и нејзините подпапки ';
$labels['folders-all'] = 'Сите папки';
$labels['more'] = 'Повеќе';
$labels['back'] = 'Назад';
$labels['options'] = 'Опции ';
$labels['first'] = 'Прво';
$labels['last'] = 'Последно';
$labels['previous'] = 'Претходно';
$labels['next'] = 'Следно';
$labels['select'] = 'Одбери';
$labels['all'] = 'Сите';
$labels['none'] = 'Ниедно';
$labels['currpage'] = 'Моменталната страница';
$labels['isread'] = 'Читај';
$labels['unread'] = 'Непрочитани';
$labels['flagged'] = 'Обележано';
$labels['unflagged'] = 'Не обележано';
$labels['unanswered'] = 'Неодговорено';
$labels['withattachment'] = 'Со додатоци';
$labels['deleted'] = 'Избришано';
$labels['undeleted'] = 'Не избришано ';
$labels['replied'] = 'Одговорено';
$labels['forwarded'] = 'Препратено';
$labels['invert'] = 'Обратно';
$labels['filter'] = 'Филтер';
$labels['list'] = 'Листа ';
$labels['threads'] = 'Теми ';
$labels['expand-all'] = 'Прошири ги сите ';
$labels['expand-unread'] = 'Прошири ги непрочитаните ';
$labels['collapse-all'] = 'Намали ги сите ';
$labels['threaded'] = 'Навојни ';
$labels['autoexpand_threads'] = 'Прошири ги теми пораките ';
$labels['do_expand'] = 'сите теми ';
$labels['expand_only_unread'] = 'само со непрочитани теми ';
$labels['fromto'] = 'Од/до ';
$labels['flag'] = 'Облежи';
$labels['attachment'] = 'Прилог';
$labels['nonesort'] = 'Ниедно';
$labels['sentdate'] = 'Дата на праќање ';
$labels['arrival'] = 'Дата на пристигање ';
$labels['asc'] = 'Растечки';
$labels['desc'] = 'Опаѓачки';
$labels['listcolumns'] = 'Список со колони ';
$labels['listsorting'] = 'Сортирање колони';
$labels['listorder'] = 'Ред на сортирање ';
$labels['listmode'] = 'Начин на преглед - листа ';
$labels['layout'] = 'Распоред ';
$labels['layoutwidescreen'] = 'Широк екран';
$labels['layoutdesktop'] = 'Работната површина';
$labels['layoutlist'] = 'Список';
$labels['folderactions'] = 'Акции на папка ';
$labels['compact'] = 'Компактно';
$labels['empty'] = 'Испразни';
$labels['importmessages'] = 'Внеси пораки';
$labels['quota'] = 'Искористен простор';
$labels['unknown'] = 'непознато';
$labels['unlimited'] = 'неограничено';
$labels['quotatype'] = 'Тип на квота ';
$labels['quotatotal'] = 'Лимит';
$labels['quotaused'] = 'Користени';
$labels['quotastorage'] = 'Простор на дискот';
$labels['quotamessage'] = 'Број пораки';
$labels['quicksearch'] = 'Брзо пребарување';
$labels['resetsearch'] = 'Ново пребарување';
$labels['searchmod'] = 'Модификатори на пребарувањето';
$labels['msgtext'] = 'Цело писмо';
$labels['body'] = 'Тело';
$labels['type'] = 'Тип';
$labels['namex'] = 'Име';
$labels['searchscope'] = 'Опсег';
$labels['currentfolder'] = 'Моментална папка ';
$labels['subfolders'] = 'Ова ги затвара подпапките ';
$labels['allfolders'] = 'Сите под папки ';
$labels['searchinterval-1W'] = 'постари од една недела ';
$labels['searchinterval-1M'] = 'постари од еден месец ';
$labels['searchinterval-1Y'] = 'постари од една година ';
$labels['searchinterval1W'] = 'помлади од една недела ';
$labels['searchinterval1M'] = 'помлади од еден месец ';
$labels['searchinterval1Y'] = 'помлади од една година ';
$labels['openinextwin'] = 'Отвори во нов прозорец';
$labels['emlsave'] = 'Преземи (.eml)';
$labels['changeformattext'] = 'Прикажи во обичен формат на текс ';
$labels['changeformathtml'] = 'Прикажи во HTML формат';
$labels['editasnew'] = 'Уреди како ново';
$labels['send'] = 'Прати';
$labels['sendmessage'] = 'Испрати сега';
$labels['savemessage'] = 'Зачувај го писмото во Непратени';
$labels['addattachment'] = 'Приложи податотека';
$labels['charset'] = 'Збир од знаци';
$labels['editortype'] = 'Тип на уредник';
$labels['returnreceipt'] = 'Врати';
$labels['dsn'] = 'известување за статусот на испорака';
$labels['mailreplyintro'] = 'На $дата,$праќач напиша:';
$labels['originalmessage'] = 'Оригинална порака';
$labels['selectimage'] = 'Селектирај слика ';
$labels['addimage'] = 'Додај слика ';
$labels['selectmedia'] = 'Селектирај филм';
$labels['addmedia'] = 'Додај филм ';
$labels['encrypt'] = 'Енкриптирај ';
$labels['encryptmessage'] = 'Енкриптирај порака ';
$labels['encryptmessagemailvelope'] = 'Енкриптирај порака  со Mailvelope ';
$labels['importpubkeys'] = 'Внеси јавни клучови ';
$labels['encryptedsendialog'] = 'Праќање енкриптирана порака ';
$labels['keyid'] = 'Клуч ID';
$labels['keylength'] = 'Битови ';
$labels['keyexpired'] = 'Истечено';
$labels['keyrevoked'] = 'Отповикан';
$labels['bccinstead'] = 'Користи Bcc';
$labels['insert'] = 'Внеси ';
$labels['recipient'] = 'Примач';
$labels['editidents'] = 'Уреди идентитети ';
$labels['spellcheck'] = 'Правопис';
$labels['checkspelling'] = 'Провери правопис';
$labels['resumeediting'] = 'Продолжи со уредување';
$labels['revertto'] = 'Врати на';
$labels['restore'] = 'Врати';
$labels['restoremessage'] = 'Врати порака?';
$labels['ignore'] = 'Игнорирај';
$labels['responses'] = 'Одговори';
$labels['insertresponse'] = 'Внеси одговор';
$labels['manageresponses'] = 'Менаџирај одговор';
$labels['newresponse'] = 'Создај нов одговор';
$labels['addresponse'] = 'додај одговор';
$labels['editresponse'] = 'Уреди одговор';
$labels['editresponses'] = 'Уреди одговори ';
$labels['responsename'] = 'Име ';
$labels['responsetext'] = 'Текст за одговор';
$labels['attach'] = 'Прикчи ';
$labels['attachments'] = 'Приложено';
$labels['upload'] = 'Подигни';
$labels['uploadprogress'] = '$процент($моментално од $вкупно)';
$labels['close'] = 'Затвори';
$labels['messageoptions'] = 'Опции на порака ';
$labels['togglecomposeoptions'] = 'Вклучи ги опциите за состав';
$labels['attachmentrename'] = 'Преименувај приврзување';
$labels['low'] = 'Низок';
$labels['lowest'] = 'Најнизок';
$labels['normal'] = 'Нормален';
$labels['high'] = 'Висок';
$labels['highest'] = 'Највисок';
$labels['nosubject'] = '(без наслов)';
$labels['showimages'] = 'Прикажи слики';
$labels['alwaysshow'] = 'Секогаш прикажувај ги сликите од $sender';
$labels['isdraft'] = 'Ова е нацрт-порака.';
$labels['andnmore'] = '$nr повеќе...';
$labels['togglemoreheaders'] = 'Прикажи повеќе заглавија на пораки';
$labels['togglefullheaders'] = 'Вклучи необработени заглавја на пораки ';
$labels['htmltoggle'] = 'HTML';
$labels['plaintoggle'] = 'Обичен текст';
$labels['savesentmessagein'] = 'Сними го пратеното писмо во';
$labels['dontsave'] = 'не зачувувај';
$labels['maxuploadsize'] = 'Максималната дозволена големина за податотеката е $size';
$labels['addcc'] = 'Додај Cc';
$labels['addbcc'] = 'Додај Bcc';
$labels['addreplyto'] = 'Додај Одговори-на';
$labels['addfollowupto'] = 'Додај следење-до';
$labels['mdnrequest'] = 'Праќачот на оваа порака сака да биде известен кога ќе го прочитате писмото. Дали сакате да го известите?';
$labels['receiptread'] = 'Извести (прочитано)';
$labels['yourmessage'] = 'Ова е известување за вашата порака';
$labels['receiptnote'] = 'Напомена: Ова известување само потврдува дека писмото кое сте го пратиле е отворено. Не е гаранција дека примачот го прочитал или разбрал истото.';
$labels['name'] = 'Име за приказ';
$labels['firstname'] = 'Име';
$labels['surname'] = 'Презиме';
$labels['middlename'] = 'Средно име ';
$labels['nameprefix'] = 'Префикс ';
$labels['namesuffix'] = 'Суфикс ';
$labels['nickname'] = 'Прекар';
$labels['jobtitle'] = 'Назив на работа ';
$labels['department'] = 'Оддел';
$labels['gender'] = 'Пол';
$labels['maidenname'] = 'Моминско име';
$labels['email'] = 'Е-пошта';
$labels['phone'] = 'Телефон';
$labels['address'] = 'Адреса ';
$labels['street'] = 'Улица ';
$labels['locality'] = 'Град ';
$labels['zipcode'] = 'Поштенски код';
$labels['region'] = 'Држава / Провинција';
$labels['country'] = 'Земја';
$labels['birthday'] = 'Роденден';
$labels['anniversary'] = 'Годишнина';
$labels['website'] = 'Веб страна ';
$labels['instantmessenger'] = 'ИМ';
$labels['notes'] = 'Белешки';
$labels['male'] = 'Машки';
$labels['female'] = 'Зенски';
$labels['manager'] = 'Менаџер';
$labels['assistant'] = 'Асистент ';
$labels['spouse'] = 'Сопруг';
$labels['allfields'] = 'Сите полиња ';
$labels['search'] = 'Барај';
$labels['searchresult'] = 'Резултати од пребарување ';
$labels['advsearch'] = 'Напредно Пребарување';
$labels['advanced'] = 'Напредно';
$labels['other'] = 'Друго';
$labels['printcontact'] = 'Испринтај контакт ';
$labels['qrcode'] = 'QR Код';
$labels['typehome'] = 'Дома';
$labels['typework'] = 'Работа';
$labels['typeother'] = 'Друго';
$labels['typemobile'] = 'Мобилен ';
$labels['typemain'] = 'Главен ';
$labels['typehomefax'] = 'Домашен факс ';
$labels['typeworkfax'] = 'Службен факс ';
$labels['typecar'] = 'Кола ';
$labels['typepager'] = 'Пејџер';
$labels['typevideo'] = 'Видео ';
$labels['typeassistant'] = 'Асистент ';
$labels['typehomepage'] = 'Домашна страна ';
$labels['typeblog'] = 'Блог';
$labels['typeprofile'] = 'Профил ';
$labels['addfield'] = 'Додај поле';
$labels['addcontact'] = 'Додај контакт ';
$labels['editcontact'] = 'Уреди контакт';
$labels['contacts'] = 'Контакти ';
$labels['contactproperties'] = 'Својства ан контакти ';
$labels['contactnameandorg'] = 'Име и организација ';
$labels['personalinfo'] = 'Лични информаци';
$labels['personal'] = 'Лично';
$labels['contactphoto'] = 'Слика на контакт';
$labels['edit'] = 'Уреди';
$labels['cancel'] = 'Откажи';
$labels['save'] = 'Зачувај';
$labels['delete'] = 'Избриши';
$labels['discard'] = 'Отфрли';
$labels['rename'] = 'Преименувај';
$labels['addphoto'] = 'Додај';
$labels['replacephoto'] = 'Замени';
$labels['uploadphoto'] = 'Прикачи слика ';
$labels['newcontact'] = 'Креирај нов контакт ';
$labels['deletecontact'] = 'Избриши ги следните имиња';
$labels['composeto'] = 'Напиши порака за';
$labels['contactsfromto'] = 'Имиња од $from до $to од $count';
$labels['print'] = 'Испечати';
$labels['export'] = 'Извези како';
$labels['exportall'] = 'Премести се ';
$labels['exportsel'] = 'Премести селектирани ';
$labels['exportvcards'] = 'Извези ги контактите во vCard формат';
$labels['newgroup'] = 'Создај нова група ';
$labels['addgroup'] = 'Додај група ';
$labels['grouprename'] = 'Преименувај група ';
$labels['groupdelete'] = 'Ибриши група ';
$labels['groupremoveselected'] = 'Избриши селектирани контакти од групата';
$labels['uponelevel'] = 'Едно ниво горе';
$labels['previouspage'] = 'Прикажи претходна страна';
$labels['firstpage'] = 'Прикажи ја првата страна';
$labels['nextpage'] = 'Прикажи ја следната страна';
$labels['lastpage'] = 'Прикажи ја последната страна';
$labels['group'] = 'Група ';
$labels['groups'] = 'Групи';
$labels['listgroup'] = 'Листа на членови на групата ';
$labels['personaladrbook'] = 'Лични адреси';
$labels['searchsave'] = 'Зачувај пребарување ';
$labels['searchdelete'] = 'Избриши пребарување ';
$labels['import'] = 'Увези';
$labels['importcontacts'] = 'Увези контакти';
$labels['importtarget'] = 'Додај контакти во ';
$labels['importreplace'] = 'Замени го целиот именик';
$labels['importgroups'] = 'Внеси задачи за група ';
$labels['importgroupsall'] = 'Сите (создај групи ако е потребно)';
$labels['importgroupsexisting'] = 'Само за постоечки групи ';
$labels['done'] = 'Завршено';
$labels['settingsfor'] = 'Нагодувања за';
$labels['about'] = 'За ';
$labels['preferences'] = 'Нагодувања';
$labels['userpreferences'] = 'Кориснички нагодувања';
$labels['editpreferences'] = 'Промени кориснички нагодувања';
$labels['identities'] = 'Идентитети';
$labels['manageidentities'] = 'Менаџирај идентитети ';
$labels['newidentity'] = 'Создај нов идентитет ';
$labels['addidentity'] = 'Додај нов идентитет';
$labels['editidentity'] = 'Уреди идентитет';
$labels['preferhtml'] = 'Прикажи во HTML';
$labels['defaultcharset'] = 'Стандарден сет на карактери ';
$labels['htmlmessage'] = 'HTML писмо';
$labels['messagepart'] = 'Дел ';
$labels['digitalsig'] = 'Дигитален потпис ';
$labels['dateformat'] = 'Дата формат ';
$labels['timeformat'] = 'Формат на време ';
$labels['prettydate'] = 'Убави датуми';
$labels['setdefault'] = 'Постави за основно';
$labels['autodetect'] = 'Автоматски';
$labels['language'] = 'Јазик';
$labels['timezone'] = 'Часовна зона';
$labels['pagesize'] = 'Редови по страна';
$labels['signature'] = 'Потпис';
$labels['dstactive'] = 'Промени на времето';
$labels['showinextwin'] = 'Отвори порака во нов прозорец ';
$labels['composeextwin'] = 'Компонирај во нов прозорец';
$labels['htmleditor'] = 'Пиши HTML порака';
$labels['htmlonreply'] = 'на одговор до HTML порака ';
$labels['htmlonreplyandforward'] = 'на препраќање или одговор до HTML порака ';
$labels['htmlsignature'] = 'HTML потпис';
$labels['showemail'] = 'Покажи email адреса со име на екран ';
$labels['previewpane'] = 'Прикажи прозорец за преглед';
$labels['skin'] = 'Модел на изгледот';
$labels['logoutclear'] = 'Исчисти ја Кантата при излез';
$labels['logoutcompact'] = 'Подреди ги примените при излез';
$labels['uisettings'] = 'Кориснички изглед';
$labels['serversettings'] = 'Нагодувања на серверот';
$labels['mailboxview'] = 'Приказ на поштенското сандаче';
$labels['mdnrequests'] = 'Известувања за праќачот';
$labels['askuser'] = 'прашај го корисникот';
$labels['autosend'] = 'испрати автоматски';
$labels['autosendknown'] = 'прати примач до моите контакти, инаку прашај ме ';
$labels['autosendknownignore'] = 'прати примач до моите контакти, инаку игнорирај ';
$labels['ignorerequest'] = 'игнорирај барање ';
$labels['readwhendeleted'] = 'Обележи го писмото како прочитано при бришење';
$labels['flagfordeletion'] = 'Обележи го писмото за бришење наместо да го избришеш';
$labels['skipdeleted'] = 'Не ги прикажувај избришаните писма';
$labels['deletealways'] = 'Ака преместувањето на пораките до ѓубрето не успее, избриши ги ';
$labels['deletejunk'] = 'Дирктно избриши пораки во ѓубре';
$labels['showremoteimages'] = 'Прикажи вметнати слики';
$labels['fromknownsenders'] = 'од познати праќачи';
$labels['always'] = 'секогаш';
$labels['alwaysbutplain'] = 'секогаш, освен при одговарање на обичен текст ';
$labels['showinlineimages'] = 'Прикажи приложени слики под писмото';
$labels['autosavedraft'] = 'Авоматски зачувувај во Непратени';
$labels['everynminutes'] = 'секои $n минути';
$labels['refreshinterval'] = 'Освежи(провери за нови пораки, и сл.)';
$labels['never'] = 'никогаш';
$labels['immediately'] = 'Веднаш';
$labels['messagesdisplaying'] = 'Прикажување на писма';
$labels['messagescomposition'] = 'Пишување на писма';
$labels['mimeparamfolding'] = 'Име на прикачените податотеки';
$labels['2231folding'] = 'Полн RFC 2231 (Thunderbird)';
$labels['miscfolding'] = 'RFC 2047/2231 (MS Outlook)';
$labels['2047folding'] = 'Полн RFC 2047 (друго)';
$labels['force7bit'] = 'Користи MIME кодирање за 8-битни карактери ';
$labels['savelocalstorage'] = "Зачувајте во локалното складирање на прелистувачот (привремено)";
$labels['advancedoptions'] = 'Напредни можности';
$labels['toggleadvancedoptions'] = 'Вклучи напредни опции ';
$labels['focusonnewmessage'] = 'Фокусирај го прозорецот на прелистувачот на новото писмо';
$labels['checkallfolders'] = 'Провери ги сите папки за нови писма';
$labels['defaultfont'] = 'Стандарден фонд на  HTML пораки ';
$labels['mainoptions'] = 'Главни можности';
$labels['browseroptions'] = 'Опции на прелистувач';
$labels['section'] = 'Заглавие';
$labels['maintenance'] = 'Одржување';
$labels['newmessage'] = 'Ново писмо';
$labels['signatureoptions'] = 'Можности за потписот';
$labels['whenreplying'] = 'При одговарање';
$labels['replyempty'] = 'Не ја цитирајте оригиналната порака';
$labels['replytopposting'] = 'новото писмо започни го над оригиналот';
$labels['replytoppostingnoindent'] = 'почни нова порака над цитатот (без вовлекување)';
$labels['replybottomposting'] = 'новото писмо започни го под оригиналот';
$labels['replyremovesignature'] = 'При одговарање отстрани го изворниот потпис од писмото';
$labels['autoaddsignature'] = 'Автоматски додавај потпис';
$labels['newmessageonly'] = 'само нови писма';
$labels['replyandforwardonly'] = 'само одгорови и препраќања';
$labels['insertsignature'] = 'Вметни потпис';
$labels['sigbelow'] = 'Стави потпис под цитираната порака ';
$labels['sigseparator'] = 'Форсирај стандарден одделувач во потписите';
$labels['afternseconds'] = 'после $n секунди ';
$labels['reqmdn'] = 'Секогаш побарај повратна порака ';
$labels['reqdsn'] = 'Секогаш барајте известување за статусот на испорака';
$labels['replysamefolder'] = 'Поставете ги одговорите во папката на пораката на која е одговорено';
$labels['defaultabook'] = 'Стандардна книга на адреси';
$labels['autocompletesingle'] = 'Сконки алтернативни email адреси во автоматско довршување ';
$labels['listnamedisplay'] = 'Листа на контакти како ';
$labels['spellcheckbeforesend'] = 'Провери правопис пред испраќање на порака ';
$labels['spellcheckoptions'] = 'Опции за проверка на правопис';
$labels['spellcheckignoresyms'] = 'Игнорирај зборови со симболи';
$labels['spellcheckignorenums'] = 'Игнорирај зборови со броеви ';
$labels['spellcheckignorecaps'] = 'Игнорирај зборови со сите големи букви';
$labels['addtodict'] = 'Додај во речник';
$labels['mailtoprotohandler'] = 'Регистрирај управувач на протокол за mailto: линкови';
$labels['standardwindows'] = 'Справи се со скокачки прозори како обични прозори ';
$labels['forwardmode'] = 'пораката се препраќа';
$labels['inline'] = 'во линија';
$labels['asattachment'] = 'како додаток';
$labels['replyallmode'] = 'Стандардна акција од [Одговори на сите] копче ';
$labels['replyalldefault'] = 'одговори на сите ';
$labels['replyalllist'] = 'Одговори само на мејлинг листа (ако е пронајдена)';
$labels['allmessages'] = 'Сите пораки ';
$labels['folder'] = 'Папка';
$labels['folders'] = 'Папки';
$labels['foldername'] = 'Име на папката';
$labels['subscribed'] = 'Претплатен';
$labels['messagecount'] = 'Пораки';
$labels['create'] = 'Создај';
$labels['createfolder'] = 'Создај нова папка';
$labels['managefolders'] = 'Организирање на папки';
$labels['specialfolders'] = 'Специјални папки';
$labels['properties'] = 'Својства ';
$labels['folderproperties'] = 'Својства на папка ';
$labels['parentfolder'] = 'Родител папка ';
$labels['location'] = 'Локација ';
$labels['info'] = 'Информација ';
$labels['getfoldersize'] = 'Кликни за да ја добиеш големината на папката';
$labels['changesubscription'] = 'Кликни за да сменисх претплата ';
$labels['foldertype'] = 'Тип на папка ';
$labels['personalfolder'] = 'Приватна папка ';
$labels['otherfolder'] = 'Папка на други корисници';
$labels['sharedfolder'] = 'Јавна папка ';
$labels['findfolders'] = 'Најди папки ';
$labels['namespace.personal'] = 'Лично';
$labels['namespace.other'] = 'Други корисници';
$labels['namespace.shared'] = 'Споделено';
$labels['sortby'] = 'Сортирај по';
$labels['sortasc'] = 'Сортирај нагорно';
$labels['sortdesc'] = 'Сортирај надолно';
$labels['undo'] = 'Врати ';
$labels['installedplugins'] = 'Инсталирани прикличоци ';
$labels['plugin'] = 'Прикличоци ';
$labels['version'] = 'Верзии ';
$labels['source'] = 'Извор';
$labels['license'] = 'Лиценца';
$labels['support'] = 'Добиј подршка ';
$labels['B'] = 'Б';
$labels['KB'] = 'КБ';
$labels['MB'] = 'МБ';
$labels['GB'] = 'ГБ';
$labels['unicode'] = 'Уникод';
$labels['english'] = 'Англиски ';
$labels['westerneuropean'] = 'Западно европски';
$labels['easterneuropean'] = 'Источно европски ';
$labels['southeasterneuropean'] = 'Југо-источно европски';
$labels['baltic'] = 'Балтички ';
$labels['cyrillic'] = 'Кириличен';
$labels['arabic'] = 'Арапски';
$labels['greek'] = 'Грчки';
$labels['hebrew'] = 'Еврејски';
$labels['turkish'] = 'Турски';
$labels['nordic'] = 'Нордиски';
$labels['thai'] = 'Тајландски';
$labels['celtic'] = 'Селтик';
$labels['vietnamese'] = 'Виетнамски';
$labels['japanese'] = 'Јапонски';
$labels['korean'] = 'Корејски';
$labels['chinese'] = 'Кинески';
$labels['arialabeltopnav'] = 'Контрола на прозорец ';
$labels['arialabeltasknav'] = 'Задачи на апликацијата ';
$labels['arialabeltoolbar'] = 'Лента со алатки на апликацијата ';
$labels['arialabelactivetask'] = 'Активни задачи ';
$labels['arialabelmessagessearchfilter'] = 'Филтер за прелистување на е-пошта';
$labels['arialabelmailsearchform'] = 'Форма на пребарување на е-пошта ';
$labels['arialabelcontactsearchform'] = 'Форма на пребарување контакти ';
$labels['arialabelmailquicksearchbox'] = 'Внес на е-пошта пребарување';
$labels['arialabelquicksearchbox'] = 'Пребарување влез';
$labels['arialabelfoldersearchfilter'] = 'Филтер за листата со папки';
$labels['arialabelfoldersearchform'] = 'Форма за пребарување папки ';
$labels['arialabelfolderlist'] = 'Селекција на е-маил папки ';
$labels['arialabelmessagelist'] = 'Листа на пораки за е-пошта';
$labels['arialabelmailpreviewframe'] = 'Преглед на порака';
$labels['arialabelmailboxmenu'] = 'Мени за дејства на папките';
$labels['arialabellistselectmenu'] = 'Мени за избор на листа';
$labels['arialabelthreadselectmenu'] = 'Мени за листа на теми';
$labels['arialabelmessagelistoptions'] = 'Приказ на листа на пораки и опции за сортирање ';
$labels['arialabelmailimportdialog'] = 'Дијалог за внес на порака ';
$labels['arialabelmessagenav'] = 'Навигација за пораки';
$labels['arialabelmessagebody'] = 'Тело на порака';
$labels['arialabelmessageactions'] = 'Акции за порака';
$labels['arialabelcontactquicksearch'] = 'Форма за барање контакти ';
$labels['arialabelcontactsearchbox'] = 'Влез за пребарување контакти ';
$labels['arialabelmessageheaders'] = 'Заглавја на порака ';
$labels['arialabelforwardingoptions'] = 'Опции за препраќање ';
$labels['arialabelreplyalloptions'] = 'Опции за Врати на сите ';
$labels['arialabelmoremessageactions'] = 'Повеке акции за порака ';
$labels['arialabelmarkmessagesas'] = 'Означи ги селектираните пораки како...';
$labels['arialabelcomposeoptions'] = 'Опции за композиција';
$labels['arialabelresponsesmenu'] = 'Мени за одобрени одговори';
$labels['arialabelattachmentuploadform'] = 'Форма за прикачени додатоци ';
$labels['arialabelattachmentpreview'] = 'Преглед на додатоци ';
$labels['ariasummarycomposecontacts'] = 'Листа на контакти и групи  за да се селектираат како примачи  ';
$labels['arialabelcontactexportoptions'] = 'опции за изнес на контакти ';
$labels['arialabelabookgroupoptions'] = 'Опции за Адресар/група';
$labels['arialabelpreferencesform'] = 'Форма на преференции';
$labels['arialabelidentityeditfrom'] = 'Форма за едитирање идентитети ';
$labels['arialabelresponseeditfrom'] = 'Форма за едитирање на одговори ';
$labels['arialabelsearchterms'] = 'Термини за пребарување';
$labels['helplistnavigation'] = 'Листа со навигација на тастатура ';
$labels['helplistkeyboardnavigation'] = "Стрелки горе/доле: Помести фокус на ред/селекција.
Спејс: Селектирај фокусиран ред.
Шифт + горе/доле: Селектирај додатен ред над/под.
Цтрл + Спејс: Додај го фокусираниот ред во селекцијата/тргни го од селекцијата.";
$labels['helplistkeyboardnavmessages'] = "Стрелки десно/лево: прошири/собери теми на порака (само во теми модул).
Ентер: Отвори ја селектираната/фокусираната порака.
Избриши: Премести ја селектираната порака во ѓубрето.";
$labels['helplistkeyboardnavcontacts'] = "Ентер: Отвори го селектираниот/фокусираниот контакт.";
