<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail client                     |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/labels/
*/


$labels['welcome'] = 'Croeso i $product';
$labels['username'] = 'Enw defnyddiwr';
$labels['password'] = 'Cyfrinair';
$labels['server'] = 'Gweinydd';
$labels['login'] = 'Mewngofnodi';
$labels['oauthlogin'] = 'Mewngofnodi gyda $provider';
$labels['menu'] = 'Bwydlen';
$labels['logout'] = 'Allgofnodi';
$labels['mail'] = 'E-bost';
$labels['settings'] = 'Gosodiadau Personol';
$labels['addressbook'] = 'Llyfr Cyfeiriadau';
$labels['darkmode'] = 'Modd tywyll';
$labels['lightmode'] = 'Modd golau';
$labels['inbox'] = 'Mewnflwch';
$labels['drafts'] = 'Drafftiau';
$labels['sent'] = 'Danfonwyd';
$labels['trash'] = 'Sbwriel';
$labels['junk'] = 'Sothach';
$labels['show_real_foldernames'] = 'Dangos enwau go-iawn ar gyfer ffolderi arbennig';
$labels['subject'] = 'Pwnc';
$labels['from'] = 'Oddi wrth';
$labels['sender'] = 'Anfonwr';
$labels['to'] = 'Derbyniwr';
$labels['cc'] = 'Copi';
$labels['bcc'] = 'Bcc';
$labels['replyto'] = 'Ateb-I';
$labels['followupto'] = 'Followup-To';
$labels['date'] = 'Dyddiad';
$labels['size'] = 'Maint';
$labels['priority'] = 'Blaenoriaeth';
$labels['organization'] = 'Enw\'r Sefydliad';
$labels['readstatus'] = 'Statws darllen';
$labels['listoptions'] = 'Dewisiadau rhestr...';
$labels['listoptionstitle'] = 'Dewisiadau rhestr';
$labels['mailboxlist'] = 'Ffolderi';
$labels['messagesfromto'] = 'Negeseuon $from i $to o $count';
$labels['threadsfromto'] = 'Edefau $from i $to o $count';
$labels['messagenrof'] = 'Neges $nr o $count';
$labels['fromtoshort'] = '$from - $to o $count';
$labels['copy'] = 'Copio';
$labels['move'] = 'Symud';
$labels['moveto'] = 'Symud i...';
$labels['copyto'] = 'Copio i...';
$labels['download'] = 'Lawrlwytho';
$labels['open'] = 'Agor';
$labels['showattachment'] = 'Dangos';
$labels['showanyway'] = 'Dangos beth bynnag';
$labels['filename'] = 'Enw ffeil';
$labels['filesize'] = 'Maint ffeil';
$labels['addtoaddressbook'] = 'Ychwanegu i\'r llyfr cyfeiriadau';
$labels['sun'] = 'Sul';
$labels['mon'] = 'Llun';
$labels['tue'] = 'Maw';
$labels['wed'] = 'Mer';
$labels['thu'] = 'Iau';
$labels['fri'] = 'Gwe';
$labels['sat'] = 'Sad';
$labels['sunday'] = 'Dydd Sul';
$labels['monday'] = 'Dydd Llun';
$labels['tuesday'] = 'Dydd Mawrth';
$labels['wednesday'] = 'Dydd Mercher';
$labels['thursday'] = 'Dydd Iau';
$labels['friday'] = 'Dydd Gwener';
$labels['saturday'] = 'Dydd Sadwrn';
$labels['jan'] = 'Ion';
$labels['feb'] = 'Chwe';
$labels['mar'] = 'Maw';
$labels['apr'] = 'Ebr';
$labels['may'] = 'Mai';
$labels['jun'] = 'Meh';
$labels['jul'] = 'Gor';
$labels['aug'] = 'Aws';
$labels['sep'] = 'Med';
$labels['oct'] = 'Hyd';
$labels['nov'] = 'Tach';
$labels['dec'] = 'Rhag';
$labels['longjan'] = 'Ionawr';
$labels['longfeb'] = 'Chwefror';
$labels['longmar'] = 'Mawrth';
$labels['longapr'] = 'Ebrill';
$labels['longmay'] = 'Mai';
$labels['longjun'] = 'Mehefin';
$labels['longjul'] = 'Gorffennaf';
$labels['longaug'] = 'Awst';
$labels['longsep'] = 'Medi';
$labels['longoct'] = 'Hydref';
$labels['longnov'] = 'Tachwedd';
$labels['longdec'] = 'Rhagfyr';
$labels['today'] = 'Heddiw';
$labels['refresh'] = 'Ail-ofyn';
$labels['checkmail'] = 'Edrych am negeseuon newydd';
$labels['compose'] = 'Ysgrifennu neges';
$labels['writenewmessage'] = 'Creu neges newydd';
$labels['reply'] = 'Ymateb';
$labels['replytomessage'] = 'Ymateb i\'r anfonwr';
$labels['replytoallmessage'] = 'Ymateb i\'r anfonwr a phob derbyniwr';
$labels['replyall'] = 'Ymateb i bawb';
$labels['replylist'] = 'Ymateb i\'r rhestr';
$labels['forward'] = 'Anfon ymlaen';
$labels['forwardinline'] = 'Anfon ymlaen o fewn y neges';
$labels['forwardattachment'] = 'Anfon ymlaen fel atodiad';
$labels['forwardmessage'] = 'Danfon y neges ymlaen';
$labels['bouncemsg'] = 'Ail-anfon (bowns)';
$labels['bounce'] = 'Ail-anfon';
$labels['deletemessage'] = 'Dileu\'r neges';
$labels['movemessagetotrash'] = 'Symud y neges i\'r sbwriel';
$labels['printmessage'] = 'Argraffu\'r neges';
$labels['previousmessage'] = 'Dangos y neges flaenorol';
$labels['firstmessage'] = 'Dangos y neges gyntaf';
$labels['nextmessage'] = 'Dangos y neges nesaf';
$labels['lastmessage'] = 'Dangos y neges olaf';
$labels['backtolist'] = 'Nôl i\'r rhestr o negeseuon';
$labels['viewsource'] = 'Edrych ar y ffynhonnell';
$labels['mark'] = 'Nodi';
$labels['markmessages'] = 'Nodi\'r negeseuon';
$labels['markread'] = 'Wedi eu darllen';
$labels['markunread'] = 'Heb eu darllen';
$labels['markflagged'] = 'Wedi eu fflagio';
$labels['markunflagged'] = 'Heb eu fflagio';
$labels['markundeleted'] = 'Fel heb ei ddileu';
$labels['moreactions'] = 'Mwy o weithredoedd...';
$labels['markallread'] = 'Nodi pob un wedi ei ddarllen';
$labels['folders-cur'] = 'Ffolder dewiswyd yn unig';
$labels['folders-sub'] = 'Ffolder dewiswyd a\'i isffolderi';
$labels['folders-all'] = 'Pob ffolder';
$labels['more'] = 'Mwy';
$labels['back'] = 'Yn ôl';
$labels['options'] = 'Dewisiadau';
$labels['composeoptions'] = 'Dewisiadau ysgrifennu';
$labels['optionsandattachments'] = 'Dewisiadau ac atodiadau';
$labels['actions'] = 'Gweithredoedd';
$labels['first'] = 'Cyntaf';
$labels['last'] = 'Olaf';
$labels['previous'] = 'Blaenorol';
$labels['next'] = 'Nesaf';
$labels['select'] = 'Dewis';
$labels['selection'] = 'Dewis';
$labels['all'] = 'Popeth';
$labels['none'] = 'Dim';
$labels['currpage'] = 'Tudalen gyfredol';
$labels['isread'] = 'Darllenwyd';
$labels['unread'] = 'Heb eu darllen';
$labels['flagged'] = 'Nodwyd';
$labels['unflagged'] = 'Heb eu Fflagio';
$labels['unanswered'] = 'Heb ei ateb';
$labels['withattachment'] = 'Gyda atodiad';
$labels['deleted'] = 'Dilewyd';
$labels['undeleted'] = 'Heb ei ddileu';
$labels['replied'] = 'Ymatebwyd';
$labels['forwarded'] = 'Anfonwyd ymlaen';
$labels['invert'] = 'Gwrth-droi';
$labels['filter'] = 'Hidlo';
$labels['list'] = 'Rhestr';
$labels['threads'] = 'Edafedd';
$labels['expand-all'] = 'Ehangu Popeth';
$labels['expand-unread'] = 'Ehangu Negeseuon Heb eu darllen';
$labels['collapse-all'] = 'Crebachu Popeth';
$labels['threaded'] = 'Edafedd';
$labels['showunread'] = 'Dangos negeseuon heb eu darllen';
$labels['autoexpand_threads'] = 'Ehangu edefau neges';
$labels['do_expand'] = 'pob edefyn';
$labels['expand_only_unread'] = 'dim ond gyda negeseuon heb eu darllen';
$labels['fromto'] = 'Danfonwr/Derbynnydd';
$labels['flag'] = 'Fflag';
$labels['attachment'] = 'Atodiad';
$labels['nonesort'] = 'Dim';
$labels['sentdate'] = 'Dyddiad danfon';
$labels['arrival'] = 'Dyddiad derbyn';
$labels['asc'] = 'esgynnol';
$labels['desc'] = 'disgynnol';
$labels['listcolumns'] = 'Rhestr colofnau';
$labels['listsorting'] = 'Colofn trefnu';
$labels['listorder'] = 'Trefn didoli';
$labels['listmode'] = 'Golwg rhestr';
$labels['lmode'] = 'Golwg rhestr';
$labels['layout'] = 'Cynllun';
$labels['layoutwidescreen'] = 'Sgrîn lydan';
$labels['layoutdesktop'] = 'Pen bwrdd';
$labels['layoutlist'] = 'Rhestr';
$labels['layoutwidescreendesc'] = 'Sgrîn lydan (golwg 3 colofn)';
$labels['layoutdesktopdesc'] = 'Pen-bwrdd (rhestr lydan a rhagolwg isod)';
$labels['layoutlistdesc'] = 'Rhestr (dim rhagolwg)';
$labels['folderactions'] = 'Gweithredoedd ffolder...';
$labels['compact'] = 'Crynhoi';
$labels['empty'] = 'Gwagio';
$labels['importmessages'] = 'Mewnforio negeseuon';
$labels['mailimportdesc'] = 'Fe allwch chi lwytho fyny ffeiliau ebost mewn fformat <a href="https://en.wikipedia.org/wiki/Email#Message_format">MIME</a> neu <a href="https://en.wikipedia.org/wiki/Mbox">Mbox</a>';
$labels['mailimportzip'] = 'Gellir cywasgu nifer o ffeiliau mewn i archif zip.';
$labels['quota'] = 'Defnydd';
$labels['unknown'] = 'anhysbys';
$labels['unlimited'] = 'diderfyn';
$labels['quotatype'] = 'Math Cwota';
$labels['quotatotal'] = 'Cyfyngiad';
$labels['quotaused'] = 'Defnyddiwyd';
$labels['quotastorage'] = 'Gofod disg';
$labels['quotamessage'] = 'Nifer negeseuon';
$labels['shortheaderdate'] = 'Ar $date';
$labels['shortheaderto'] = 'I $to ar $date';
$labels['shortheaderfrom'] = 'O $from i $date';
$labels['quicksearch'] = 'Chwiliad cyflym';
$labels['searchplaceholder'] = 'Chwilio...';
$labels['resetsearch'] = 'Ail-osod chwiliad';
$labels['searchmod'] = 'Addasyddion chwilio';
$labels['msgtext'] = 'Y neges yn llawn';
$labels['body'] = 'Corff';
$labels['type'] = 'Math';
$labels['namex'] = 'Enw';
$labels['searchscope'] = 'Amrediad';
$labels['currentfolder'] = 'Ffolder cyfredol';
$labels['subfolders'] = 'Hwn a is-ffolderi';
$labels['allfolders'] = 'Pob ffolder';
$labels['searchinterval-1W'] = 'hynach na wythnos';
$labels['searchinterval-1M'] = 'hynach na mis';
$labels['searchinterval-1Y'] = 'hynach na blwyddyn';
$labels['searchinterval1W'] = 'ifancach na wythnos';
$labels['searchinterval1M'] = 'ifancach na mis';
$labels['searchinterval1Y'] = 'ifancach na blwyddyn';
$labels['openinextwin'] = 'Agor mewn ffenest newydd';
$labels['emlsave'] = 'Lawrlwytho (.eml)';
$labels['changeformattext'] = 'Dangos mewn fformat testun plaen';
$labels['changeformathtml'] = 'Dangos mewn fformat HTML';
$labels['editasnew'] = 'Golygu fel neges newydd';
$labels['send'] = 'Anfon';
$labels['sendmessage'] = 'Anfon nawr';
$labels['savemessage'] = 'Cadw\'r drafft hwn';
$labels['addattachment'] = 'Atodi ffeil';
$labels['charset'] = 'Set nodiau';
$labels['editortype'] = 'Math golygydd';
$labels['returnreceipt'] = 'Cadarnhau derbyn';
$labels['dsn'] = 'Hysbysiad statws danfon';
$labels['keepformatting'] = 'Cadw\'r fformatio';
$labels['mailreplyintro'] = 'Ar $date, ysgrifennodd $sender:';
$labels['originalmessage'] = 'Neges Wreiddiol';
$labels['selectimage'] = 'Dewiswch lun';
$labels['addimage'] = 'Ychwanegwch lun';
$labels['selectmedia'] = 'Dewiswch fideo';
$labels['addmedia'] = 'Ychwanegwch fideo';
$labels['encrypt'] = 'Amgryptio';
$labels['encryptmessage'] = 'Amgryptio neges';
$labels['encryptmessagemailvelope'] = 'Amgryption neges gyda Mailvelope';
$labels['importpubkeys'] = 'Mewnforio allweddi cyhoeddus';
$labels['encryptedsendialog'] = 'Anfon neges wedi amgryptio';
$labels['encryptandsign'] = 'Amgodi ac arwyddo';
$labels['keyid'] = 'ID Allwedd';
$labels['keylength'] = 'Didiau';
$labels['keyexpired'] = 'Wedi darfod';
$labels['keyrevoked'] = 'Wedi dirymu';
$labels['bccinstead'] = 'Defnyddio Bcc';
$labels['addheader'] = 'Ychwanegu derbynnydd (pennawd)';
$labels['insert'] = 'Mewnosod';
$labels['insertcontact'] = 'Mewnosod cyswllt/cysylltiadau';
$labels['recipient'] = 'Derbynnwr';
$labels['recipientedit'] = 'Golygu derbynnydd';
$labels['editidents'] = 'Golygu personoliaethau';
$labels['spellcheck'] = 'Sillafu';
$labels['checkspelling'] = 'Gwirio sillafu';
$labels['resumeediting'] = 'Ail-ddechrau golygu';
$labels['revertto'] = 'Dychwelyd i';
$labels['restore'] = 'Adfer';
$labels['restoremessage'] = 'Adfer neges?';
$labels['ignore'] = 'Anwybyddu';
$labels['responses'] = 'Ymatebion';
$labels['insertresponse'] = 'Mewnosod ymateb';
$labels['manageresponses'] = 'Rheoli ymatebion';
$labels['newresponse'] = 'Cadw ymateb newydd';
$labels['addresponse'] = 'Ychwanegu ymateb';
$labels['editresponse'] = 'Golygu ymateb';
$labels['editresponses'] = 'Golygu ymatebion';
$labels['responsename'] = 'Enw';
$labels['responsetext'] = 'Testun Ymateb';
$labels['attach'] = 'Atodi';
$labels['attachments'] = 'Atodiadau';
$labels['upload'] = 'Lanlwytho';
$labels['uploadprogress'] = '$percent ($current o $total)';
$labels['close'] = 'Cau';
$labels['messageoptions'] = 'Dewisiadau neges...';
$labels['togglecomposeoptions'] = 'Newid dewisiadau ysgrifennu';
$labels['attachmentrename'] = 'Ailenwi atodiad';
$labels['low'] = 'Isel';
$labels['lowest'] = 'Isaf';
$labels['normal'] = 'Cyffredin';
$labels['high'] = 'Uchel';
$labels['highest'] = 'Uchaf';
$labels['nosubject'] = '(dim pwnc)';
$labels['showimages'] = 'Dangos lluniau';
$labels['allow'] = 'Caniatau';
$labels['alwaysshow'] = 'Dangos lluniau bob amser o $sender';
$labels['alwaysallow'] = 'Caniatau bob amser o $sender';
$labels['isdraft'] = 'Mae hwn yn neges ddrafft';
$labels['andnmore'] = '$nr mwy...';
$labels['details'] = 'Manylion';
$labels['summary'] = 'Crynodeb';
$labels['headers'] = 'Penawdau';
$labels['allheaders'] = 'Pob pennawd...';
$labels['togglemoreheaders'] = 'Dangos fwy o benynnau\'r neges';
$labels['togglefullheaders'] = 'Toglo penawdau llawn y neges';
$labels['htmltoggle'] = 'HTML';
$labels['plaintoggle'] = 'Testun plaen';
$labels['savesentmessagein'] = 'Cadw negeseuon a ddanfonir yn';
$labels['dontsave'] = 'peidio cadw';
$labels['maxuploadsize'] = 'Y maint ffeil uchaf a ganiateir yw $size';
$labels['addcc'] = 'Ychwanegu Cc';
$labels['addbcc'] = 'Ychwanegu Bcc';
$labels['addreplyto'] = 'Ychwanegu Ateb-I';
$labels['addfollowupto'] = 'Ychwanegu Followup-To';
$labels['sendreceipt'] = 'Danfon hysbysiad derbyn?';
$labels['mdnrequest'] = 'Mae anfonwr y neges hwn wedi gofyn am hysbysiad eich bod wedi darllen y neges. Hoffech chi hysbysu\'r anfonwr?';
$labels['receiptread'] = 'Cadarnhad Derbyn (darllenwyd)';
$labels['yourmessage'] = 'Mae hwn yn gadarnhad o dderbyn eich neges';
$labels['receiptnote'] = 'Nodyn: Mae\'r cadarnhad hwn yn cydnabod fod y neges wedi ei ddangos ar gyfrifiadur y derbynnydd. \'Does dim sicrwydd fod y derbynydd wedi darllen neu ddeall cynnwys y neges.';
$labels['sendalwaysto'] = 'Danfon bob amser i $email';
$labels['zoomin'] = 'Chwyddo Mewn';
$labels['zoomout'] = 'Chwyddo Allan';
$labels['rotate'] = 'Cylchdroi';
$labels['increaseimage'] = 'Cynyddu maint delwedd';
$labels['decreaseimage'] = 'Lleihau maint delwedd';
$labels['rotateimage'] = 'Cylchdroi delwedd';
$labels['showtools'] = 'Dangos teclynnau delwedd';
$labels['hidetools'] = 'Cuddio teclynnau delwedd';
$labels['name'] = 'Enw ddangosir';
$labels['firstname'] = 'Enw cyntaf';
$labels['surname'] = 'Enw olaf';
$labels['middlename'] = 'Enw Canol';
$labels['nameprefix'] = 'Rhagddodiad';
$labels['namesuffix'] = 'Olddodiad';
$labels['nickname'] = 'Llysenw';
$labels['jobtitle'] = 'Teitl Swydd';
$labels['department'] = 'Adran';
$labels['gender'] = 'Rhyw';
$labels['maidenname'] = 'Enw cyn priodi';
$labels['email'] = 'E-bost';
$labels['phone'] = 'Ffôn';
$labels['address'] = 'Cyfeiriad';
$labels['street'] = 'Stryd';
$labels['locality'] = 'Tref/Dinas';
$labels['zipcode'] = 'Côd Post/ZIP';
$labels['region'] = 'Sîr/Talaith';
$labels['country'] = 'Gwlad';
$labels['birthday'] = 'Penblwydd';
$labels['anniversary'] = 'Cylchwyl';
$labels['website'] = 'Gwefan';
$labels['instantmessenger'] = 'IM';
$labels['notes'] = 'Nodiadau';
$labels['male'] = 'gwryw';
$labels['female'] = 'benyw';
$labels['manager'] = 'Rheolwr';
$labels['assistant'] = 'Cynorthwyydd';
$labels['spouse'] = 'Cymar';
$labels['allfields'] = 'Pob maes';
$labels['search'] = 'Chwilio';
$labels['searchresult'] = 'Canlyniadau chwilio';
$labels['advsearch'] = 'Chwilio Uwch';
$labels['advanced'] = 'Uwch';
$labels['other'] = 'Arall';
$labels['printcontact'] = 'Cyswllt argraffu';
$labels['qrcode'] = 'Cod QR';
$labels['typehome'] = 'Cartref';
$labels['typework'] = 'Gwaith';
$labels['typeother'] = 'Arall';
$labels['typemobile'] = 'Symudol';
$labels['typemain'] = 'Prif';
$labels['typehomefax'] = 'Ffacs Adref';
$labels['typeworkfax'] = 'Ffacs Gwaith';
$labels['typecar'] = 'Car';
$labels['typepager'] = 'Peiriant Galw';
$labels['typevideo'] = 'Fideo';
$labels['typeassistant'] = 'Cynorthwyydd';
$labels['typehomepage'] = 'Gwefan';
$labels['typeblog'] = 'Blog';
$labels['typeprofile'] = 'Proffil';
$labels['addfield'] = 'Ychwanegu maes...';
$labels['addcontact'] = 'Ychwanegu cyswllt';
$labels['editcontact'] = 'Golygu cyswllt';
$labels['contacts'] = 'Cysylltiadau';
$labels['contactproperties'] = 'Nodweddion cyswllt';
$labels['contactnameandorg'] = 'Enw a Corff';
$labels['personalinfo'] = 'Gwybodaeth bersonol';
$labels['personal'] = 'Persono';
$labels['contactphoto'] = 'Llun cyswllt';
$labels['edit'] = 'Golygu';
$labels['cancel'] = 'Canslo';
$labels['save'] = 'Cadw';
$labels['delete'] = 'Dileu';
$labels['discard'] = 'Gwaredu';
$labels['continue'] = 'Parhau';
$labels['ok'] = 'Iawn';
$labels['rename'] = 'Ail-enwi';
$labels['addphoto'] = 'Ychwanegu';
$labels['replacephoto'] = 'Amnewid';
$labels['uploadphoto'] = 'Lanlwytho llun';
$labels['choosefile'] = 'Dewis ffeil...';
$labels['choosefiles'] = 'Dewis ffeiliau...';
$labels['browse'] = 'Pori';
$labels['newcontact'] = 'Creu cyswllt newydd';
$labels['deletecontact'] = 'Dileu y cysylltiadau a ddewiswyd';
$labels['composeto'] = 'Ysgrifennu neges at';
$labels['contactsfromto'] = 'Cysylltiadau $from i $to o $count';
$labels['print'] = 'Argraffu';
$labels['export'] = 'Allforio';
$labels['exportall'] = 'Allforio popeth';
$labels['exportsel'] = 'Allforio dewiswyd';
$labels['exportvcards'] = 'Allforio cysylltiadau mewn fformat vCard';
$labels['newgroup'] = 'Creu grŵp newydd';
$labels['addgroup'] = 'Ychwanegu grŵp';
$labels['grouprename'] = 'Ail-enwi grŵp';
$labels['groupdelete'] = 'Dileu grŵp';
$labels['groupassign'] = 'Ychwanegu i\'r grŵp...';
$labels['groupremove'] = 'Tynnu o\'r grŵp';
$labels['groupremoveselected'] = 'Dileu y cysylltiadau dewiswyd o\'r grŵp';
$labels['uponelevel'] = 'Fyny un lefel';
$labels['previouspage'] = 'Dangos y set flaenorol';
$labels['firstpage'] = 'Dangos y set gyntaf';
$labels['nextpage'] = 'Dangos y set nesaf';
$labels['lastpage'] = 'Dangos y set olaf';
$labels['group'] = 'Grŵp';
$labels['groups'] = 'Grwpiau';
$labels['listgroup'] = 'Rhestru aelodau\'r grŵp';
$labels['personaladrbook'] = 'Cyfeiriadau Personol';
$labels['searchsave'] = 'Cadw chwiliad';
$labels['searchdelete'] = 'Dileu chwiliad';
$labels['import'] = 'Mewnforio';
$labels['importcontacts'] = 'Mewnforio cysylltiadau';
$labels['importfromfile'] = 'Mewnforio o ffeil';
$labels['importtarget'] = 'Ychwanegu cysylltiadau i';
$labels['importreplace'] = 'Dileu y llyfr cyfeiriadau cyfan wrth lwytho';
$labels['importgroups'] = 'Mewnforio penodiadau grŵp';
$labels['importgroupsall'] = 'Holl (creu grwpiau os oes angen)';
$labels['importgroupsexisting'] = 'Dim ond ar gyfer grwpiau sy\'n bodoli';
$labels['importdesc'] = 'Gallwch lwytho fyny cysylltiadau o lyfr cyfeiriadau blaenorol. <br/>Ar hyn o bryd rydym yn cefnogi mewnforio cyfeiriadau o\'r fformatau data <a href="https://en.wikipedia.org/wiki/VCard">vCard</a> neu CSV (comma-separated)';
$labels['importmapdesc'] = 'Cadarnhewch fod y wybodaeth mapio meysydd isod yn gywir cyn parhau gyda mewnforio data CSV.';
$labels['fieldnotmapped'] = 'Ni fapiwyd y maes (peidio mewnforio)';
$labels['skipheader'] = 'Peidio mewnforio\'r llinell gyntaf (pennawdau)';
$labels['done'] = 'Wedi gorffen';
$labels['settingsfor'] = 'Gosodiadau ar gyfer';
$labels['about'] = 'Amdan';
$labels['preferences'] = 'Dewisiadau';
$labels['userpreferences'] = 'Dewisiadau\'r defnyddiwr';
$labels['editpreferences'] = 'Golygu dewisiadau\'r defnyddiwr';
$labels['identities'] = 'Personoliaethau';
$labels['manageidentities'] = 'Rheoli personoliaethau';
$labels['newidentity'] = 'Creu personoliaeth newydd';
$labels['addidentity'] = 'Ychwanegu personoliaeth';
$labels['editidentity'] = 'Golygu personoliaeth';
$labels['identityencryption'] = 'Amgryptiad';
$labels['preferhtml'] = 'Dangos HTML';
$labels['defaultcharset'] = 'Set Nodau Diofyn';
$labels['htmlmessage'] = 'Neges HTML';
$labels['messagepart'] = 'Rhan';
$labels['digitalsig'] = 'Llofnod Digidol';
$labels['dateformat'] = 'Fformat dyddiad';
$labels['timeformat'] = 'Fformat amser';
$labels['prettydate'] = 'Dyddiadau pert';
$labels['setdefault'] = 'Rhagosod';
$labels['autodetect'] = 'Awto';
$labels['language'] = 'Iaith';
$labels['timezone'] = 'Parth amser';
$labels['pagesize'] = 'Rhesi ar bob tudalen';
$labels['signature'] = 'Llofnod';
$labels['dstactive'] = 'Amser arbed golau ddydd';
$labels['showinextwin'] = 'Agor neges mewn ffenest newydd';
$labels['composeextwin'] = 'Ysgrifennu mewn ffenest newydd';
$labels['htmleditor'] = 'Ysgrifennu negeseuon HTML';
$labels['htmlonreply'] = 'wrth ateb i neges HTML yn unig';
$labels['htmlonreplyandforward'] = 'wrth ddanfon ymlaen neu ymateb i neges HTML';
$labels['htmlsignature'] = 'Llofnod HTML';
$labels['showemail'] = 'Dangos cyfeiriad ebost gyda\'r enw gweledig';
$labels['previewpane'] = 'Dangos ffenest rhagolwg';
$labels['skin'] = 'Croen rhyngwyneb';
$labels['logoutclear'] = 'Clirio\'r Sbwriel wrth allgofnodi';
$labels['logoutcompact'] = 'Crynhoi\'r Mewnflwch wrth allgofnodi';
$labels['uisettings'] = 'Rhyngwyneb Defnyddiwr';
$labels['serversettings'] = 'Gosodiadau Gweinydd';
$labels['mailboxview'] = 'Ymddangosiad y Blychau';
$labels['mdnrequests'] = 'Hysbysiadau anfonwr';
$labels['askuser'] = 'gofyn i\'r defnyddiwr';
$labels['autosend'] = 'anfon yn awtomatig';
$labels['autosendknown'] = 'anfon derbynneb i fy nghysylltiadau, gofyn i mi fel arall';
$labels['autosendknownignore'] = 'anfon derbynneb i fy nghysylltiadau, anwybyddu fel arall';
$labels['autosendtrusted'] = 'danfon hysbysiad derbyn i bob danfonwr ymddiriedig, fel arall gofyn';
$labels['autosendtrustedignore'] = 'danfon hysbysiad derbyn i bob danfonwr ymddiriedig, fel arall anwybyddu';
$labels['ignorerequest'] = 'anwybyddu\'r cais';
$labels['readwhendeleted'] = 'Nodi\'r neges fel darllenwyd wrth ddileu';
$labels['flagfordeletion'] = 'Fflagio\'r neges i\'w ddileu yn hytrach na dileu yn syth';
$labels['skipdeleted'] = 'Peidio dangos negesuon wedi ei dileu';
$labels['deletealways'] = 'Pan fod symud negeseuon i\'r Sbwriel yn methu, dileu nhw';
$labels['deletejunk'] = 'Dileu negeseuon yn uniongyrchol yn Sbwriel';
$labels['showremoteimages'] = 'Dangos lluniau o wefannau allanol';
$labels['allowremoteresources'] = 'Caniatau adnoddau pell (delweddau, arddulliau)';
$labels['fromknownsenders'] = 'o anfonwyr hysbys';
$labels['fromtrustedsenders'] = 'o ddanfonwyr ymddiriedig';
$labels['frommycontacts'] = 'o fy nghysylltiadau';
$labels['always'] = 'bob amser';
$labels['alwaysbutplain'] = 'bob amser, heblaw pan yn ymateb i destun plaen';
$labels['showinlineimages'] = 'Dangos lluniau atodol islaw\'r neges';
$labels['autosavedraft'] = 'Cadw drafft yn awtomatig';
$labels['everynminutes'] = 'bob $n munud';
$labels['refreshinterval'] = 'Ail-lwytho (edrych am negeseuon newydd ayyb)';
$labels['never'] = 'byth';
$labels['immediately'] = 'ar unwaith';
$labels['messagesdisplaying'] = 'Dangos Negeseuon';
$labels['messagescomposition'] = 'Ysgrifennu Negeseuon';
$labels['mimeparamfolding'] = 'Enw atodiadau';
$labels['2231folding'] = 'RFC 2231 llawn (Thunderbird)';
$labels['miscfolding'] = 'RFC 2047/2231 (MS Outlook)';
$labels['2047folding'] = 'RFC 2047 llawn (arall)';
$labels['force7bit'] = 'Defnyddio amgodi MIME ar gyfer llythrennau 8-did';
$labels['savelocalstorage'] = "Cadw yn storfa leol y porwr (dros dro)";
$labels['advancedoptions'] = 'Dewisiadau uwch';
$labels['toggleadvancedoptions'] = 'Newid dewisiadau uwch';
$labels['focusonnewmessage'] = 'Ffocysu\'r porwr ar y neges newydd';
$labels['checkallfolders'] = 'Chwilio pob ffolder am negeseuon newydd';
$labels['displaynext'] = 'Dangos cofnod rhestr nesaf ar ôl dileu/symud';
$labels['defaultfont'] = 'Ffont arferol ar gyfer negeseuon HTML';
$labels['mainoptions'] = 'Prif Ddewisiadau';
$labels['browseroptions'] = 'Dewisiadau Porwr';
$labels['section'] = 'Adran';
$labels['maintenance'] = 'Gwaith cynnal a chadw';
$labels['newmessage'] = 'Neges Newydd';
$labels['signatureoptions'] = 'Dewisiadau Llofnod';
$labels['whenreplying'] = 'Wrth ateb';
$labels['replyempty'] = 'peidio dyfynnu\'r neges wreiddiol';
$labels['replytopposting'] = 'dechrau\'r neges newydd uwchben y neges wreiddiol';
$labels['replytoppostingnoindent'] = 'dechrau neges newydd uwchben y dyfyniad (dim cilosodiad)';
$labels['replybottomposting'] = 'dechrau\'r neges newydd o dan y neges wreiddiol';
$labels['replyremovesignature'] = 'Wrth ateb, dileu\'r llofnod gwreiddiol o\'r neges';
$labels['autoaddsignature'] = 'Ychwanegu llofnod yn awtomatig';
$labels['newmessageonly'] = 'negeseuon newydd yn unig';
$labels['replyandforwardonly'] = 'atebion a danfon ymlaen yn unig';
$labels['insertsignature'] = 'Mewnosod llofnod';
$labels['sigbelow'] = 'Rhowch y llofnod o dan y neges wedi wreiddiol';
$labels['sigseparator'] = 'Gorfodi gwahanwr safonol yn y llofnodion';
$labels['automarkread'] = 'Nodi\'r negeseuon fel darllenwyd';
$labels['afternseconds'] = 'ar ôl $n eiliad';
$labels['reqmdn'] = 'Bob amser gofyn am dderbynneb danfon';
$labels['reqdsn'] = 'Gofyn am hysbysiad statws danfon bob amser';
$labels['replysamefolder'] = 'Rhoi atebion yn yr un ffolder i\'r neges sy\'n cael ei ateb';
$labels['defaultabook'] = 'Llyfr cyfeiriadau diofyn';
$labels['autocompletesingle'] = 'Hepgor cyfeiriadau ebost amgen wrth awto-gwblhau';
$labels['listnamedisplay'] = 'Rhestru cysylltiadau fel';
$labels['contactformmode'] = 'Modd ffurflen gyswllt';
$labels['privatemode'] = 'Preifat (Gartref)';
$labels['businessmode'] = 'Busnes (Gwaith)';
$labels['collectedaddresses'] = 'Cyfeiriadau a gasglwyd';
$labels['collectedrecipients'] = 'Derbynwyr a gasglwyd';
$labels['collectedrecipientsopt'] = 'Storio derbynwyr ebost allanol yn';
$labels['collectedsendersopt'] = 'Storio anfonwyr ymddiriedig yn';
$labels['trustedsenders'] = 'Anfonwyr Ymddiredig';
$labels['spellcheckbeforesend'] = 'Gwirio sillafu cyn anfon neges';
$labels['spellcheckoptions'] = 'Dewisiadau gwirio sillafu';
$labels['spellcheckignoresyms'] = 'Anwybyddu geiriau gyda symbolau';
$labels['spellcheckignorenums'] = 'Anwybyddu geiriau gyda rhifau';
$labels['spellcheckignorecaps'] = 'Anwybyddu geiriau sy\'n briflythrennau yn gyfangwbl';
$labels['addtodict'] = 'Ychwanegu i\'r geiriadur';
$labels['mailtoprotohandler'] = 'Cofrestru trafodwr protocol ar gyfer dolenni mailto:';
$labels['standardwindows'] = 'Trin ffenestri naid fel ffenestri arferol';
$labels['forwardmode'] = 'Danfon neges ymlaen';
$labels['inline'] = 'mewnlin';
$labels['asattachment'] = 'fel atodiad';
$labels['replyallmode'] = 'Gweithred diofyn botwm [Ymateb i bawb]';
$labels['replyalldefault'] = 'ymateb i bawb';
$labels['replyalllist'] = 'ymateb i\'r rhestr trafod yn unig (os canfuwyd)';
$labels['allmessages'] = 'pob neges';
$labels['olderxdays'] = 'hynach na $x diwrnod';
$labels['folder'] = 'Ffolder';
$labels['folders'] = 'Ffolderi';
$labels['foldername'] = 'Enw ffolder';
$labels['subscribed'] = 'Tanysgrifwyd';
$labels['messagecount'] = 'Negeseuon';
$labels['create'] = 'Creu';
$labels['createfolder'] = 'Creu ffolder newydd';
$labels['managefolders'] = 'Rheoli ffolderi';
$labels['specialfolders'] = 'Ffolderi arbennig';
$labels['properties'] = 'Nodweddion';
$labels['folderproperties'] = 'Ffolder nodweddion';
$labels['parentfolder'] = 'Ffolder uwchben';
$labels['location'] = 'Lleoliad';
$labels['info'] = 'Gwybodaeth';
$labels['getfoldersize'] = 'Cliciwch i gael maint ffolder';
$labels['changesubscription'] = 'Cliciwch i newid y tanysgrifiad';
$labels['foldertype'] = 'Math Ffolder';
$labels['personalfolder'] = 'Ffolder Preifat';
$labels['otherfolder'] = 'Ffolder Defnyddiwr Arall';
$labels['sharedfolder'] = 'Ffolder Cyhoeddus';
$labels['findfolders'] = 'Canfod ffolderi';
$labels['findcontacts'] = 'Canfod cysylltiadau';
$labels['findmail'] = 'Canfod negeseuon ebost';
$labels['namespace.personal'] = 'Persono';
$labels['namespace.other'] = 'Defnyddwyr arall';
$labels['namespace.shared'] = 'Rhannwyd';
$labels['dualuselabel'] = 'Gall gynnwys yn unig';
$labels['dualusemail'] = 'negeseuon';
$labels['dualusefolder'] = 'ffolder';
$labels['generate'] = 'Cynhyrchu';
$labels['encryptioncreatekey'] = 'Creu pâr allweddi newydd';
$labels['openmailvelopesettings'] = 'Agor Gosodiadau Mailvelope';
$labels['encryptionprivkeysinmailvelope'] = 'Mae gennych $nr allwedd preifat cyfatebol wedi eu storio yn eich cylch allwedd Mailvelope:';
$labels['encryptionnoprivkeysinmailvelope'] = 'Nid oes gan y anfonwr hwn allwedd preifat PGP wedi ei storio yn eich estyniad Mailvelope. Hoffech chi greu un er mwyn ei ddefnyddio i anfon negeseuon wedi eu amgryptio?';
$labels['encryption'] = 'Amgryptiad';
$labels['mailvelopeoptions'] = 'Dewisiadau Mailvelope';
$labels['mailvelopemainkeyring'] = 'Defnyddio prif gylch allweddi Mailvelope';
$labels['mailvelopenotfound'] = 'Nid yw\'r estyniad Mailvelope ar gael/wedi ei osod yn eich porwr';
$labels['sortby'] = 'Trefnu yn ôl';
$labels['sortasc'] = 'Trefn esgynnol';
$labels['sortdesc'] = 'Trefn ddisgynnol';
$labels['undo'] = 'Dad-wneud';
$labels['installedplugins'] = 'Ategynnau wedi eu gosod';
$labels['plugin'] = 'Ategyn';
$labels['version'] = 'Fersiwn';
$labels['source'] = 'Ffynhonnell';
$labels['destination'] = 'Cyrchfan';
$labels['license'] = 'Trwydded';
$labels['support'] = 'Gofyn am gymorth';
$labels['savedsearches'] = 'Chwiliadau wedi cadw';
$labels['dateformatY'] = 'BBBB';
$labels['dateformaty'] = 'BB';
$labels['dateformatm'] = 'MM';
$labels['dateformatd'] = 'DD';
$labels['dateformatj'] = 'D';
$labels['dateformatn'] = 'M';
$labels['B'] = 'B';
$labels['KB'] = 'KB';
$labels['MB'] = 'MB';
$labels['GB'] = 'GB';
$labels['unicode'] = 'Unicode';
$labels['english'] = 'Saesneg';
$labels['westerneuropean'] = 'Gorllewin Ewropeaidd';
$labels['easterneuropean'] = 'Dwyrain Ewropeaidd';
$labels['southeasterneuropean'] = 'De-Ddwyrain Ewropeaidd';
$labels['baltic'] = 'Baltig';
$labels['cyrillic'] = 'Cyrilig';
$labels['arabic'] = 'Arabeg';
$labels['greek'] = 'Groegaidd';
$labels['hebrew'] = 'Hebraeg';
$labels['turkish'] = 'Twrceg';
$labels['nordic'] = 'Nordeg';
$labels['thai'] = 'Thai';
$labels['celtic'] = 'Celtaidd';
$labels['vietnamese'] = 'Fietnamaidd';
$labels['japanese'] = 'Japaneaidd';
$labels['korean'] = 'Corëeg';
$labels['chinese'] = 'Tsieineaidd';
$labels['arialabeltopnav'] = 'Rheolaeth ffenest';
$labels['arialabeltasknav'] = 'Tasgiau rhaglen';
$labels['arialabeltoolbar'] = 'Bar offer y rhaglen';
$labels['arialabellistnav'] = 'Llywio rhestr';
$labels['arialabelactivetask'] = 'Tasg gweithredol';
$labels['arialabelmessagessearchfilter'] = 'Hidlydd rhestr ebost';
$labels['arialabelmailsearchform'] = 'Ffurflen chwilio neges ebost';
$labels['arialabelcontactsearchform'] = 'Ffurflen chwilio cysylltiadau';
$labels['arialabelmailquicksearchbox'] = 'Mewnbwn chwilio ebost';
$labels['arialabelquicksearchbox'] = 'Mewnbwn chwilio';
$labels['arialabelfoldersearchfilter'] = 'Hidlydd rhestr ffolderi';
$labels['arialabelfoldersearchform'] = 'Ffurflen chwilio ffolderi';
$labels['arialabelfolderlist'] = 'Dewis ffolderi ebost';
$labels['arialabelmessagelist'] = 'Rhestr Negeseuon Ebost';
$labels['arialabelmailpreviewframe'] = 'Rhagolwg neges';
$labels['arialabelmailboxmenu'] = 'Bwydlen gweithrediadau ffolder';
$labels['arialabellistselectmenu'] = 'Bwydlen dewis rhestr';
$labels['arialabelthreadselectmenu'] = 'Bwydlen rhestr edefynnau';
$labels['arialabelmessagelistoptions'] = 'Dewisiadau dangos a trefnu rhestr negeseuon';
$labels['arialabelmailimportdialog'] = 'Deialog mewnforio negeseuon';
$labels['arialabelmessagenav'] = 'Llywio neges';
$labels['arialabelmessagebody'] = 'Corff Neges';
$labels['arialabelmessageactions'] = 'Gweithrediadau neges';
$labels['arialabelcontactquicksearch'] = 'Ffurflen chwilio cysylltiadau';
$labels['arialabelcontactsearchbox'] = 'Mewnbwn chwilio cyswllt';
$labels['arialabelmessageheaders'] = 'Pennynau neges';
$labels['arialabelforwardingoptions'] = 'Dewisiadau anfon ymlaen';
$labels['arialabelreplyalloptions'] = 'Dewisiadau ymateb i bawb';
$labels['arialabelmoremessageactions'] = 'Mwy o weithrediadau neges';
$labels['arialabelmorecontactactions'] = 'Mwy o weithreoedd cyswllt';
$labels['arialabelmarkmessagesas'] = 'Nodi y negeseuon dewiswyd fel...';
$labels['arialabelcomposeoptions'] = 'Dewisiadau ysgrifennu';
$labels['arialabelresponsesmenu'] = 'Bwydlen ymatebion parod';
$labels['arialabelattachmentuploadform'] = 'Ffurflen lanlwytho atodiad';
$labels['arialabelattachmentmenu'] = 'Dewisiadau atodiad';
$labels['arialabelmailtomenu'] = 'Dewisiadau cyfeiriad ebost';
$labels['arialabelattachmentpreview'] = 'Rhagolwg atodiad';
$labels['ariasummarycomposecontacts'] = 'Rhestr o gysylltiadau a grwpiau i ddewis fel derbynwyr';
$labels['arialabelcontactexportoptions'] = 'Dewisiadau allforio cysylltiadau';
$labels['arialabelabookgroupoptions'] = 'Dewisiadau grŵp/llyfr cyfeiriadau';
$labels['arialabelpreferencesform'] = 'Ffurflen dewisiadau';
$labels['arialabelidentityeditfrom'] = 'Ffurflen golygu personoliaeth';
$labels['arialabelresponseeditfrom'] = 'Ffurflen golygu ymateb';
$labels['arialabelsearchterms'] = 'Chwilio termau';
$labels['arialabeldropactionmenu'] = 'Bwydlen Llusgo-a-Gollwng';
$labels['arialabelheadersmenu'] = 'Bwydlen ychwanegu derbynnydd (pennawd)';
$labels['arialabelimagetools'] = 'Teclynnau delwedd';
$labels['helplistnavigation'] = 'Rhestru llywio bysellfwrdd';
$labels['helplistkeyboardnavigation'] = "Saeth fyny/lawr: Symud dewis/ffocws dan sylw.
Bwlch: Dewis rhes dan sylw.
Shift + fyny/lawr; Dewis rhes ychwanegol uwchben/islaw.
Ctrl + Bwlch: Ychwanegu rhes dan sylw i'r dewis/dileu o'r dewis.";
$labels['helplistkeyboardnavmessages'] = "Saeth dde/chwith: ehangu/crebachu edefyn neges (yn modd edefynnau yn unig).
Enter: Agor y neges dewiswyd/dan sylw.
Delete: Symud y negeseuon dewiswyd i'r Sbwriel.";
$labels['helplistkeyboardnavcontacts'] = "Enter: Agor y cyswllt dewiswyd/dan sylw.";
