<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail Managesieve plugin         |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/plugin-managesieve/
*/


$labels['filters'] = 'Filtriloj';
$labels['managefilters'] = 'Mastrumi filtrilojn pri enirantaj mesaĝoj';
$labels['filtername'] = 'Nomo de filtrilo';
$labels['newfilter'] = 'Nova filtrilo';
$labels['filteradd'] = 'Aldoni filtrilon';
$labels['filterdel'] = 'Forigi filtrilon';
$labels['moveup'] = 'Movi supren';
$labels['movedown'] = 'Movi malsupren';
$labels['filterany'] = 'ĉiuj mesaĝoj';
$labels['filtercontains'] = 'enhavas';
$labels['filternotcontains'] = 'ne enhavas';
$labels['filteris'] = 'egalas al';
$labels['filterisnot'] = 'ne egalas al';
$labels['filterexists'] = 'ekzistas';
$labels['filternotexists'] = 'ne ekzistas';
$labels['filtermatches'] = 'kongruas esprimon';
$labels['filternotmatches'] = 'ne kongruas esprimon';
$labels['filterregex'] = 'kongruas regularan esprimon';
$labels['filternotregex'] = 'ne kongruas regularan esprimon';
$labels['filterunder'] = 'sub';
$labels['filterover'] = 'preter';
$labels['addrule'] = 'Aldoni regulon';
$labels['delrule'] = 'Forigi regulon';
$labels['messagemoveto'] = 'Movi mesaĝon al';
$labels['messageredirect'] = 'Aidirekti mesaĝon al';
$labels['messagecopyto'] = 'Kopii mesaĝo en';
$labels['messagesendcopy'] = 'Sendi kopion de mesaĝo al';
$labels['messagereply'] = 'Respondi per mesaĝo';
$labels['messagedelete'] = 'Forigi mesaĝon';
$labels['add'] = 'Aldoni';
$labels['del'] = 'Forigi';
$labels['sender'] = 'Sendanto';
$labels['recipient'] = 'Ricevanto';
$labels['flagread'] = 'Legi';
$labels['flagdeleted'] = 'Forigita';
$labels['flagflagged'] = 'Markita';
$labels['notifymethodmailto'] = 'Retpoŝto';
$labels['notifymethodtel'] = 'Telefono';
$labels['datetest'] = 'Dato';
$labels['spamtestequals'] = 'egalas al';
$labels['spamtestnotequals'] = 'ne egalas al';
$labels['vacation.subject'] = 'Temo';
$labels['vacation.keep'] = 'Manteni';
