<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail ACL plugin                 |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/plugin-acl/
*/

$labels['sharing'] = 'Delen';
$labels['myrights'] = 'Toegangsrechten';
$labels['username'] = 'Gebruiker:';
$labels['advanced'] = 'Gevorderde modus';
$labels['add'] = 'Toevoegen';
$labels['newuser'] = 'Invoer toevoegen';
$labels['editperms'] = 'Machtigingen bewerken';
$labels['actions'] = 'Toegang juiste acties...';
$labels['anyone'] = 'Alle gebruikers (iedereen)';
$labels['anonymous'] = 'Gasten (anoniem)';
$labels['identifier'] = 'Identificator';
$labels['acll'] = 'Opzoeken';
$labels['aclr'] = 'Lees berichten';
$labels['acls'] = 'Houd Bekeken status';
$labels['aclw'] = 'Schrijf flags';
$labels['acli'] = 'Invoegen ( Kopieer in)';
$labels['aclp'] = 'Post';
$labels['aclc'] = 'Submappen aanmaken';
$labels['aclk'] = 'Submappen aanmaken';
$labels['acld'] = 'Berichten verwijderen';
$labels['aclt'] = 'Berichten verwijderen';
$labels['acle'] = 'Schrappen';
$labels['aclx'] = 'Map verwijderen';
$labels['acla'] = 'Beheer';
$labels['acln'] = 'Berichten van commentaar voorzien';
$labels['aclfull'] = 'Volledige controle';
$labels['aclother'] = 'Andere';
$labels['aclread'] = 'Lees';
$labels['aclwrite'] = 'Schrijf';
$labels['acldelete'] = 'Verwijderen';
$labels['shortacll'] = 'Opzoeken';
$labels['shortaclr'] = 'Lees';
$labels['shortacls'] = 'Bewaar';
$labels['shortaclw'] = 'Schrijf';
$labels['shortacli'] = 'Voeg in';
$labels['shortaclp'] = 'Post';
$labels['shortaclc'] = 'Aanmaken';
$labels['shortaclk'] = 'Aanmaken';
$labels['shortacld'] = 'Verwijderen';
$labels['shortaclt'] = 'Verwijderen';
$labels['shortacle'] = 'Schrappen';
$labels['shortaclx'] = 'Map verwijderen';
$labels['shortacla'] = 'Beheer';
$labels['shortacln'] = 'Maak aantekeningen';
$labels['shortaclother'] = 'Andere';
$labels['shortaclread'] = 'Lees';
$labels['shortaclwrite'] = 'Schrijf';
$labels['shortacldelete'] = 'Verwijderen';
$labels['longacll'] = 'De map is zichtbaar op lijsten en kan worden ingeschreven op';
$labels['longaclr'] = 'De map kan worden geopend om te lezen';
$labels['longacls'] = 'Berichten Bekeken flag kan worden gewijzigd';
$labels['longaclw'] = 'Berichten flags en sleutelwoorden kunnen worden gewijzigd, behalve Bekeken en Verwijderd';
$labels['longacli'] = 'Berichten kunnen worden geschreven of gekopieerd naar de map';
$labels['longaclp'] = 'Berichten kunnen in deze map worden geplaatst';
$labels['longaclc'] = 'Mappen kunnen rechtstreeks onder deze map worden aangemaakt (of hernoemd).';
$labels['longaclk'] = 'Mappen kunnen rechtstreeks onder deze map worden aangemaakt (of hernoemd).';
$labels['longacld'] = 'Berichten Verwijderen flag kan worden gewijzigd';
$labels['longaclt'] = 'Messages Delete flag can be changed';
$labels['longacle'] = 'Berichten kunnen worden vernietigd';
$labels['longaclx'] = 'De map kan worden verwijderd of hernoemd';
$labels['longacla'] = 'De toegangsrechten voor de map kunnen gewijzigd worden';
$labels['longacln'] = 'Berichten gedeelde metadata ( aantekeningen) kunnen worden gewijzigd';
$labels['longaclfull'] = 'Volledige controle, inclusief mapbeheer';
$labels['longaclread'] = 'De map kan worden geopend om te lezen';
$labels['longaclwrite'] = 'Berichten kunnen worden gemarkeerd, geschreven of gekopieerd naar de map';
$labels['longacldelete'] = 'Berichten kunnen worden verwijderd';
$labels['longaclother'] = 'Andere toegangsrechten';
$labels['ariasummaryacltable'] = 'Lijst toegangsrechten';
$labels['arialabelaclactions'] = 'Lijst acties';
$labels['arialabelaclform'] = 'Formulier toegangsrechten';
$messages['deleting'] = 'Toegangsrechten verwijderen...';
$messages['saving'] = 'Toegangsrechten opslaan...';
$messages['updatesuccess'] = 'Toegangsrechten succesvol gewijzigd';
$messages['deletesuccess'] = 'Toegangsrechten succesvol verwijderd';
$messages['createsuccess'] = 'Toegangsrechten succesvol toegevoegd';
$messages['updateerror'] = 'Kan toegangsrechten niet bijwerken';
$messages['deleteerror'] = 'Kan toegangsrechten niet verwijderen';
$messages['createerror'] = 'Kan geen toegangsrechten toevoegen';
$messages['deleteconfirm'] = 'Weet u zeker dat u de toegangsrechten van de geselecteerde gebruiker(s) wilt verwijderen?';
$messages['norights'] = 'Er zijn geen rechten gespecificeerd!';
$messages['nouser'] = 'Er is geen gebruikersnaam opgegeven!';
