<?php

/**
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail Enigma plugin              |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/roundcube/roundcube-webmail/plugin-enigma/
*/

$labels['encryption'] = 'Criptiúchán';
$labels['keyname'] = 'Ainm';
$labels['fingerprint'] = 'Méarlorg';
$labels['basicinfo'] = 'An fhaisnéis bhunúsach';
$labels['userids'] = 'Úsáideoirí breise';
$labels['typepublickey'] = 'eochair phoiblí';
$labels['typesign'] = 'Sínigh';
$labels['typeencrypt'] = 'Criptigh';
$labels['typecert'] = 'Deimhnigh';
$labels['typeauth'] = 'Fíordheimhniú';
$labels['subkeyid'] = 'Aitheantas';
$labels['subkeyalgo'] = 'Algartam';
$labels['subkeycreated'] = 'Cruthaithe';
$labels['subkeyexpires'] = 'Éagann sé';
$labels['subkeyusage'] = 'Úsáid';
$labels['expiresnever'] = 'riamh';
$labels['unknown'] = 'anaithnid';
$labels['uservalid'] = 'Bailí';
$labels['userid'] = 'Aitheantas';
$labels['valid'] = 'bailí';
$labels['signdefault'] = 'Sínigh gach teachtaireacht mar réamhshocrú';
$labels['encryptdefault'] = 'Criptigh gach teachtaireacht mar réamhshocrú';
$labels['nminutes'] = '$m nóiméad';
$labels['wholesession'] = 'an dreas ar fad';
$labels['keyremove'] = 'Bain';
$labels['keydisable'] = 'Díchumasaigh';
$labels['keyrevoke'] = 'Aisghairm';
$labels['keysend'] = 'Seol eochair phoiblí i dteachtaireacht';
$labels['keychpass'] = 'Athraigh d\'fhocal faire';
$labels['newkeypass'] = 'Pasfhocal';
$labels['newkeypassconfirm'] = 'Deimhnigh an focal faire';
$labels['keygenerating'] = 'Ag cruthú eochracha...';
$labels['encryptmsg'] = 'Criptigh an teachtaireacht seo';
$labels['signmsg'] = 'Sínigh an teachtaireacht seo go digiteach';
$labels['attachpubkeymsg'] = 'Ceangail m\'eochair phoiblí';
$labels['keyimportlabel'] = 'Tabhair isteach ó chomhad';
$messages['decrypterror'] = 'Theip ar an díchriptiú';
$messages['signerror'] = 'Theip ar an síniú.';
$messages['encrypterror'] = 'Theip ar an gcriptiú.';
$messages['nokeysfound'] = 'Níor aimsíodh aon eochair';
$messages['keynotfound'] = 'Níor aimsíodh an eochair!';
$messages['passwordsdiffer'] = 'Ní hionann na focail fhaire!';
$labels['newkeysize'] = 'Méid na heochrach';
$labels['key2048'] = '2048 beart - an réamhshocrú';
