<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail ACL plugin                 |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/plugin-acl/
*/

$labels['sharing'] = 'Megosztás';
$labels['myrights'] = 'Hozzáférési jogok';
$labels['username'] = 'Felhasználó:';
$labels['advanced'] = 'Haladó mód';
$labels['add'] = 'Hozzáadás';
$labels['newuser'] = 'Elem hozzáadása';
$labels['editperms'] = 'Jogosultságok szerkesztése';
$labels['actions'] = 'Hozzáférési jogok müveletei..';
$labels['anyone'] = 'Minden felhasználó (bárki)';
$labels['anonymous'] = 'Vendégek (névtelen)';
$labels['identifier'] = 'Azonosító';
$labels['acll'] = 'Keresés';
$labels['aclr'] = 'Üzenetek olvasása';
$labels['acls'] = 'Olvasottsági állapot megtartása';
$labels['aclw'] = 'Üzenet jelölése';
$labels['acli'] = 'Beillesztés (Bemásolás)';
$labels['aclp'] = 'Bejegyzés';
$labels['aclc'] = 'Almappa létrehozás';
$labels['aclk'] = 'Almappa létrehozás';
$labels['acld'] = 'Üzenetek törlése';
$labels['aclt'] = 'Üzenetek törlése';
$labels['acle'] = 'Törölt üzenetek eltávolítása';
$labels['aclx'] = 'Mappa törlés';
$labels['acla'] = 'Adminisztrátor';
$labels['acln'] = 'Üzenetekhez címkézés';
$labels['aclfull'] = 'Teljes hozzáférés';
$labels['aclother'] = 'Egyéb';
$labels['aclread'] = 'Olvasás';
$labels['aclwrite'] = 'Írás';
$labels['acldelete'] = 'Törlés';
$labels['shortacll'] = 'Keresés';
$labels['shortaclr'] = 'Olvasás';
$labels['shortacls'] = 'Megtartás';
$labels['shortaclw'] = 'Írás';
$labels['shortacli'] = 'Beszúrás';
$labels['shortaclp'] = 'Bejegyzés';
$labels['shortaclc'] = 'Létrehozás';
$labels['shortaclk'] = 'Létrehozás';
$labels['shortacld'] = 'Törlés';
$labels['shortaclt'] = 'Törlés';
$labels['shortacle'] = 'Törölt üzenetek eltávolítása';
$labels['shortaclx'] = 'Mappa törlése';
$labels['shortacla'] = 'Adminisztrátor';
$labels['shortacln'] = 'Cimkézés';
$labels['shortaclother'] = 'Egyéb';
$labels['shortaclread'] = 'Olvasás';
$labels['shortaclwrite'] = 'Írás';
$labels['shortacldelete'] = 'Törlés';
$labels['longacll'] = 'A mappa látható a listán és fel tudsz rá iratkozni.';
$labels['longaclr'] = 'A mappa olvasásra megnyitható';
$labels['longacls'] = 'Az üzenet megtekintési állapota módosítható';
$labels['longaclw'] = 'Az üzenetek jelölései és kulcsszavai módosíthatóak, kivéve az olvasottsági állapotot és az üzenet törölt állapotát.';
$labels['longacli'] = 'Üzenetek irhatóak és máolshatóak a mappába.';
$labels['longaclp'] = 'Ebbe a mappába tudsz  üzeneteket tenni.';
$labels['longaclc'] = 'Mappák létrehozhazóak (átnevezhetőek) ez alatt a mappa alatt.';
$labels['longaclk'] = 'Mappák létrehozhazóak (átnevezhetőek) ez alatt a mappa alatt.';
$labels['longacld'] = 'Üzenet törölve jelző módositható.';
$labels['longaclt'] = 'Üzenet törölve jelző módositható.';
$labels['longacle'] = 'Az üzenetek véglegesen eltávolíthatóak';
$labels['longaclx'] = 'A mappa törölhető vagy átnevezhető';
$labels['longacla'] = 'A mappa hozzáférési jogai módosíthatóak';
$labels['longacln'] = 'Üzenetek megosztott metaadatai(cimkéi) módosíthatoak';
$labels['longaclfull'] = 'Teljes hozzáférés beleértve a mappák kezelését';
$labels['longaclread'] = 'A mappa olvasásra megnyitható';
$labels['longaclwrite'] = 'Az üzenetek megjelölhetök, irhatók és másolhatók ebbe a mappába';
$labels['longacldelete'] = 'Az üzenetek törölhetőek';
$labels['longaclother'] = 'Egyébb hozzáférési jogok';
$labels['ariasummaryacltable'] = 'Hozzáférési jogok listája';
$labels['arialabelaclactions'] = 'Listázási müveletek';
$labels['arialabelaclform'] = 'Hozzáférési jogok űrlap';
$messages['deleting'] = 'Hozzáférési jogok törlése...';
$messages['saving'] = 'Hozzáférési jogok mentése...';
$messages['updatesuccess'] = 'A hozzáférési jogok sikeresen módosultak.';
$messages['deletesuccess'] = 'A hozzáférési jogok törlése sikeresen megtörtént.';
$messages['createsuccess'] = 'A hozzáférési jogok hozzáadása sikeresen megtörtént.';
$messages['updateerror'] = 'Nem sikerült módosítani a hozzáférési jogokat.';
$messages['deleteerror'] = 'Nem sikerült törölni a hozzáférési jogokat.';
$messages['createerror'] = 'Nem sikerült a hozzáférési jogok hozzáadása';
$messages['deleteconfirm'] = 'Biztosan eltávolítja a kiválasztott felhasználó(k) hozzáférési jogait?';
$messages['norights'] = 'Nincsennek jogok megadva.';
$messages['nouser'] = 'A felhasználónév nincs megadva.';
