<?php

/**
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail Enigma plugin              |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/roundcube/roundcube-webmail/plugin-enigma/
*/

$labels['encryption'] = 'Dulritun';
$labels['enigmacerts'] = 'S/MIME skilríki';
$labels['enigmakeys'] = 'PGP-lyklar';
$labels['keysfromto'] = 'Dulritunarlyklar $from til $to af $count';
$labels['keyname'] = 'Heiti';
$labels['keyid'] = 'Auðkenni lykils';
$labels['keyuserid'] = 'Notandaauðkenni';
$labels['keytype'] = 'Tegund dulritunarlykils';
$labels['fingerprint'] = 'Fingrafar';
$labels['subkeys'] = 'Undirlyklar';
$labels['keyprops'] = 'Eiginleikar lykils';
$labels['basicinfo'] = 'Grunnupplýsingar';
$labels['userids'] = 'Viðbótarnotendur';
$labels['typepublickey'] = 'dreyfilykill';
$labels['typekeypair'] = 'lyklapar';
$labels['keyattimport'] = 'Flytja inn lykil/lykla';
$labels['typesign'] = 'Undirrita';
$labels['typeencrypt'] = 'Dulrita';
$labels['typecert'] = 'Votta';
$labels['typeauth'] = 'Auðkenning';
$labels['subkeyid'] = 'Auðkenni';
$labels['subkeyalgo'] = 'Reiknirit';
$labels['subkeycreated'] = 'Búið til';
$labels['subkeyexpires'] = 'Rennur út';
$labels['subkeyusage'] = 'Notkun';
$labels['expiresnever'] = 'aldrei';
$labels['unknown'] = 'óþekkt';
$labels['uservalid'] = 'Gilt';
$labels['userid'] = 'Auðkenni';
$labels['valid'] = 'gilt';
$labels['nminutes'] = '$m mínútur';
$labels['createkeys'] = 'Búa til nýtt lyklapar';
$labels['importkeys'] = 'Flytja inn lykil/lykla';
$labels['exportkeys'] = 'Flytja út lykil/lykla';
$labels['keyremove'] = 'Fjarlægja';
$labels['keydisable'] = 'Gera óvirkt';
$labels['keyrevoke'] = 'Afturkalla';
$labels['keychpass'] = 'Breyta lykilorði';
$labels['newkeyident'] = 'Auðkenni';
$labels['newkeypass'] = 'Lykilorð';
$labels['newkeypassconfirm'] = 'Staðfestu  lykilorð';
$labels['newkeytype'] = 'Tegund dulritunarlykils';
$labels['keygenerating'] = 'Útbý dulritunarlykla...';
$labels['encryptmsg'] = 'Dulrita þessi skilaboð';
$labels['keyimportlabel'] = 'Flytja inn úr skrá';
$labels['managekeys'] = 'Sýsla með PGP-lykla';
$messages['signerror'] = 'Undirritun mistókst.';
$labels['newkeysize'] = 'Stærð lykils';
$labels['key2048'] = '2048 bita - sjálfgefið';
$labels['key4096'] = '4096 bita - öruggara';
