<?php

/*
 +-----------------------------------------------------------------------+
 | localization/<lang>/csv2vcard.inc                                     |
 |                                                                       |
 | Localization file of the Roundcube Webmail client                     |
 | Copyright (C) 2005-2013, The Roundcube Dev Team                       |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 |                                                                       |
 +-----------------------------------------------------------------------+
 | Author: Marek Mečiar <mmmeciar@gmail.com>                             |
 +-----------------------------------------------------------------------+
*/
$map = array();
$map['anniversary'] = "Výročie";
$map['assistants_name'] = "Meno asistenta";
$map['assistants_phone'] = "Telefón asistenta";
$map['birthday'] = "Narodeniny";
$map['business_city'] = "Mesto (práca)";
$map['business_countryregion'] = "Krajina/oblasť (práca)";
$map['business_fax'] = "Fax do práce";
$map['business_phone'] = "Telefón do práce";
$map['business_phone_2'] = "Telefón do práce 2";
$map['business_postal_code'] = "PSČ (práca)";
$map['business_state'] = "Okres (práca)";
$map['business_street'] = "Ulica (práca)";
$map['car_phone'] = "Autotelefón";
$map['categories'] = "Kategórie";
$map['company'] = "Spoločnosť";
$map['department'] = "Oddelenie";
$map['email_address'] = "E-mailová adresa";
$map['first_name'] = "Krstné meno";
$map['gender'] = "Pohlavie";
$map['home_city'] = "Mesto (domov)";
$map['home_countryregion'] = "Krajina/oblasť (domov)";
$map['home_fax'] = "Fax domov";
$map['home_phone'] = "Telefón domov";
$map['home_phone_2'] = "Telefón domov 2";
$map['home_postal_code'] = "PSČ (domov)";
$map['home_state'] = "Okres (domov)";
$map['home_street'] = "Ulica (domov)";
$map['job_title'] = "Funkcia";
$map['last_name'] = "Priezvisko";
$map['managers_name'] = "Meno manažéra";
$map['middle_name'] = "Ďalšie meno";
$map['mobile_phone'] = "Mobilný telefón";
$map['notes'] = "Poznámky";
$map['other_city'] = "Iné mesto";
$map['other_countryregion'] = "Krajina/oblasť (iné)";
$map['other_fax'] = "Iný fax";
$map['other_phone'] = "Iný telefón";
$map['other_postal_code'] = "Iné PSČ";
$map['other_state'] = "Krajina/oblasť (iné)";
$map['other_street'] = "Iná ulica";
$map['pager'] = "Operátor";
$map['primary_phone'] = "Primárny telefón";
$map['spouse'] = "Manžel(ka)";
$map['suffix'] = "Prípona";
$map['title'] = "Titul";
$map['web_page'] = "Webová stránka";
$map['birth_day'] = "Deň narodenia";
$map['birth_month'] = "Mesiac narodenia";
$map['birth_year'] = "Rok narodenia";
$map['display_name'] = "Zobrazované meno";
$map['fax_number'] = "Fax";
$map['home_address'] = "Adresa domov";
$map['home_country'] = "Štát domov";
$map['home_zipcode'] = "PSČ domov";
$map['mobile_number'] = "Mobil";
$map['nickname'] = "Prezývka";
$map['organization'] = "Organizácia";
$map['pager_number'] = "Pager";
$map['primary_email'] = "E-mailová adresa";
$map['secondary_email'] = "Ďalšia e-mailová adresa";
$map['web_page_1'] = "Webová stránka 1";
$map['web_page_2'] = "Webová stránka 2";
$map['work_phone'] = "Telefón do zamestnania";
$map['work_address'] = "Pracovná adresa";
$map['work_country'] = "Štát zamestnania";
$map['work_zipcode'] = "PSČ zamestnania";
