<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail Password plugin            |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/plugin-password/
*/

$labels['curpasswd']  = 'Mật khẩu hiện tại';
$labels['newpasswd']  = 'Mật khẩu mới:';
$labels['confpasswd']  = 'Xác nhận mật khẩu mới';
$messages['nopassword'] = 'Mời nhập mật khẩu mới';
$messages['nocurpassword'] = 'Mời nhập mật khẩu hiện tại';
$messages['passwordincorrect'] = 'Mật khẩu hiện thời không đúng';
$messages['passwordinconsistency'] = 'Mật khẩu không khớp, hãy thử lại';
$messages['crypterror'] = 'Không thể lưu mật khẩu mới. Thiếu chức năng mã hóa';
$messages['connecterror'] = 'Không thể lưu mật mã mới. Lổi kết nối';
$messages['internalerror'] = 'Không thể lưu mật khẩu mới';
$messages['passwordshort'] = 'Mật khẩu phải dài ít nhất $ ký tự';
$messages['passwordweak'] = 'Mật khẩu phải bao gồm ít nhất 1 con số và 1 ký tự dấu câu';
$messages['passwordforbidden'] = 'Mật khẩu bao gồm ký tự không hợp lệ';
