<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail Archive plugin             |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/plugin-archive/
*/

$labels['buttontext'] = 'Архивирай';
$labels['buttontitle'] = 'Архивиране на писмото';
$labels['archived'] = 'Архивирането премина успешно';
$labels['archivedreload'] = 'Успешно архивирано. Презаредете страницата за да видите архивираните папки.';
$labels['archiveerror'] = 'Някои писма не бяха архивирани';
$labels['archivefolder'] = 'Архивирай';
$labels['settingstitle'] = 'Архив';
$labels['archivetype'] = 'Раздели архива по';
$labels['archivetypeyear'] = 'Година (пр. Архив/2012)';
$labels['archivetypemonth'] = 'Месец (пр. Архив/2012/06)';
$labels['archivetypetbmonth'] = 'Месец - съвместим с Thunderbird (пр. Архив/2012/2012-06)';
$labels['archivetypefolder'] = 'Оригинална папка';
$labels['archivetypefolderyear'] = 'Година и оригиналната папка (пр. Архив/2012/...) ';
$labels['archivetypefoldermonth'] = 'Година, месец и оригиналната папка (пр. Архив/2012/06/...) ';
$labels['archivetypesender'] = 'E-mail адрес на подател';
$labels['unkownsender'] = 'неизвестно';
$labels['readonarchive'] = 'Маркирай писмото като прочетено в архива';
