<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail Help plugin                |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/plugin-help/
*/

$labels['help'] = 'Skoazell';
$labels['about'] = 'Diwar-benn';
$labels['license'] = 'Lañvaz';
$labels['csrfinfo'] = 'Gouzout hiroc\'h a-zivout an CSRF ha penaos e warezomp ac\'hanoc\'h';
