<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail Managesieve plugin         |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/plugin-managesieve/
*/


$labels['filters'] = 'Filtres';
$labels['managefilters'] = 'Gestiona els filtres dels missatges d\'entrada';
$labels['filtername'] = 'Nom del filtre';
$labels['newfilter'] = 'Filtre nou';
$labels['filteradd'] = 'Afegeix un filtre';
$labels['filterdel'] = 'Suprimeix el filtre';
$labels['rules'] = 'Regles';
$labels['actions'] = 'Accions';
$labels['scope'] = 'Abast';
$labels['moveup'] = 'Mou amunt';
$labels['movedown'] = 'Mou avall';
$labels['filterallof'] = 'que coincideixi amb totes les regles següents';
$labels['filteranyof'] = 'que coincideixi amb qualsevol de les regles següents';
$labels['filterany'] = 'tots els missatges';
$labels['filtercontains'] = 'conté';
$labels['filternotcontains'] = 'no conté';
$labels['filteris'] = 'és igual a';
$labels['filterisnot'] = 'és diferent de';
$labels['filterexists'] = 'existeix';
$labels['filternotexists'] = 'no existeix';
$labels['filtermatches'] = 'coincideix amb l\'expressió';
$labels['filternotmatches'] = 'no coincideix amb l\'expressió';
$labels['filterregex'] = 'coincideix amb l\'expressió regular';
$labels['filternotregex'] = 'no coincideix amb l\'expressió regular';
$labels['filterunder'] = 'sota';
$labels['filterover'] = 'sobre';
$labels['mime'] = 'MIME:';
$labels['mimepart'] = 'Part MIME:';
$labels['mime-message'] = 'missatge';
$labels['mime-anychild'] = 'qualsevol';
$labels['mime-type'] = 'tipus';
$labels['mime-subtype'] = 'subtipus';
$labels['mime-contenttype'] = 'tipus de contingut';
$labels['mime-param'] = 'paràmetre';
$labels['addrule'] = 'Afegeix una regla';
$labels['delrule'] = 'Suprimeix una regla';
$labels['messagemoveto'] = 'Mou el missatge a';
$labels['messageredirect'] = 'Redirigeix el missatge cap a';
$labels['messagecopyto'] = 'Copia el missatge a';
$labels['messagesendcopy'] = 'Envia una còpia del missatge a';
$labels['messagereply'] = 'Respon amb un missatge';
$labels['messagedelete'] = 'Suprimeix missatge';
$labels['messagediscard'] = 'Descarta amb un missatge';
$labels['messagekeep'] = 'Deixa el missatge a la bústia';
$labels['messagesrules'] = 'Pels missatges entrants:';
$labels['messagesactions'] = '..executa les següents accions:';
$labels['add'] = 'Afegeix';
$labels['del'] = 'Suprimeix';
$labels['sender'] = 'Remitent';
$labels['recipient'] = 'Destinatari';
$labels['vacationaddr'] = 'Les meves adreces de correu electrònic:';
$labels['vacationdays'] = 'Cada quan s\'ha d\'enviar un missatge (en dies):';
$labels['vacationinterval'] = 'Amb quina freqüència s\'han d\'enviar els missatges:';
$labels['vacationreason'] = 'Cos del missatge (raó de l\'absència):';
$labels['vacationfrom'] = 'Respon a l\'adreça del remitent:';
$labels['vacationsubject'] = 'Assumpte del missatge:';
$labels['days'] = 'dies';
$labels['seconds'] = 'segons';
$labels['rulestop'] = 'Deixa d\'avaluar regles';
$labels['enable'] = 'Habilita/Deshabilita';
$labels['filterset'] = 'Conjunt de filtres';
$labels['filtersets'] = 'Conjunts de filtres';
$labels['filtersetadd'] = 'Afegeix un conjunt de filtres';
$labels['filtersetdel'] = 'Suprimeix un conjunt de filtres';
$labels['filtersetact'] = 'Activa el conjunt de filtres actuals';
$labels['filtersetdeact'] = 'Desactiva el conjunt de filtres actuals';
$labels['filterseteditraw'] = 'Edita el conjunt de filtres';
$labels['filtersetswitch'] = 'Activa/desactiva el conjunt de filtres';
$labels['filterdef'] = 'Definició del filtre';
$labels['filtersetname'] = 'Nom del conjunt de filtres';
$labels['newfilterset'] = 'Nou conjunt de filtres';
$labels['active'] = 'actiu';
$labels['none'] = 'cap';
$labels['fromset'] = 'des del conjunt';
$labels['fromfile'] = 'des del fitxer';
$labels['filterdisabled'] = 'Filtre desactivat';
$labels['filterenabled'] = 'Filtre activat';
$labels['countisgreaterthan'] = 'el recompte és més gran de';
$labels['countisgreaterthanequal'] = 'el recompte és més gran o igual a';
$labels['countislessthan'] = 'el recompte és menor de';
$labels['countislessthanequal'] = 'el recompte és menor o igual a';
$labels['countequals'] = 'el recompte és igual que';
$labels['countnotequals'] = 'el recompte és diferent de';
$labels['valueisgreaterthan'] = 'el valor és més gran de';
$labels['valueisgreaterthanequal'] = 'el valor és major o igual que';
$labels['valueislessthan'] = 'el valor és menor que';
$labels['valueislessthanequal'] = 'el valor és menor o igual de';
$labels['valueequals'] = 'el valor és igual a';
$labels['valuenotequals'] = 'el valor és diferent de';
$labels['setflags'] = 'Posa indicadors al missatge';
$labels['addflags'] = 'Afegeix indicadors al missatge';
$labels['removeflags'] = 'Suprimeix indicadors del missatge';
$labels['flagread'] = 'Llegit';
$labels['flagdeleted'] = 'Suprimit';
$labels['flaganswered'] = 'Respost';
$labels['flagflagged'] = 'Marcat';
$labels['flagdraft'] = 'Esborrany';
$labels['addheader'] = 'Afegeix una capçalera al missatge';
$labels['deleteheader'] = 'Suprimeix una capçalera del missatge';
$labels['headername'] = 'Nom de la capçalera';
$labels['headervalue'] = 'Valor de la capçalera';
$labels['headerpos'] = 'Posició de la capçalera';
$labels['headeratstart'] = 'al començament';
$labels['headeratend'] = 'al final';
$labels['headeroccurrence'] = 'Ocurrència/posició de la capçalera';
$labels['headerfromstart'] = 'des de l\'inici';
$labels['headerfromend'] = 'des del final';
$labels['headerpatterns'] = 'Patrons de valor de capçalera';
$labels['headermatchtype'] = 'tipus de concordança';
$labels['setvariable'] = 'Ajusta la variable';
$labels['setvarname'] = 'Nom de la variable:';
$labels['setvarvalue'] = 'Valor de la variable:';
$labels['setvarmodifiers'] = 'Modificadors:';
$labels['varlower'] = 'minúscules';
$labels['varupper'] = 'majúscules';
$labels['varlowerfirst'] = 'el primer caràcter en minúscula';
$labels['varupperfirst'] = 'el primer caràcter en majúscula';
$labels['varquotewildcard'] = 'engloba els caràcters especials amb cometes';
$labels['varlength'] = 'llargada';
$labels['notify'] = 'Envia notificació';
$labels['notifytarget'] = 'Objectiu de la notificació:';
$labels['notifymessage'] = 'Missatge de notificació (opcional):';
$labels['notifyoptions'] = 'Opcions de notificació (opcional):';
$labels['notifyfrom'] = 'Remitent de la notificació (opcional):';
$labels['notifyimportance'] = 'Importància:';
$labels['notifyimportancelow'] = 'baixa';
$labels['notifyimportancenormal'] = 'normal';
$labels['notifyimportancehigh'] = 'alta';
$labels['notifymethodmailto'] = 'Correu electrònic';
$labels['notifymethodtel'] = 'Telèfon';
$labels['notifymethodsms'] = 'SMS';
$labels['filtercreate'] = 'Crea filtre';
$labels['usedata'] = 'Fes servir les següents dades al filtre:';
$labels['nextstep'] = 'Següent pas';
$labels['...'] = '...';
$labels['string'] = 'Cadena de text';
$labels['currdate'] = 'Data actual';
$labels['datetest'] = 'Data';
$labels['dateheader'] = 'capçalera:';
$labels['year'] = 'any';
$labels['month'] = 'mes';
$labels['day'] = 'dia';
$labels['date'] = 'data (aaaa-mm-dd)';
$labels['julian'] = 'data (calendari julià)';
$labels['hour'] = 'hora';
$labels['minute'] = 'minut';
$labels['second'] = 'segon';
$labels['time'] = 'hora (hh:mm:ss)';
$labels['iso8601'] = 'data (ISO8601)';
$labels['std11'] = 'data (RFC2822)';
$labels['zone'] = 'fus horari';
$labels['weekday'] = 'dia de la setmana (0-6)';
$labels['advancedopts'] = 'Opcions avançades';
$labels['body'] = 'Cos';
$labels['address'] = 'adreça';
$labels['envelope'] = 'sobre';
$labels['modifier'] = 'modificador:';
$labels['text'] = 'text';
$labels['undecoded'] = 'descodificat (en brut)';
$labels['contenttype'] = 'tipus de contingut';
$labels['modtype'] = 'tipus:';
$labels['allparts'] = 'tots';
$labels['domain'] = 'domini';
$labels['localpart'] = 'part local';
$labels['user'] = 'usuari';
$labels['detail'] = 'detall';
$labels['comparator'] = 'comparador:';
$labels['default'] = 'per defecte';
$labels['octet'] = 'estricte (octet)';
$labels['asciicasemap'] = 'No distingeix entre majúscules i minúscules  (ascii-casemap)';
$labels['asciinumeric'] = 'numèric (ascii-numèric)';
$labels['index'] = 'índex:';
$labels['indexlast'] = 'cap enrere';
$labels['spamtest'] = 'Nivell de correu brossa';
$labels['spamtestisgreaterthan'] = 'és més gran de';
$labels['spamtestisgreaterthanequal'] = 'és major o igual que';
$labels['spamtestislessthan'] = 'és menor que';
$labels['spamtestislessthanequal'] = 'és menor o igual a';
$labels['spamtestequals'] = 'és igual a';
$labels['spamtestnotequals'] = 'és diferent de';
$labels['spamtestisunknown'] = 'és desconegut';
$labels['vacation'] = 'Fora de l\'oficina';
$labels['vacation.reply'] = 'Missatge de resposta';
$labels['vacation.advanced'] = 'Paràmetres avançats';
$labels['vacation.from'] = 'Respon a l\'adreça del remitent';
$labels['vacation.subject'] = 'Assumpte';
$labels['vacation.body'] = 'Cos';
$labels['vacation.start'] = 'Hora d\'inici';
$labels['vacation.end'] = 'Hora final';
$labels['vacation.status'] = 'Estat';
$labels['vacation.on'] = 'Activat';
$labels['vacation.off'] = 'Desactivat';
$labels['vacation.addresses'] = 'Les meves adreces de correu electrònic';
$labels['vacation.interval'] = 'Interval de resposta';
$labels['vacation.after'] = 'Col·loca la regla de \'fora de l\'oficina\' darrera';
$labels['vacation.saving'] = 'S\'estan desant les dades...';
$labels['vacation.action'] = 'Acció pel missatge entrant';
$labels['vacation.keep'] = 'Conserva';
$labels['vacation.discard'] = 'Descarta';
$labels['vacation.redirect'] = 'Redirigeix cap a';
$labels['vacation.copy'] = 'Envia còpia a';
$labels['forward'] = 'Reenviament';
$labels['forward.redirect'] = 'Redirigeix cap a';
$labels['forward.copy'] = 'Envia còpia a';
$labels['forward.on'] = 'Activat';
$labels['forward.off'] = 'Desactivat';
$labels['forward.status'] = 'Estat:';
$labels['forward.action'] = 'Per als missatges d\'entrada executa la següent acció:';
$labels['forward.saving'] = 'S\'estan desant les dades...';
$labels['filladdresses'] = 'Emplena-ho amb totes les meves adreces de correu electrònic';
$labels['arialabelfiltersetactions'] = 'Accions pel conjunt de filtres';
$labels['arialabelfilteractions'] = 'Accions del filtre';
$labels['arialabelfilterform'] = 'Propietats del filtre';
$labels['ariasummaryfilterslist'] = 'Llistat de filtres';
$labels['ariasummaryfiltersetslist'] = 'Llistat de conjunts de filtres';
$labels['filterstitle'] = 'Edita els filtres pels missatges entrants';
$labels['vacationtitle'] = 'Edita la norma "fora de l\'oficina"';
$labels['forwardtitle'] = 'Edita la regla de reenviament de correu';
$labels['message'] = 'Missatge';
$labels['duplicate'] = 'està duplicat';
$labels['notduplicate'] = 'no està duplicat';
$labels['duplicate.handle'] = 'gestor:';
$labels['duplicate.header'] = 'capçalera:';
$labels['duplicate.uniqueid'] = 'Identificador:';
$labels['duplicate.seconds'] = 'temps d\'espera (en segons):';
$labels['duplicate.last'] = 'relatiu a la darrera execució';
$messages['filterunknownerror'] = 'Hi ha hagut un error desconegut al servidor.';
$messages['filterconnerror'] = 'No s\'ha pogut connectar al servidor.';
$messages['filterdeleteerror'] = 'No s\'ha pogut suprimir el filtre. Hi ha hagut un error al servidor.';
$messages['filterdeleted'] = 'El filtre s\'ha suprimit correctament.';
$messages['filtersaved'] = 'El filtre s\'ha desat correctament.';
$messages['filtersaveerror'] = 'No s\'ha pogut desar el filtre. Hi ha hagut un error al servidor.';
$messages['filterformerror'] = 'El formulari de filtres conté errors.';
$messages['filterdeleteconfirm'] = 'Esteu segur de voler suprimir el filtre seleccionat?';
$messages['ruledeleteconfirm'] = 'Esteu segur de voler suprimir la regla seleccionada?';
$messages['actiondeleteconfirm'] = 'Esteu segur de voler suprimir l\'acció seleccionada?';
$messages['forbiddenchars'] = 'El camp conté caràcters prohibits.';
$messages['cannotbeempty'] = 'El camp no pot estar buit.';
$messages['ruleexist'] = 'Ja existeix un filtre amb aquest nom.';
$messages['setactivateerror'] = 'No s\'ha pogut activar el conjunt de filtres seleccionat. Hi ha hagut un error al servidor.';
$messages['setdeactivateerror'] = 'No s\'ha pogut desactivar el conjunt de filtres seleccionat. Hi ha hagut un error al servidor.';
$messages['setdeleteerror'] = 'No s\'ha pogut suprimir el conjunt de filtres seleccionat. Hi ha hagut un error al servidor.';
$messages['setactivated'] = 'El conjunt de filtres s\'ha activat correctament.';
$messages['setdeactivated'] = 'El conjunt de filtres s\'ha desactivat correctament.';
$messages['setdeleted'] = 'El conjunt de filtres s\'ha suprimit correctament.';
$messages['setupdated'] = 'El conjunt de filtres s\'ha actualitzat correctament.';
$messages['setdeleteconfirm'] = 'Esteu segur de voler suprimir el conjunt de filtres seleccionat?';
$messages['setcreateerror'] = 'No s\'ha pogut crear el conjunt filtres. Hi ha hagut un error al servidor.';
$messages['setcreated'] = 'El conjunt de filtres s\'ha creat correctament.';
$messages['activateerror'] = 'No s\'ha pogut activar el(s) filtre(s) seleccionat(s). Hi ha hagut un error al servidor.';
$messages['deactivateerror'] = 'No s\'ha pogut desactivar el(s) filtre(s) seleccionat(s). Hi ha hagut un error al servidor.';
$messages['deactivated'] = 'Filtre(s) desactivat(s) correctament.';
$messages['activated'] = 'Filtre(s) activat(s) correctament.';
$messages['moved'] = 'S\'ha mogut correctament el filtre.';
$messages['moveerror'] = 'No s\'ha pogut moure el filtre seleccionat. Hi ha hagut un error al servidor.';
$messages['nametoolong'] = 'El nom és massa llarg.';
$messages['namereserved'] = 'Nom reservat.';
$messages['setexist'] = 'El conjunt ja existeix.';
$messages['nodata'] = 'S\'ha de seleccionar com a mínim una posició!';
$messages['invaliddateformat'] = 'data no vàlida o format no vàlid';
$messages['saveerror'] = 'No s\'han pogut desar les dades. Hi ha hagut un error al servidor.';
$messages['vacationsaved'] = 'Dades de \'fora de l\'oficina\' desades correctament.';
$messages['forwardsaved'] = 'Dades de reenviament desades correctament.';
$messages['emptyvacationbody'] = 'És obligatori definir el cos del missatge de vacances';
$messages['duplicate.conflict.err'] = 'L\'encapçalament i l\'identificador únic a la vegada no estan permesos.';
$messages['disabledaction'] = 'Acció no permesa.';
$messages['lastindexempty'] = 'És necessari l\'índex quan es compta des del final';
$messages['noflagset'] = 'Cal seleccionar almenys una marca.';
