<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail ACL plugin                 |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/plugin-acl/
*/

$labels['sharing'] = 'ھەمبەھىرلەش';
$labels['myrights'] = 'ئىشلىتىش ھوقوقلىرى';
$labels['username'] = 'ئىشلەتكۈچى:';
$labels['advanced'] = 'ئالىي ھالەت';
$labels['add'] = 'قۇشۇش';
$labels['newuser'] = 'قۇر قېتىش';
$labels['editperms'] = 'ئىجازەتلەرنى تەھرىرلەش';
$labels['actions'] = 'كىرىش ھوقوقى ھەركەتلىرى';
$labels['anyone'] = 'ھەممە ئىشلەتكۈچىلەر (ھەرقانداق ئادەم)';
$labels['anonymous'] = 'مىھمان (نامسىز)';
$labels['identifier'] = 'بېكىتكۈچ';
$labels['acll'] = 'قاراش';
$labels['aclr'] = 'خەتلەرنى ئۇقۇش';
$labels['acls'] = 'ئۇقۇغان ھالىتىنى ساقلاش';
$labels['aclw'] = 'بايراقلىرى قىستۇرۇش';
$labels['acli'] = 'كىرگۈزۈش (كۆچۈرۈلگەن)';
$labels['aclp'] = 'ئېلان قىلىش';
$labels['aclc'] = 'بالا-قىسقۇچ قۇرۇش';
$labels['aclk'] = 'بالا-قىسقۇچ قۇرۇش';
$labels['acld'] = 'خەتلەرنى ئۆچۈرۈش';
$labels['aclt'] = 'خەتلەرنى ئۆچۈرۈش';
$labels['acle'] = 'ئۆچۈرۈش';
$labels['aclx'] = 'قىسقۇچنى ئۆچۈرۈش';
$labels['acla'] = 'باشقۇرغۇچى';
$labels['acln'] = 'خەتلەرنى ئىزاھلاش';
$labels['aclfull'] = 'تۇلۇق ھوقوق';
$labels['aclother'] = 'باشقا';
$labels['aclread'] = 'ئۇقۇش';
$labels['aclwrite'] = 'يېزىش';
$labels['acldelete'] = 'ئۆچۈرۈش';
$labels['shortacll'] = 'قاراش';
$labels['shortaclr'] = 'ئۇقۇش';
$labels['shortacls'] = 'ساقلاش';
$labels['shortaclw'] = 'يېزىش';
$labels['shortacli'] = 'كىرگۈزۈش';
$labels['shortaclp'] = 'ئېلان قىلىش';
$labels['shortaclc'] = 'قۇرۇش';
$labels['shortaclk'] = 'قۇرۇش';
$labels['shortacld'] = 'ئۆچۈرۈش';
$labels['shortaclt'] = 'ئۆچۈرۈش';
$labels['shortacle'] = 'ئۆچۈرۈش';
$labels['shortaclx'] = 'قىسقۇچ ئۆچۈرۈش';
$labels['shortacla'] = 'باشقۇرغۇچى';
$labels['shortacln'] = 'ئىزاھلاش';
$labels['shortaclother'] = 'باشقا';
$labels['shortaclread'] = 'ئۇقۇش';
$labels['shortaclwrite'] = 'يېزىش';
$labels['shortacldelete'] = 'ئۆچۈرۈش';
$labels['longacll'] = 'بۇ قىسقۇچ تىزىملىكلەردە كۆرۈنىدۇ ھەمدە مۇشتەرى بولغىلى بۇلىدۇ';
$labels['longaclr'] = 'بۇ قىسقۇچنى ئۇقۇش ئۈچۈن ئاچقىلى بۇلىدۇ';
$labels['longacls'] = 'خەت ئۇقۇغانلىق بايرىقىنى ئۆزگەرتكىلى بۇلىدۇ';
$labels['longaclw'] = 'خەت بايراقلىرى ھەمدە ئاچقۇچلۇق سۆزلەرنى ئۆزگەرتكىلى بۇلىدۇ، كۆرگەن ۋە ئۆچۈرگەندىن باشقىسىنى';
$labels['longacli'] = 'خەتلەرنى يازغىلى ياكى قىسقۇچقا كۆچۈرگىلى بۇلىدۇ';
$labels['longaclp'] = 'خەتلەرنى بۇ قىسقۇچقا ئېلان قىلغىلى بۇلىدۇ';
$labels['longaclc'] = 'قىسقۇچلارنى بۇ قىسقۇچنىڭ ئىچىگە قۇرغىلى (ياكى يېڭى ئىسىم قويغىلى) بۇلىدۇ ';
$labels['longaclk'] = 'قىسقۇچلارنى بۇ قىسقۇچنىڭ ئىچىگە قۇرغىلى (ياكى يېڭى ئىسىم قويغىلى) بۇلىدۇ ';
$labels['longacld'] = 'ئۇچۇر ئۆچۈرگەنلىك بايرىقىنى ئۆزگەرتكىلى بۇلىدۇ';
$labels['longaclt'] = 'خەتنى ئۆچۈرگەنلىك بايرىقىنى ئۆزگەرتكىلى بۇلىدۇ';
$labels['longacle'] = 'خەتنى ئۆچۈرگىلى بۇلىدۇ';
$labels['longaclx'] = 'قىسقۇچنى ئۆچۈرگىلى ياكى يېڭى ئىسىم قويغىلى بۇلىدۇ';
$labels['longacla'] = 'قىسقۇچقا كىرىش ھوقوقىنى ئۆزگەرتكىلى بۇلىدۇ';
$labels['longacln'] = 'خەت ھەمبەھىرلىگەن ئىزاھ ئۇچۇرىنى (ئىزھاتلار) ئۆزگەرتىشكە بۇلىدۇ';
$labels['longaclfull'] = 'قىسقۇچنى باشقۇرۇشنى ئۆز-ئىچىگە ئالغان تۇلۇق ھوقوق';
$labels['longaclread'] = 'بۇ قىسقۇچنى ئۇقۇش ئۈچۈن ئاچقىلى بۇلىدۇ';
$labels['longaclwrite'] = 'خەتنى يازغىلى ياكى بۇ قىسقۇچقا كۆچۈرگىلى ياكى بەلگە قويغىلى بۇلىدۇ';
$labels['longacldelete'] = 'خەتنى ئۆچۈرگىلى بۇلىدۇ';
$labels['longaclother'] = 'باشقا كىرىش ھوقوقلىرى';
$labels['ariasummaryacltable'] = 'كىرىش ھوقوقلىرى تىزىملىكى';
$labels['arialabelaclactions'] = 'ھەركەتلەرنى تىزىش';
$labels['arialabelaclform'] = 'كىرىش ھوقوقلىرى جەدىۋېلى';
$messages['deleting'] = 'كىرىش ھوقوقلىرىنى ئۆچۈرۋاتىدۇ...';
$messages['saving'] = 'كىرىش ھوقوقلىرىنى ساقلاۋاتىدۇ...';
$messages['updatesuccess'] = 'كىرىش ھوقوقلىرىنى ئۆزگەرتىش مۇۋاپىقىيەتلىك بولدى';
$messages['deletesuccess'] = 'كىرىش ھوقوقلىرىنى ئۆچۈرۈش مۇۋاپىقىيەتلىك بولدى';
$messages['createsuccess'] = 'كىرىش ھوقوقلىرىنى قېتىش مۇۋاپىقىيەتلىك بولدى';
$messages['updateerror'] = 'كىرىش ھوقوقلىرىنى يېڭىلاشقا بولمىدى';
$messages['deleteerror'] = 'كىرىش ھوقوقلىرىنى ئۆچۈرۈشكە بولمىدى';
$messages['createerror'] = 'كىرىش ھوقوقلىرىنى قېتىشقا بولمىدى';
$messages['deleteconfirm'] = 'تاللانغان ئىشلەتكۈچى(لەر)نىڭ كىرىش ھوقوقلىرىنى ئۆچۈرۈشنى جەزىملەشتۈرەمسىز؟';
$messages['norights'] = 'ھېچقانداق ھوقوق كۆرسىتىلمىدى!';
$messages['nouser'] = 'ھېچقانداق ئىشلەتكۈچى ئىسمى تېپىلمىدى!';
