<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail client                     |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/messages/
*/

$messages['errortitle']  = 'Un error ha occurrite.';
$messages['loginfailed']  = 'Apertura de session fallite.';
$messages['cookiesdisabled'] = 'Vostre navigator non accepta cookies.';
$messages['sessionerror'] = 'Le session es invalide o ha expirate.';
$messages['storageerror'] = 'Le connexion al servitor de immagazinage ha fallite.';
$messages['servererror'] = 'Error de servitor.';
$messages['servererrormsg'] = 'Error de sevitor: $msg';
$messages['accountlocked'] = 'Troppo de tentativas fallite de authentication. Reproba plus tarde.';
$messages['connerror'] = 'Error de connexion (impossibile attinger le servitor).';
$messages['dberror'] = 'Error de base de datos.';
$messages['windowopenerror'] = 'Le fenestra pop-up ha essite blocate.';
$messages['requesttimedout'] = 'Requesta expirate';
$messages['errorreadonly'] = 'Impossibile exequer le operation. Le dossier es in modo lectura sol.';
$messages['errornoperm'] = 'Impossibile exequer le operation. Permission refusate.';
$messages['erroroverquota'] = 'Impossibile exequer le operation. Nulle spatio libere sur disco.';
$messages['erroroverquotadelete'] = 'Nulle spatio libere sur disco. Preme SHIFT+DEL pro deler un message.';
$messages['invalidrequest'] = 'Requesta non valide. Le datos non ha essite salveguardate.';
$messages['invalidhost'] = 'Nomine de servitor non valide.';
$messages['nomessagesfound'] = 'Nulle message trovate in iste cassa postal.';
$messages['mailboxempty'] = 'Le cassa postal es vacue';
$messages['nomessages'] = 'Nulle message';
$messages['refreshing'] = 'A refrescar...';
$messages['loading'] = 'A cargar...';
$messages['uploading'] = 'A incargar un file...';
$messages['attaching'] = 'Attacha file...';
$messages['uploadingmany'] = 'A incargar files...';
$messages['loadingdata'] = 'A cargar datos...';
$messages['checkingmail'] = 'A verificar si il ha nove messages...';
$messages['sendingmessage'] = 'A inviar le message...';
$messages['messagesent'] = 'Message inviate con successo.';
$messages['savingmessage'] = 'A salveguardar le message...';
$messages['messagesaved'] = 'Message salveguardate in "Versiones provisori".';
$messages['successfullysaved'] = 'Salveguardate con successo.';
$messages['savingresponse'] = 'A salveguardar le texto del responsa...';
$messages['deleteresponseconfirm'] = 'Es vos secur de voler deler iste texto de responsa?';
$messages['addedsuccessfully'] = 'Le contacto ha essite addite al adressario.';
$messages['contactexists'] = 'Un contacto con le mesme adresse de e-mail jam existe.';
$messages['contactnameexists'] = 'Un contacto con le mesme nomine jam existe.';
$messages['blockedimages'] = 'Pro proteger vostre vita private, le imagines a distantia es blocate in iste message.';
$messages['encryptedmessage'] = 'Iste message ha essite cryptate e non pote esser monstrate.';
$messages['externalmessagedecryption'] = 'Isto es un message cryptate e pote esser decryptate con tu extension de navigator.';
$messages['nopubkeyfor'] = 'Nulle clave public valide trovate pro $email';
$messages['nopubkeyforsender'] = 'Nulle clave public valide ha essite trovate pro tu identitate de expeditor. Vole tu cryptar le message pro le destinatarios solmente?';
$messages['encryptnoattachments'] = 'Le attachamentos jam incargate non pote esser cryptate. Per favor re-adde los in le editor cryptographic.';
$messages['searchpubkeyservers'] = 'Vole tu cercar le claves mancante in le servitores de claves public?';
$messages['encryptpubkeysfound'] = 'Le sequente claves public ha essite trovate:';
$messages['nocontactsfound'] = 'Nulle contacto trovate.';
$messages['contactnotfound'] = 'Le contacto requestate non ha essite trovate.';
$messages['sendingfailed'] = 'Le invio del message ha fallite.';
$messages['senttooquickly'] = 'Per favor, attende $sec secunda(s) ante inviar iste message.';
$messages['errorsavingsent'] = 'Un error ha occurrite durante le salveguarda del message inviate.';
$messages['errorsaving'] = 'Un error ha occurrite durante le salveguarda.';
$messages['errormoving'] = 'Impossibile displaciar le message(s).';
$messages['errorcopying'] = 'Impossibile copiar le message(s).';
$messages['errordeleting'] = 'Impossibile deler le message(s).';
$messages['errormarking'] = 'Impossibile marcar le message(s).';
$messages['deletecontactconfirm']  = 'Es vos secur de voler deler le contacto(s) seligite?';
$messages['deletegroupconfirm']  = 'Es vos secur de voler deler le gruppo seligite?';
$messages['deletemessagesconfirm'] = 'Es vos secur de voler deler le message(s) seligite?';
$messages['deletefolderconfirm']  = 'Es vos secur de voler deler le dossier seligite?';
$messages['purgefolderconfirm']  = 'Es vos secur de voler deler tote le messages in iste dossier?';
$messages['contactdeleting'] = 'A deler contacto(s)...';
$messages['groupdeleting'] = 'A deler le gruppo...';
$messages['folderdeleting'] = 'A deler le dossier...';
$messages['foldermoving'] = 'A displaciar le dossier...';
$messages['foldersubscribing'] = 'A subscriber se al dossier...';
$messages['folderunsubscribing'] = 'A cancellar le subscription al dossier...';
$messages['formincomplete'] = 'Le formulario non ha essite totalmente completate.';
$messages['noemailwarning'] = 'Per favor, specifica un adresse de e-mail valide.';
$messages['nonamewarning']  = 'Per favor, specifica un nomine.';
$messages['nopagesizewarning'] = 'Per favor, specifica un dimension de pagina.';
$messages['nosenderwarning'] = 'Per favor, specifica le adresse de e-mail del expeditor.';
$messages['norecipientwarning'] = 'Per favor, specifica al minus un destinatario.';
$messages['disclosedrecipwarning'] = 'Tote le destinatarios videra le adresses de e-mail le unes del alteres. Pro impedir isto e proteger lor confidentialitate, usa le campo Bcc.';
$messages['disclosedreciptitle'] = 'Il ha troppo de destinatarios public';
$messages['nosubjectwarning']  = 'Le campo "Subjecto" es vacue. Vole vos specificar un subjecto ora?';
$messages['nosubjecttitle']  = 'Sin subjecto';
$messages['nobodywarning'] = 'Inviar iste message sin texto?';
$messages['notsentwarning'] = 'Le message non ha essite inviate e ha modificationes non salveguardate. Abandonar le modificationes?';
$messages['restoresavedcomposedata'] = 'Un message anteriormente componite ma non inviate ha essite trovate.\n\nSubjecto: $subject\nSalveguardate: $date\n\nVole vos restaurar iste message?';
$messages['nosearchname'] = 'Per favor, specifica le nomine o adresse de e-mail de un contacto.';
$messages['notuploadedwarning'] = 'Non tote le attachamentos ha ancora essite incargate. Per favor, attende o cancella le incargamento.';
$messages['searchsuccessful'] = '$nr messages trovate.';
$messages['contactsearchsuccessful'] = '$nr contactos trovate.';
$messages['searchnomatch'] = 'Le recerca non ha producite resultatos.';
$messages['searching'] = 'A cercar...';
$messages['checking'] = 'A verificar...';
$messages['stillsearching'] = 'A continuar le recerca...';
$messages['nospellerrors'] = 'Nulle error de orthographia trovate.';
$messages['folderdeleted'] = 'Le dossier ha essite delite.';
$messages['foldersubscribed'] = 'Le subscription al dossier ha succedite.';
$messages['folderunsubscribed'] = 'Le subscription al dossier ha essite cancellate.';
$messages['deletedsuccessfully'] = 'Delete con successo.';
$messages['converting'] = 'A remover le formatation...';
$messages['messageopenerror'] = 'Impossibile cargar le message ab le servitor.';
$messages['filelinkerror'] = 'Le attachamento del file ha fallite.';
$messages['fileuploaderror'] = 'Incargamento de file falleva.';
$messages['filesizeerror'] = 'Le file incargate excede le dimension maxime de $size.';
$messages['filecounterror'] = 'Vos pote incargar al maximo $count files simul.';
$messages['msgsizeerror'] = 'Le attachamento de un file ha fallite. Le dimension maxime de un message ($size) ha essite excedite.';
$messages['copysuccess'] = '$nr contactos ha essite copiate.';
$messages['movesuccess'] = '$nr contactos ha essite displaciate.';
$messages['copyerror'] = 'Impossibile copiar le contactos.';
$messages['moveerror'] = 'Impossibile displaciar le contactos.';
$messages['sourceisreadonly'] = 'Iste fonte de adresses es pro lectura solmente.';
$messages['errorsavingcontact'] = 'Impossibile salveguardar le adresse del contacto.';
$messages['movingmessage'] = 'A displaciar le message(s)...';
$messages['copyingmessage'] = 'A copiar le message(s)...';
$messages['copyingcontact'] = 'A copiar le contacto(s)...';
$messages['movingcontact'] = 'A mover le contacto(s)...';
$messages['deletingmessage'] = 'A deler le message(s)...';
$messages['markingmessage'] = 'A marcar le message(s)...';
$messages['addingmember'] = 'A adder contacto(s) al gruppo...';
$messages['removingmember'] = 'A remover contacto(s) del gruppo...';
$messages['receiptsent'] = 'Un confirmation de lectura ha essite inviate.';
$messages['errorsendingreceipt'] = 'Impossibile inviar le confirmation.';
$messages['deleteidentityconfirm'] = 'Es vos secur de voler deler iste identitate?';
$messages['nodeletelastidentity'] = 'Vos non pote deler iste identitate; illo es vostre ultime.';
$messages['forbiddencharacter'] = 'Le nomine del dossier contine un character interdicte.';
$messages['selectimportfile'] = 'Per favor tu selige le file a incargar.';
$messages['addresswriterror'] = 'Le adressario seligite non permitte le scriptura.';
$messages['contactaddedtogroup'] = 'Le contactos ha essite addite a iste gruppo.';
$messages['contactremovedfromgroup'] = 'Le contactos ha essite removite de iste gruppo.';
$messages['nogroupassignmentschanged'] = 'Nulle assignation de gruppo ha essite cambiate.';
$messages['importwait'] = 'A importar, un momento...';
$messages['importformaterror'] = 'Importation fallite. Le file incargate non es un file de datos de importation valide.';
$messages['importconfirm'] = '<b>$inserted contactos ha essite importate</b>';
$messages['importconfirmskipped'] = '<b>$skipped entratas existente ha essite saltate</b>';
$messages['importmessagesuccess'] = '$nr messages ha essite importate';
$messages['importmessageerror'] = 'Importation fallite. Le file incargate non es un file de cassa postal o message valide.';
$messages['opnotpermitted'] = 'Operation non permittite.';
$messages['nofromaddress'] = 'Le adresse de e-mail manca in le identitate seligite.';
$messages['editorwarning'] = 'Si vos cambia de typo de editor, le formato del texto pote esser perdite. Desira vos continuar?';
$messages['httpreceivedencrypterror'] = 'Un error fatal de configuration ha occurrite. Contacta immediatemente vostre administrator.<b>Vostre message non pote esser inviate.</b>';
$messages['smtpconnerror'] = 'Error SMTP ($code): Le connexion al servitor ha fallite.';
$messages['smtpautherror'] = 'Error SMTP ($code): Authentication fallite.';
$messages['smtpfromerror'] = 'Error SMTP ($code): Impossibile fixar le expeditor "$from" ($msg).';
$messages['smtptoerror'] = 'Error SMTP ($code): Impossibile adder le destinatario "$to" ($msg).';
$messages['smtprecipientserror'] = 'Error SMTP: Impossibile interpretar le lista de destinatarios.';
$messages['smtpsizeerror'] = 'Error de SMTP: Le grandor del message excede le limite del servitor ($limit)';
$messages['smtperror'] = 'Error SMTP: $msg';
$messages['emailformaterror'] = 'Adresse de e-mail invalide: $email';
$messages['toomanyrecipients'] = 'Troppo de destinatarios. Reduce le numero de destinatarios a $max.';
$messages['maxgroupmembersreached'] = 'Le numero de membros del gruppo excede le maximo de $max.';
$messages['internalerror'] = 'Un error interne ha occurrite. Per favor, essaya lo de novo.';
$messages['contactdelerror'] = 'Impossibile deler le contacto(s).';
$messages['contactdeleted'] = 'Le contacto(s) ha essite delite.';
$messages['contactrestoreerror'] = 'Impossibile restaurar le contacto(s) delite.';
$messages['contactrestored'] = 'Le contacto(s) ha essite restaurate.';
$messages['groupdeleted'] = 'Le gruppo ha essite delite.';
$messages['grouprenamed'] = 'Le gruppo ha essite renominate.';
$messages['groupcreated'] = 'Le gruppo ha essite create.';
$messages['savedsearchdeleted'] = 'Le recerca salveguardate ha essite delite.';
$messages['savedsearchdeleteerror'] = 'Impossibile deler le recerca salveguardate.';
$messages['savedsearchcreated'] = 'Le recerca salveguardate ha essite create.';
$messages['savedsearchcreateerror'] = 'Impossibile crear le recerca salveguardate.';
$messages['messagedeleted'] = 'Le message(s) ha essite delite.';
$messages['messagemoved'] = 'Le message(s) ha essite displaciate.';
$messages['messagemovedtotrash'] = 'Le message(s) ha essite displaciate al corbe a papiro con successo.';
$messages['messagecopied'] = 'Le message(s) ha essite copiate.';
$messages['messagemarked'] = 'Le message(s) ha essite marcate.';
$messages['autocompletechars'] = 'Specifica al minus $min characteres pro autocompletion.';
$messages['autocompletemore'] = 'Plure entratas corresponde. Per favor, specifica plus characteres.';
$messages['namecannotbeempty'] = 'Le nomine non pote esser vacue.';
$messages['nametoolong'] = 'Le nomine es troppo longe.';
$messages['namedotforbidden'] = 'Le nomine del dossier non pote comenciar per un puncto.';
$messages['folderupdated'] = 'Le dossier ha essite actualisate.';
$messages['foldercreated'] = 'Le dossier ha essite create.';
$messages['invalidimageformat'] = 'Non es un formato de imagine valide.';
$messages['mispellingsfound'] = 'Errores de orthographia ha essite detegite in le message.';
$messages['parentnotwritable'] = 'Impossibile crear/displaciar le dossier in le dossier genitor seligite. Nulle permission de accesso.';
$messages['messagetoobig'] = 'Le parte del message es troppo grande pro tractar lo.';
$messages['noscriptwarning'] = 'Attention: Iste servicio webmail require JavaScript. Pro usar lo, per favor activa JavaScript in le configuration de vostre navigator.';
$messages['messageissent'] = 'Le message ha jam essite inviate ma non ancora salveguardate. Vole tu salveguardar lo ora?';
$messages['errnotfound'] = 'File non trovate';
$messages['errnotfoundexplain'] = 'Le ressource requestate non ha essite trovate.';
$messages['errfailedrequest'] = 'Requesta fallite';
$messages['errauthorizationfailed'] = 'Autorisation fallite';
$messages['errunauthorizedexplain'] = 'Non poteva verificar que tu es autorisate a acceder a iste servicio.';
$messages['errrequestcheckfailed'] = 'Verification del requesta fallite';
$messages['errcsrfprotectionexplain'] = "Pro vostre protection, le accesso a iste ressource ha essite securisate contra le falsification de requestas inter sitos (CSRF).\nSi vos vide isto, vos probabilemente non ha claudite session ante de quitar le application web.\n\nOra, un interaction human es requirite pro continuar.";
$messages['errcontactserveradmin'] = 'Per favor contacta le administrator de tu servitor.';
$messages['clicktoresumesession'] = 'Clicca hic pro continuar tu session anterior';
$messages['errcomposesession'] = 'Error del session de composition';
$messages['errcomposesessionexplain'] = 'Session de composition requestate non ha essite trovate.';
$messages['clicktocompose'] = 'Clicca hic pro componer un nove message';
