<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail ACL plugin                 |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/plugin-acl/
*/

$labels['sharing'] = 'Bo‘lishish';
$labels['myrights'] = 'Kirish huquqlari';
$labels['username'] = 'Foydalanuvchi:';
$labels['advanced'] = 'Kengaytirilgan rejim';
$labels['add'] = 'Qo`shish';
$labels['newuser'] = 'Qo‘shish';
$labels['editperms'] = 'Ruxsatlarni tahrirlash';
$labels['actions'] = 'Kirish huquqi harakatlari';
$labels['anyone'] = 'Barcha foydalanuvchilar (hamma)';
$labels['anonymous'] = 'Mehmonlar (anonim)';
$labels['identifier'] = 'Identifikatsiya';
$labels['acll'] = 'Qidirish';
$labels['aclr'] = 'Xatlarni o‘qish';
$labels['acli'] = 'Kiritish (...ga nusxalash)';
$labels['aclp'] = 'Xat';
$labels['aclc'] = 'Ichki papkalarni yaratish';
$labels['aclk'] = 'Ichki papkalarni yaratish';
$labels['acld'] = 'Xabarlarni o‘chirish';
$labels['aclt'] = 'Xabarlarni o‘chirish';
$labels['aclx'] = 'Papkani o‘chirish';
$labels['aclother'] = 'Boshqa';
$labels['aclread'] = 'O`qilgan';
$labels['acldelete'] = 'O`chirish';
$labels['shortacll'] = 'Qidirish';
$labels['shortaclr'] = 'O`qilgan';
$labels['shortaclp'] = 'Xat';
$labels['shortaclc'] = 'Yaratish';
$labels['shortaclk'] = 'Yaratish';
$labels['shortacld'] = 'O`chirish';
$labels['shortaclt'] = 'O`chirish';
$labels['shortaclother'] = 'Boshqa';
$labels['shortaclread'] = 'O`qilgan';
$labels['shortacldelete'] = 'O`chirish';
