<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail client                     |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/messages/
*/

$messages['errortitle']  = 'Ocurreu un erro!';
$messages['loginfailed']  = 'O contrasinal ou o nome de utente son incorrectos.';
$messages['cookiesdisabled'] = 'O teu navegador non acepta cookies.';
$messages['sessionerror'] = 'A tú sesión non é válida ou expirou.';
$messages['storageerror'] = 'Fallou a conexión co servidor IMAP.';
$messages['servererror'] = 'Erro do servidor!';
$messages['servererrormsg'] = 'Erro do servidor: $msg';
$messages['connerror'] = 'Fallou a conexión co servidor!';
$messages['dberror'] = 'Erro na base de datos!';
$messages['windowopenerror'] = 'Bloquouse a fiestra emerxente!';
$messages['requesttimedout'] = 'A petición expirou';
$messages['errorreadonly'] = 'Non foi posíbel realizar a operación. O cartafol é de só lectura.';
$messages['errornoperm'] = 'Non foi posíbel realizar a operación. Permiso denegado.';
$messages['erroroverquota'] = 'Non se pode realizar a operación, non hai espazo no disco.';
$messages['erroroverquotadelete'] = 'Non hai espazo no disco. Usa Maiúsculas+Supr para borrar unha mensaxe.';
$messages['invalidrequest'] = 'Petición non válida! Non se gardou ningún dato.';
$messages['invalidhost'] = 'O nome do servidor non é válido.';
$messages['nomessagesfound'] = 'Non se atoparon mensaxes nesta caixa de correo.';
$messages['mailboxempty'] = 'O cartafol está baleiro';
$messages['nomessages'] = 'Non hai mensaxes';
$messages['refreshing'] = 'A refrescar...';
$messages['loading'] = 'Cargando...';
$messages['uploading'] = 'Cargando ficheiro...';
$messages['uploadingmany'] = 'Cargando ficheiros...';
$messages['loadingdata'] = 'Cargando datos...';
$messages['checkingmail'] = 'Á procura de novas mensaxes...';
$messages['sendingmessage'] = 'Enviando mensaxe...';
$messages['messagesent'] = 'A mensaxe enviouse correctamente.';
$messages['savingmessage'] = 'Gardando mensaxe...';
$messages['messagesaved'] = 'A mensaxe gardouse en "Borradores"';
$messages['successfullysaved'] = 'Gardado correctamente.';
$messages['savingresponse'] = 'Gardar texto de resposta...';
$messages['deleteresponseconfirm'] = 'Realmente queres borrar este texto de resposta?';
$messages['addedsuccessfully'] = 'O contacto engadiuse correctamente á Axenda de enderezos.';
$messages['contactnameexists'] = 'Xa existe un contacto con este nome.';
$messages['blockedimages'] = 'Estanse a bloquear as imaxes remotas para protexer a túa privacidade.';
$messages['encryptedmessage'] = 'Sentímolo! Non se pode amosar a mensaxe porque está cifrada.';
$messages['nocontactsfound'] = 'Non se atoparon contactos.';
$messages['contactnotfound'] = 'Non se atopou o contacto solicitado.';
$messages['sendingfailed'] = 'Fallou o envío da mensaxe.';
$messages['senttooquickly'] = 'Por favor, espera $sec segundos antes de enviar esta mensaxe.';
$messages['errorsavingsent'] = 'Houbo un erro ao gardar a mensaxe enviada.';
$messages['errorsaving'] = 'Houbo un erro ao gardar.';
$messages['errormoving'] = 'Non foi posíbel mover a(s) mensaxe(s).';
$messages['errorcopying'] = 'Non foi posíbel copiar a(s) mensaxe(s).';
$messages['errordeleting'] = 'Non foi posíbel eliminar a(s) mensaxe(s).';
$messages['errormarking'] = 'Non foi posíbel marcar a(s) mensaxe(s).';
$messages['deletecontactconfirm']  = 'Queres eliminar o(s) contacto(s) seleccionado(s)?';
$messages['deletegroupconfirm']  = 'Queres eliminar o grupo seleccionado?';
$messages['deletemessagesconfirm'] = 'Queres eliminar a(s) mensaxe(s) seleccionadas?';
$messages['deletefolderconfirm']  = 'Queres eliminar este cartafol?';
$messages['purgefolderconfirm']  = 'Queres eliminar todas as mensaxes neste cartafol?';
$messages['contactdeleting'] = 'Eliminando o(s) contacto(s)...';
$messages['groupdeleting'] = 'Eliminando o grupo...';
$messages['folderdeleting'] = 'Eliminando o cartafol...';
$messages['foldermoving'] = 'Movendo o cartafol...';
$messages['foldersubscribing'] = 'Subscribindo o cartafol...';
$messages['folderunsubscribing'] = 'Desubscribindo o cartafol...';
$messages['formincomplete'] = 'O formulario non foi completamente cuberto.';
$messages['noemailwarning'] = 'Por favor, engade un enderezo de correo electrónico válido.';
$messages['nonamewarning']  = 'Por favor, engade un nome.';
$messages['nopagesizewarning'] = 'Por favor, engade un tamaño de páxina.';
$messages['norecipientwarning'] = 'Por favor, engade polo menos unha persoa destinataria.';
$messages['nosubjectwarning']  = 'O campo "Asunto" está baleiro. Queres completalo?';
$messages['nobodywarning'] = 'Queres enviar esta mensaxe sen texto?';
$messages['restoresavedcomposedata'] = 'Foi atopada unha mensaxe que non se enviara.\n\nSubject: $subject\nSaved: $date\n\n¿queres restaurar esta mensaxe?';
$messages['nosearchname'] = 'Por favor, engade un nome ou un enderezo de correo electrónico.';
$messages['notuploadedwarning'] = 'Aínda non se cargaron tódolos ficheiros. Por favor, agarde ou cancele a carga.';
$messages['searchsuccessful'] = 'Atopáronse $nr mensaxes.';
$messages['contactsearchsuccessful'] = 'Atopáronse $nr contactos.';
$messages['searchnomatch'] = 'A busca non atopou coincidencias.';
$messages['searching'] = 'Buscando...';
$messages['checking'] = 'Comprobando...';
$messages['stillsearching'] = 'Buscando...';
$messages['nospellerrors'] = 'Non hai erros ortográficos.';
$messages['folderdeleted'] = 'O cartafol foi eliminado correctamente.';
$messages['foldersubscribed'] = 'O cartafol subscribiuse correctamente.';
$messages['folderunsubscribed'] = 'O cartafol desubscribiuse correctamente.';
$messages['deletedsuccessfully'] = 'Eliminouse correctamente.';
$messages['converting'] = 'Eliminando o formato da mensaxe...';
$messages['messageopenerror'] = 'Non foi posíbel cargar a mensaxe desde o servidor.';
$messages['fileuploaderror'] = 'Fallou a carga do ficheiro.';
$messages['filesizeerror'] = 'O ficheiro cargado é máis grande que o tamaño máximo de $size.';
$messages['copysuccess'] = 'Copiáronse correctamente $nr contactos.';
$messages['movesuccess'] = 'Movidos con suceso $nr contactos.';
$messages['copyerror'] = 'Non foi posíbel copiar contactos.';
$messages['moveerror'] = 'Non foi posíbel mover contactos.';
$messages['sourceisreadonly'] = 'Este enderezo de orixe é de só lectura.';
$messages['errorsavingcontact'] = 'Non foi posíbel gardar o contacto.';
$messages['movingmessage'] = 'Movendo a(s) mensaxe(s)...';
$messages['copyingmessage'] = 'Copiando a(s) mensaxe(s)...';
$messages['copyingcontact'] = 'Copiando o(s) contacto(s)...';
$messages['movingcontact'] = 'Movendo contacto(s)...';
$messages['deletingmessage'] = 'Eliminando a(s) mensaxe(s)...';
$messages['markingmessage'] = 'Marcando a(s) mensaxe(s)...';
$messages['addingmember'] = 'Engadindo o(s) contacto(s) ao grupo...';
$messages['removingmember'] = 'Eliminando o(s) contacto(s) do grupo...';
$messages['receiptsent'] = 'A notificación da entrega enviouse correctamente.';
$messages['errorsendingreceipt'] = 'Non foi posíbel enviar a notificación da entrega.';
$messages['deleteidentityconfirm'] = 'Queres eliminar esta identidade?';
$messages['nodeletelastidentity'] = 'Non podes eliminar esta identidade, é a última.';
$messages['forbiddencharacter'] = 'O nome do cartafol contén un caracter non válido.';
$messages['selectimportfile'] = 'Por favor, escolle un ficheiro para cargar.';
$messages['addresswriterror'] = 'Non se pode escribir na Axenda de enderezos que escolleches.';
$messages['contactaddedtogroup'] = 'Engadiuse correctamente o contacto a este grupo.';
$messages['contactremovedfromgroup'] = 'Suprimiuse correctamente o contacto deste grupo.';
$messages['nogroupassignmentschanged'] = 'Non cambiou ningunha asignación de grupo.';
$messages['importwait'] = 'A importar. Por favor, agarda...';
$messages['importformaterror'] = 'Fallou a importación! O ficheiro cargado non contén datos válidos.';
$messages['importconfirm'] = '<b>Importáronse correctamente $inserted contactos</b>';
$messages['importconfirmskipped'] = '<b>Ignoráronse $skipped existing entradas</b>';
$messages['importmessagesuccess'] = 'Importadas $nr mensaxes con éxito';
$messages['importmessageerror'] = 'Fallou a importación! O arquivo subido non é unha mensaxe válida ou un ficheiro de correo';
$messages['opnotpermitted'] = 'Operación non permitida!';
$messages['editorwarning'] = 'Se troca neste intre ao editor de texto plano, vai perder todo o formato do texto. Quere continuar?';
$messages['httpreceivedencrypterror'] = 'Produciuse un erro fatal de configuración. Contacta coa persoa administradora inmediatamente. <b>Non se enviou a túa mensaxe.</b>';
$messages['smtpconnerror'] = 'Erro SMTP ($code): Fallou a conexión co servidor.';
$messages['smtpautherror'] = 'Erro SMTP ($code): Fallou a autenticación.';
$messages['smtpfromerror'] = 'Erro SMTP ($code): Non foi posíbel estabelecer o remite "$from" ($msg).';
$messages['smtptoerror'] = 'Erro SMTP ($code): Non foi posíbel engadir a persoa destinataria "$to" ($msg).';
$messages['smtprecipientserror'] = 'Erro SMTP: Non se pode analizar a lista de persoas destinatarias.';
$messages['smtperror'] = 'Erro SMTP: $msg';
$messages['toomanyrecipients'] = 'Especificou persoas destinatarias de máis. Por favor, redúceas a un máximo de $max.';
$messages['maxgroupmembersreached'] = 'O número de integrantes do grupo excede o máximo de $max.';
$messages['internalerror'] = 'Produciuse un erro interno. Por favor, téntao de novo.';
$messages['contactdelerror'] = 'Non foi posíbel eliminar o(s) contacto(s).';
$messages['contactdeleted'] = 'Borráronse correctamente o(s) contacto(s).';
$messages['contactrestoreerror'] = 'Non foi posíbel restaurar o(s) contacto(s) borrado(s).';
$messages['contactrestored'] = 'Restauráronse correctamente o(s) contacto(s).';
$messages['groupdeleted'] = 'Borrouse correctamente o grupo.';
$messages['grouprenamed'] = 'Mudouse correctamente o nome do grupo.';
$messages['groupcreated'] = 'Creouse correctamente o grupo.';
$messages['savedsearchdeleted'] = 'Borrouse correctamente a busca gardada.';
$messages['savedsearchdeleteerror'] = 'Non foi posíbel eliminar a busca gardada.';
$messages['savedsearchcreated'] = 'Creouse correctamente a busca gardada.';
$messages['savedsearchcreateerror'] = 'Non foi posíbel crear a busca gardada.';
$messages['messagedeleted'] = 'Borráronse correctamente a(s) mensaxe(s).';
$messages['messagemoved'] = 'Movéronse correctamente a(s) mensaxe(s).';
$messages['messagecopied'] = 'Copiáronse correctamente a(s) mensaxe(s).';
$messages['messagemarked'] = 'Marcáronse correctamente a(s) mensaxe(s).';
$messages['autocompletechars'] = 'Engade polo menos $min caracteres para autocompletar.';
$messages['autocompletemore'] = 'Atopáronse máis entradas concidintes. Por favor, engade máis caracteres.';
$messages['namecannotbeempty'] = 'O nome non pode estar baleiro.';
$messages['nametoolong'] = 'O nome é longo de máis.';
$messages['folderupdated'] = 'O cartafol actualizouse correctamente.';
$messages['foldercreated'] = 'O cartafol creouse correctamente.';
$messages['invalidimageformat'] = 'O formato da imaxe non é válido.';
$messages['mispellingsfound'] = 'Atopáronse erros ortográficos na mensaxe.';
$messages['parentnotwritable'] = 'Non foi posíbel crear/mover o cartafol para o cartafol principal que selecionaches porque non tes permisos.';
$messages['messagetoobig'] = 'A mensaxe é demasiado grande para procesala';
$messages['noscriptwarning'] = 'Atención: Este servicio de correo web precisa de Javascript!. Por favor, active javascript nas opción do seu navegador.';
