<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail client                     |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/messages/
*/

$messages['errortitle']  = 'Ein feilur kom fyri!';
$messages['loginfailed']  = 'Feilur í innriting.';
$messages['cookiesdisabled'] = 'Kagi tín noktar cookies.';
$messages['sessionerror'] = 'Seta tín er ógyldig ella útgingin.';
$messages['cookiesmismatch'] = 'Tú hevur nú rita út. Farvæl!';
$messages['storageerror'] = 'Feilur í samand til goymslu ambatara.';
$messages['servererror'] = 'Ambatara Feilur!';
$messages['servererrormsg'] = 'Ambatara Feilur: $msg';
$messages['accountlocked'] = 'Ov nógvar innritingar royndir. Royn aftur seinni.';
$messages['connerror'] = 'Ambætarasambindingar feilur (Einki samband við abmætaran)!';
$messages['dberror'] = 'Dátugrun Feilur';
$messages['windowopenerror'] = 'Popup vindeyga var forða!';
$messages['requesttimedout'] = 'Umbøn gekk út';
$messages['errorreadonly'] = 'Kann ikki fremja ger. Mappan kann einans lesast.';
$messages['errornoperm'] = 'Kann ikki fremja ger. Atgongd nokta.';
$messages['erroroverquota'] = 'Kann ikki fremja ger. Einki pláss á diski.';
$messages['erroroverquotadelete'] = 'Einki pláss á diski. Brúka SHIFT+DEL fyri at strika boð.';
$messages['invalidrequest'] = 'Ógyldig umbøn! Einki dáta varð goymt.';
$messages['invalidhost'] = 'Ógyldigt ambatara navn.';
$messages['nomessagesfound'] = 'Eingi boð í funnin hesum postkassa,';
$messages['mailboxempty'] = 'Postkassi er tómur';
$messages['nomessages'] = 'Eingin boð';
$messages['refreshing'] = 'Endur-innlesur...';
$messages['loading'] = 'Innlesur...';
$messages['uploading'] = 'Leggur fílu út...';
$messages['attaching'] = 'Viðheftur fíl...';
$messages['uploadingmany'] = 'Leggur fílur út...';
$messages['loadingdata'] = 'Innlesur dáta...';
$messages['checkingmail'] = 'Kannar fyri nýggj boð...';
$messages['sendingmessage'] = 'Sendur boð...';
$messages['messagesent'] = 'Boðini vóru send.';
$messages['savingmessage'] = 'Goymur boðini.';
$messages['messagesaved'] = 'Boðini goymd til Skitsur';
$messages['successfullysaved'] = 'Goymt.';
$messages['savingresponse'] = 'Goymur svar tekst...';
$messages['deleteresponseconfirm'] = 'Vilt tú veruliga strika hendan svar tekst?';
$messages['addedsuccessfully'] = 'Persónur lagdur aftrat búðstaðar savn.';
$messages['contactexists'] = 'Ein persónur við sama telduposti er longu til.';
$messages['contactnameexists'] = 'Ein persónur við sama navn er longu til.';
$messages['blockedimages'] = 'Fyri at verja tín privatlív so eru fjarmyndir sperraðar í hesum boði.';
$messages['encryptedmessage'] = 'Hetta er eini brogla boð og kann ikki sýnast. Tíverri!';
$messages['externalmessagedecryption'] = 'Hetta eru eini brongla boð. Boðini kunnu óbronglast við einum "browser extension"';
$messages['nopubkeyfor'] = 'Eingin gildur almennur lykil, eisini kalla "public key", var funnin, fyri teldupost bústaðin $email';
$messages['nopubkeyforsender'] = 'Eingin gildur almenna lykil var funnin fyri tín sendara samleika. Vilt tú brongla boðini fyri mótakaran einans?';
$messages['encryptnoattachments'] = 'Tær longu viðheftu fílirnir, kunnu ikki bronglast. Vinarliga set teir inn av nýggjum.';
$messages['searchpubkeyservers'] = 'Vilt tú leita í almennum datagrunnum eftir manglandi lyklum?';
$messages['encryptpubkeysfound'] = 'Teir fylgjandi almennalyklar vóru funnir:';
$messages['keyservererror'] = 'Feilur at heinta lykil frá lyklaambætara';
$messages['nocontactsfound'] = 'Eingir persónar funnir.';
$messages['contactnotfound'] = 'Umbindni persónurin varð ikki funnin.';
$messages['sendingfailed'] = 'Riggaði ikki at senda boð.';
$messages['senttooquickly'] = 'Vinarliga bíða $sec sekund(ir) áðrenn tú sendur hetta boð.';
$messages['errorsavingsent'] = 'Ein feilur kom fyri tá ið roynt var at goyma send boð.';
$messages['errorsaving'] = 'Ein feilur kom fyri tá ið goymt var.';
$messages['errormoving'] = 'Kundi ikki flyta boð(ini).';
$messages['errorcopying'] = 'Kundi ikki avrita boð(ini).';
$messages['errordeleting'] = 'Kundi ikki strika boð(ini).';
$messages['errormarking'] = 'Kundi ikki merkja boð(ini).';
$messages['alerttitle'] = 'Gev gætur';
$messages['confirmationtitle'] = 'Ert tú vís/ur';
$messages['deletecontactconfirm']  = 'Ert tú vísur í at tú vilt strika merkt(ar) persónar?';
$messages['deletegroupconfirm']  = 'Ert tú vísur í at tú vilt strika valda bólk?';
$messages['deletemessagesconfirm'] = 'Ert tú vísur í at tú vilt strika vald boð()?';
$messages['deletefolderconfirm']  = 'Ert tú vísur í at tú vilt strika hesa mappu?';
$messages['movefolderconfirm']  = 'Vilt tú veruliga flyta hesa mappu?';
$messages['purgefolderconfirm']  = 'Ert tú vísur í at tú vilt strika øll boð í hesu mappu?';
$messages['contactdeleting'] = 'Strikar persón(ar)...';
$messages['groupdeleting'] = 'Strikar bólk...';
$messages['folderdeleting'] = 'Strikar mappu...';
$messages['foldermoving'] = 'Flytur mappu...';
$messages['foldersubscribing'] = 'Tegnar til mappu...';
$messages['folderunsubscribing'] = 'Ógyldar tekning til mappu...';
$messages['formincomplete'] = 'Allir teigirnir vóru ikki fyltir út.';
$messages['noemailwarning'] = 'Vinarliga skriva ein galdandi teldupost.';
$messages['nonamewarning']  = 'Vinarliga skriva eitt navn.';
$messages['nopagesizewarning'] = 'Vinarliga skriva síðu stødd.';
$messages['nosenderwarning'] = 'Vinarliga skriva sendara teldupost búðstað.';
$messages['norecipientwarning'] = 'Vinarliga skriva minst ein móttakara.';
$messages['nosubjectwarning']  = 'Evna teigurin er tómur. Vilt tú skriva nakað í hann?';
$messages['nobodywarning'] = 'Send hesi boð uttan tekst?';
$messages['restoresavedcomposedata'] = 'Eitt fyrrverandi skriva boð, men ósent, boð var funni.\n\nEvni: $subject\nGoymt: $date\n\nVilt tú endur stovna hetta boð?';
$messages['nosearchname'] = 'Vinarliga skriva eitt persón navn ella teldupost búðstað,';
$messages['notuploadedwarning'] = 'Ikki allar viðheftingar eru uppsendar enn. Vinarliga bíða ella angra uppsendingina.';
$messages['searchsuccessful'] = '$nr boð funnin.';
$messages['contactsearchsuccessful'] = '$nr persónar funnir.';
$messages['searchnomatch'] = 'Leiting gav eingin úrslit.';
$messages['searching'] = 'Leitar...';
$messages['checking'] = 'Kannar...';
$messages['stillsearching'] = 'Leitar enn...';
$messages['nospellerrors'] = 'Eingin stavifeilur funnin.';
$messages['folderdeleted'] = 'Mappa sletta.';
$messages['foldersubscribed'] = 'Mappa tekna til.';
$messages['folderunsubscribed'] = 'Ógylt tekning til mappu.';
$messages['deletedsuccessfully'] = 'Strika uftan feilir.';
$messages['converting'] = 'Tekur burt forsniðing...';
$messages['messageopenerror'] = 'Kundi ikki lesa inn boð frá servara.';
$messages['filelinkerror'] = 'Feilur kom í, tá roynt var at viðhefta fíl.';
$messages['fileuploaderror'] = 'Fíla uppsending riggaði ikk.';
$messages['filesizeerror'] = 'Uppsendi fílur er stórri enn grensan ið er $size.';
$messages['copysuccess'] = 'Avrita $nr persónar.';
$messages['movesuccess'] = 'Flutt $nr persónar.';
$messages['copyerror'] = 'Kundi ikki avrita persónar.';
$messages['moveerror'] = 'Kundi ikki flyta persónar.';
$messages['sourceisreadonly'] = 'Hendan búðstaðar keldan er einans lesandi.';
$messages['errorsavingcontact'] = 'Kann ikki goyma addressuna hjá persóni.';
$messages['movingmessage'] = 'Flytur hetta(hesi) boð...';
$messages['copyingmessage'] = 'Flytur hetta(hesi) boð...';
$messages['copyingcontact'] = 'Avritar persón(ar)...';
$messages['movingcontact'] = 'Flytur persón(ar)...';
$messages['deletingmessage'] = 'Strikar boð(ini)...';
$messages['markingmessage'] = 'Merkjur boð(ini)...';
$messages['addingmember'] = 'Leggur persón(ar) aftrat bólk...';
$messages['removingmember'] = 'Strikar persón(ar) frá bólkið...';
$messages['receiptsent'] = 'Kvittan er sent.';
$messages['errorsendingreceipt'] = 'Kundi ikki senda kvittan.';
$messages['deleteidentityconfirm'] = 'Ert tú vísur í at tú vilt strika hendan samleika?';
$messages['nodeletelastidentity'] = 'Tú kanst ikki strika hendan samleika, hetta er tann seinasti.';
$messages['forbiddencharacter'] = 'Mappu navn inniheldur óloyvd tekin.';
$messages['selectimportfile'] = 'Vinarliga vel eina fílu';
$messages['addresswriterror'] = 'Valda búðstaðar bók kann ikki skrivast í.';
$messages['contactaddedtogroup'] = 'Persónar vóru lagdir aftrat bólki.';
$messages['contactremovedfromgroup'] = 'Persónar vóru strikaðir frá bólki';
$messages['nogroupassignmentschanged'] = 'Eingin bólka tilluting broytt.';
$messages['importwait'] = 'Flytur inn, vinarliga bíða...';
$messages['importformaterror'] = 'Innflyting riggaði ikki! Tann uppsendi fílurin var ikki gyldigur dátu fílur.';
$messages['importconfirm'] = '<b>$inserted Persónar innfluttir</b>';
$messages['importconfirmskipped'] = '<b>Leyp um $skipped innsetanir</b>';
$messages['importmessagesuccess'] = 'Innflutt $nr boð.';
$messages['importmessageerror'] = 'Innflyting bar ikki til! Tann uppsendi fílurin er ikki gyldigur boð ella postkassa fílur';
$messages['opnotpermitted'] = 'Ger ikki loyvd!';
$messages['nofromaddress'] = 'Manglar teldupostur í valda samleika.';
$messages['editorwarning'] = 'At broyta rættara, eisini kallað "editor", kann gera at tín tekst formaterring verður burtur. Vilt tú halda á fram?';
$messages['httpreceivedencrypterror'] = 'Ein oyðandi samansetings feilur uppstóð. Vinarliga set teg í samband við umsitaran beinanvegin. <b>Tíni boð kundu ikki sendast.</b>';
$messages['smtpconnerror'] = 'SMTP Feilur ($code): Samband til ambatara riggaði ikki.';
$messages['smtpautherror'] = 'SMTP Feilur ($code): Atgongd nokta.';
$messages['smtpfromerror'] = 'SMTP feilur ($code): Til bar ikki at seta sendarin til "$from" ($msg).';
$messages['smtptoerror'] = 'SMTP feilur ($code): Til bar ikki at nýta móttakarin "$to" ($msg)';
$messages['smtprecipientserror'] = 'SMTP feilur: Til bar ikki at greina móttakara listan.';
$messages['smtperror'] = 'SMTP feilur: $msg';
$messages['emailformaterror'] = 'Ógyldig teldupost búðstaður: $email';
$messages['toomanyrecipients'] = 'Ov nógvir móttakarir. Minka um móttakarum til $max.';
$messages['maxgroupmembersreached'] = 'Nummarið av limum í bólkinum gongur framvið hægsta mark ið er $max.';
$messages['internalerror'] = 'Ein innanhýsis feilur kom fyri. Vinarliga royn aftur.';
$messages['contactdelerror'] = 'Kann ikki strika persón(ar).';
$messages['contactdeleted'] = 'Persón(ar) strikaðir.';
$messages['contactrestoreerror'] = 'Kann ikki endurstovna persón(ar).';
$messages['contactrestored'] = 'Persónur(ar) endurstovnaðir.';
$messages['groupdeleted'] = 'Bólkur strikaður.';
$messages['grouprenamed'] = 'Bólkur umdoyptur.';
$messages['groupcreated'] = 'Bólkur stovnaður';
$messages['savedsearchdeleted'] = 'Goymdar leitingar strikaðar';
$messages['savedsearchdeleteerror'] = 'Kundi ikki strika goymdar leitingar.';
$messages['savedsearchcreated'] = 'Goymdar leitingar stovnaðar.';
$messages['savedsearchcreateerror'] = 'Kundi ikki stovna goymdar leitingar.';
$messages['messagedeleted'] = 'Boð(ini) strika.';
$messages['messagemoved'] = 'Boð(ini) flutt.';
$messages['messagecopied'] = 'Boð(ini) avrita.';
$messages['messagemarked'] = 'Boð(ini) merkt.';
$messages['autocompletechars'] = 'Skriva minst $min tekin fyri sjálvvirkin útfylling riggar.';
$messages['autocompletemore'] = 'Fleiri úrslit funnin. Vinarliga skriva fleiri tekin.';
$messages['namecannotbeempty'] = 'Navn kann ikki verða tómt.';
$messages['nametoolong'] = 'Navnið er ov langt.';
$messages['namedotforbidden'] = 'Navni á einari mappu, kann ikki byrja við punktum.';
$messages['folderupdated'] = 'Mappa dagført.';
$messages['foldercreated'] = 'Mappa stovna.';
$messages['invalidimageformat'] = 'Ikki eitt gyldigt mynda slag.';
$messages['mispellingsfound'] = 'Stavuvillur funnar í tíni boð.';
$messages['parentnotwritable'] = 'Kann ikki flyta/avrita mappu til valda mappu. Eingin atgongu-rættindi.';
$messages['messagetoobig'] = 'Boðini eru ov stór til at handfara.';
$messages['noscriptwarning'] = 'Ávaring: Hendan webmail tænastan krevur Javascript! Um tú vilt nýta hana, so vinarliga tendra Javascript í tínum kaga.';
$messages['messageissent'] = 'Boðini vóru longu send, men ikki goymd enn. Vilt tú goyma tey nú?';
$messages['errnotfound'] = 'Fílurin var ikki funnin';
$messages['errnotfoundexplain'] = 'Tann valda hjálpartól var ikki funnið!';
$messages['errfailedrequest'] = 'Umbønin riggaði ikki';
$messages['errauthorizationfailed'] = 'Góðkenning riggaði ikki';
$messages['errunauthorizedexplain'] = 'Tað bar ikki til at vátta at tú hevur heimild til hesa tænastu!';
$messages['errrequestcheckfailed'] = 'Umbøn kanning ógildig';
$messages['errcsrfprotectionexplain'] = "Fyri tína egnu verju, so er atgongdin til hetta hjálpartól tryggja ímóti CSRF.
Um tú sært hetta. so ritaði tú nokk ikki út áðrenn tú fór frá farritinum.
Menniskja ávirkan er nú kravd fyri at halda áfram.";
$messages['errcontactserveradmin'] = 'Vinarliga set teg í samband við tín ambætara umsitara';
$messages['clicktoresumesession'] = 'Trýst her fyri at forseta tína fyrrverandi setu';
$messages['errcomposesession'] = 'Stovning av setan riggaði ikki';
$messages['errcomposesessionexplain'] = 'Tann umbiðna setan var ikki funnin';
$messages['clicktocompose'] = 'Trýst her fyri at stovna nýggj boð';
