<roundcube:include file="includes/layout.html" />

<h1 class="voice"><roundcube:label name="enigma.importkeys" /></h1>

<div class="formcontent">
	<roundcube:object name="importform" class="propform" part="import" />
</div>

<roundcube:include file="includes/footer.html" />
