<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail client                     |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/messages/
*/

$messages['errortitle']  = '오류가 발생했습니다!';
$messages['loginfailed']  = '로그인이 실패했습니다.';
$messages['cookiesdisabled'] = '브라우저가 쿠키를 허용하지 않습니다.';
$messages['sessionerror'] = '세션이 유효하지 않거나 만료되었습니다.';
$messages['cookiesmismatch'] = '쿠키 불일치를 감지했습니다. 브라우저 쿠키를 지워주세요.';
$messages['storageerror'] = '저장소 서버에 연결을 실패했습니다.';
$messages['servererror'] = '서버 오류!';
$messages['servererrormsg'] = '서버 오류: $msg';
$messages['accountlocked'] = '로그인 시도 횟수를 초과함. 나중에 다시 시도하세요.';
$messages['connerror'] = '연결 오류 (서버 접속 실패)!';
$messages['dberror'] = '데이터베이스 오류!';
$messages['dbconnerror'] = '데이터베이스에 연결할 수 없습니다.';
$messages['windowopenerror'] = '팝업 창이 차단되었습니다!';
$messages['requesttimedout'] = '요청 시간 초과';
$messages['errorreadonly'] = '작업을 수행할 수 없습니다. 읽기 전용 폴더입니다.';
$messages['errornoperm'] = '작업을 수행할 수 없습니다. 권한이 거부되었습니다.';
$messages['erroroverquota'] = '작업을 수행할 수 없습니다. 여유 디스크 공간이 없습니다.';
$messages['erroroverquotadelete'] = '여유 디스크 공간이 없습니다. SHIF+DEL로 메시지를 삭제하세요.';
$messages['invalidrequest'] = '잘못된 요청! 데이터가 저장되지 않았습니다.';
$messages['invalidhost'] = '잘못된 서버 이름입니다.';
$messages['nomessagesfound'] = '이 편지함에서 메시지를 발견하지 못했습니다.';
$messages['loggedout'] = '세션을 성공적으로 종료했습니다. 안녕히 가세요!';
$messages['mailboxempty'] = '편지함이 비어있음';
$messages['nomessages'] = '메시지 없음';
$messages['refreshing'] = '새로고침 중...';
$messages['loading'] = '로딩 중...';
$messages['uploading'] = '파일 업로드 중...';
$messages['attaching'] = '파일 첨부 중...';
$messages['uploadingmany'] = '파일 업로드 중...';
$messages['loadingdata'] = '데이터 로딩 중...';
$messages['checkingmail'] = '새 메시지 확인 중...';
$messages['sendingmessage'] = '메시지 발송 중...';
$messages['messagesent'] = '메시지를 성공적으로 보냈습니다.';
$messages['savingmessage'] = '메시지 저장 중...';
$messages['messagesaved'] = '메시지가 임시 보관함에 저장되었습니다.';
$messages['successfullysaved'] = '성공적으로 저장함.';
$messages['savingresponse'] = '응답 문구 저장 중...';
$messages['deleteresponseconfirm'] = '정말로 이 응답 문구를 삭제하시겠습니까?';
$messages['nocontactselected'] = '아직 연락처를 선택하지 않으셨습니다.';
$messages['addedsuccessfully'] = '연락처가 주소록에 성공적으로 추가되었습니다.';
$messages['contactexists'] = '동일한 이메일 주소의 연락처가 이미 존재합니다.';
$messages['contactnameexists'] = '연락처에 동일한 이름이 이미 존재합니다.';
$messages['blockedimages'] = '개인 정보 보호를 위해, 이 메시지의 외부 이미지를 차단했습니다.';
$messages['blockedresources'] = '개인정보 보호를 위해 외부 리소스를 차단했습니다.';
$messages['suspiciousemail'] = '이 메시지에 사기가 의심되는 수상한 이메일 주소가 포함되어 있습니다.';
$messages['bccemail'] = '전달된 메시지에 비밀 수신자(Bcc)가 포함되어 있습니다.';
$messages['bouncehint'] = '메시지를 수정 없이 보냅니다. 예: 본문, 헤더 및 수신자를 원본 그대로 사용.';
$messages['encryptedmessage'] = '이것은 암호화된 메시지며 표시할 수 없습니다. 죄송합니다!';
$messages['externalmessagedecryption'] = '이것은 암호화된 메시지이며 브라우저 확장 기능으로 해독할 수 있습니다.';
$messages['nopubkeyfor'] = '$email에 대한 올바른 공개 키를 찾지 못함';
$messages['nopubkeyforsender'] = '발신자 신원에 대한 올바른 공개 키를 찾지 못했습니다. 받는 사람에 대한 메시지만 암호화하시겠습니까?';
$messages['encryptnoattachments'] = '이미 첨부파일을 업로드하여 암호화할 수 없음. 암호화 편집기에 다시 추가해주세요.';
$messages['searchpubkeyservers'] = '분실한 키에 대한 공개 키 서버를 검색하시겠습니까?';
$messages['encryptpubkeysfound'] = '다음 공개 키가 발견되었습니다:';
$messages['keyservererror'] = '키 서버로부터 키를 가져오지 못했습니다';
$messages['keyimportsuccess'] = '공개 키 $key 하나를 열쇠고리에 성공적으로 가져왔습니다.';
$messages['nocontactsfound'] = '연락처를 발견하지 못했습니다.';
$messages['contactnotfound'] = '요청한 연락처를 찾을 수 없습니다.';
$messages['contactsearchonly'] = '선택한 주소록에서 연락처를 보려면 검색 상자를 이용하세요.';
$messages['sendingfailed'] = '메시지 발송을 실패했습니다.';
$messages['senttooquickly'] = '이 메시지를 보내기 전에 $sec초 동안 기다려주세요.';
$messages['errorsavingsent'] = '보낸 메시지를 저장하는 도중 오류가 발생했습니다.';
$messages['errorsaving'] = '저장하는 동안 오류가 발생했습니다.';
$messages['errormoving'] = '메시지를 이동할 수 없었습니다.';
$messages['errorcopying'] = '메시지를 복사할 수 없었습니다.';
$messages['errordeleting'] = '메시지를 삭제할 수 없었습니다.';
$messages['errormarking'] = '메시지를 표시할 수 없었습니다.';
$messages['alerttitle'] = '주목';
$messages['confirmationtitle'] = '정말...';
$messages['deletecontactconfirm']  = '정말로 선택한 연락처를 삭제하시겠습니까?';
$messages['deletegroupconfirm']  = '정말로 선택한 그룹을 삭제하시겠습니까?';
$messages['deletemessagesconfirm'] = '정말로 선택한 메시지를 삭제하시겠습니까?';
$messages['deletefolderconfirm']  = '정말로 이 폴더를 삭제하시겠습니까?';
$messages['movefolderconfirm']  = '정말로 이 폴더를 이동하시겠습니까?';
$messages['purgefolderconfirm']  = '정말로 이 폴더의 모든 메시지를 삭제하시겠습니까?';
$messages['contactdeleting'] = '연락처 삭제 중...';
$messages['groupdeleting'] = '그룹 삭제 중...';
$messages['folderdeleting'] = '폴더 삭제 중...';
$messages['foldermoving'] = '폴더 이동 중...';
$messages['foldersubscribing'] = '폴더 구독 중...';
$messages['folderunsubscribing'] = '폴더 구독 취소 중...';
$messages['formincomplete'] = '양식이 완전히 작성되지 않았습니다.';
$messages['noemailwarning'] = '유효한 이메일 주소를 입력해주세요.';
$messages['nonamewarning']  = '이름을 입력해주세요.';
$messages['nopagesizewarning'] = '페이지 크기를 입력해주세요.';
$messages['nosenderwarning'] = '보내는 사람의 이메일 주소를 입력해주세요.';
$messages['recipientsadded'] = '받는 사람을 성공적으로 추가했습니다.';
$messages['norecipientwarning'] = '최소 하나의 수신자를 입력해주세요.';
$messages['disclosedrecipwarning'] = '모든 수신자가 서로의 이메일 주소를 볼 수 있습니다. 이것을 방지하고 개인 정보를 보호하려면 Bcc 필드를 사용할 수 있습니다.';
$messages['disclosedreciptitle'] = '너무 많은 공개 수신자';
$messages['nosubjectwarning']  = '"제목" 필드가 비어있습니다. 지금 입력하시겠습니까?';
$messages['nosubjecttitle']  = '제목 없음';
$messages['nobodywarning'] = '내용 없는 메시지를 보내시겠습니까?';
$messages['notsentwarning'] = '메시지가 발신되지 않았으며 저장되지 않은 변경사항이 있습니다. 변경사항을 폐기하시겠습니까?';
$messages['restoresavedcomposedata'] = '이전에 작성했지만 보내지 않은 메시지가 발견되었습니다.\n\nSubject: $subject\nSaved: $date\n\n이 메시지를 복구하시겠습니까?';
$messages['nosearchname'] = '연락처명이나 이메일 주소를 입력해주세요.';
$messages['notuploadedwarning'] = '아직 모든 첨부가 업로드되지 않았습니다. 기다리거나 업로드를 취소해주세요.';
$messages['searchsuccessful'] = '$nr개의 메시지를 찾았습니다.';
$messages['contactsearchsuccessful'] = '$nr개의 연락처를 찾았습니다.';
$messages['searchnomatch'] = '검색이 일치하는 항목을 발견하지 못했습니다.';
$messages['searching'] = '검색 중...';
$messages['checking'] = '확인 중...';
$messages['stillsearching'] = '아직 검색 중...';
$messages['nospellerrors'] = '맞춤법 오류가 발견되지 않았습니다.';
$messages['folderdeleted'] = '폴더가 성공적으로 삭제되었습니다.';
$messages['foldersubscribed'] = '폴더를 성공적으로 구독했습니다.';
$messages['folderunsubscribed'] = '폴더 구독을 성공적으로 취소했습니다.';
$messages['folderpurged'] = '폴더를 성공적으로 비웠습니다.';
$messages['folderexpunged'] = '폴더를 성공적으로 압축했습니다.';
$messages['deletedsuccessfully'] = '성공적으로 삭제되었습니다.';
$messages['converting'] = '서식 설정 삭제 중...';
$messages['messageopenerror'] = '서버에서 메시지를 불러올 수 없었습니다.';
$messages['filelinkerror'] = '파일 첨부를 실패함.';
$messages['fileuploaderror'] = '파일 업로드를 실패했습니다.';
$messages['csvfilemismatch'] = '다른 필드를 포함한 다중 CSV 파일 가져오기는 지원하지 않습니다.';
$messages['filesizeerror'] = '업로드한 파일이 최대 크기인 $size를 초과했습니다.';
$messages['filecounterror'] = '한 번에 최대 $count개의 파일을 업로드 할 수 있습니다.';
$messages['msgsizeerror'] = '파일 첨부에 실패했습니다. 메시지의 최대 크기($size)를 초과했습니다.';
$messages['msgsizeerrorfwd'] = '메시지 최대 크기 제한을 ($size) 넘었습니다. $num개 메시지를 첨부할 수 없습니다.';
$messages['copysuccess'] = '$nr개의 연락처를 성공적으로 복사함';
$messages['movesuccess'] = '$nr개의 연락처를 성공적으로 이동되었습니다.';
$messages['copyerror'] = '모든 연락처를 복사할 수 없었습니다.';
$messages['moveerror'] = '모든 연락처를 이동할 수 없었습니다.';
$messages['sourceisreadonly'] = '이 주소 소스는 읽기 전용입니다.';
$messages['errorsavingcontact'] = '연락처 주소를 저장할 수 없었습니다.';
$messages['movingmessage'] = '메시지 이동 중...';
$messages['copyingmessage'] = '메시지 복사 중...';
$messages['copyingcontact'] = '연락처 복사 중...';
$messages['movingcontact'] = '연락처 이동 중...';
$messages['deletingmessage'] = '메시지 삭제 중...';
$messages['markingmessage'] = '메시지 표시 중...';
$messages['addingmember'] = '연락처를 그룹에 추가 중...';
$messages['removingmember'] = '연락처를 그룹에서 삭제 중...';
$messages['receiptsent'] = '읽음 확인을 성공적으로 보냈습니다.';
$messages['errorsendingreceipt'] = '읽음 확인을 보낼 수 없었습니다.';
$messages['deleteidentityconfirm'] = '이 항목을 정말로 삭제하시겠습니까?';
$messages['nodeletelastidentity'] = '이 신원 밖에 남지 않아 삭제할 수 없습니다.';
$messages['forbiddencharacter'] = '폴더명에 금지된 문자가 포함되어 있습니다.';
$messages['selectimportfile'] = '업로드할 파일을 선택해주세요.';
$messages['addresswriterror'] = '선택한 주소록은 쓰기가 불가능합니다.';
$messages['contactaddedtogroup'] = '연락처가 이 그룹에 성공적으로 추가되었습니다.';
$messages['contactremovedfromgroup'] = '연락처가 이 그룹에서 성공적으로 제거되었습니다.';
$messages['nogroupassignmentschanged'] = '그룹 할당이 변경되지 않았습니다.';
$messages['importwait'] = '가져오는 중, 잠시만 기다려주세요...';
$messages['importformaterror'] = '가져오기를 실패했습니다! 업로드한 파일은 잘못된 가져오기 데이터 파일입니다.';
$messages['importconfirm'] = '<b>$inserted개의 연락처를 성공적으로 가져옴<b>';
$messages['importconfirmskipped'] = '<b>$skipped개의 기존 입력내용을  건너뜀</b>';
$messages['importmessagesuccess'] = '$nr개의 메시지를 성공적으로 가져옴';
$messages['importmessageerror'] = '가져오기를 실패했습니다! 업로드한 파일은 잘못된 메시지 또는 메일함 파일입니다.';
$messages['opnotpermitted'] = '작업이 허용되지 않습니다!';
$messages['nofromaddress'] = '선택한 신원의 이메일 주소가 누락되었습니다.';
$messages['editorwarning'] = '편집기 유형을 전환하면 텍스트 서식을 잃게 될 수도 있습니다. 계속하시겠습니까?';
$messages['httpreceivedencrypterror'] = '치명적인 구성 오류가 발생했습니다. 즉시 관리자에게 연락하세요.
<b>메시지를 보낼 수 없습니다.</b>';
$messages['smtpconnerror'] = 'SMTP 오류 ($code): 서버와의 연결을 실패했습니다.';
$messages['smtpautherror'] = 'SMTP 오류 ($code): 인증을 실패했습니다.';
$messages['smtpfromerror'] = 'SMTP 오류 ($code): 보내는사람 "$from" ($msg) (으)로 설정하는데 실패했습니다.';
$messages['smtptoerror'] = 'SMTP 오류 ($code): 수신자를 "$to" ($msg)에 추가하는데 실패했습니다.';
$messages['smtprecipientserror'] = 'SMTP 오류: 수신자 목록을 구문 분석할 수 없습니다.';
$messages['smtputf8error'] = 'SMTP 오류: 서버가 유니코드 이메일 주소를 지원하지 않습니다.';
$messages['smtpsizeerror'] = 'SMTP 오류: 메시지 크기가 서버 제한을 ($limit) 넘었습니다.';
$messages['smtperror'] = 'SMTP 오류: $msg';
$messages['emailformaterror'] = '유효하지 않은 이메일 주소: $email';
$messages['toomanyrecipients'] = '받는 사람이 너무 많음. 수신자 인원을 $max명으로 줄이세요.';
$messages['maxgroupmembersreached'] = '그룹 구성원이 최대 인원인 $max명을 초과합니다.';
$messages['internalerror'] = '내부 오류가 발생했습니다. 다시 시도해주세요.';
$messages['contactdelerror'] = '연락처를 삭제할 수 없었습니다.';
$messages['contactdeleted'] = '연락처가 성공적으로 삭제되었습니다.';
$messages['contactrestoreerror'] = '삭제된 연락처를 복구할 수 없었습니다.';
$messages['contactrestored'] = '연락처가 성공적으로 복구되었습니다.';
$messages['groupdeleted'] = '그룹이 성공적으로 삭제되었습니다.';
$messages['grouprenamed'] = '그룹명이 성공적으로 변경되었습니다.';
$messages['groupcreated'] = '그룹이 성공적으로 생성되었습니다.';
$messages['savedsearchdeleted'] = '저장된 검색이 성공적으로 삭제되었습니다.';
$messages['savedsearchdeleteerror'] = '저장된 검색을 삭제할 수 없었습니다.';
$messages['savedsearchcreated'] = '저장된 검색이 성공적으로 생성되었습니다.';
$messages['savedsearchcreateerror'] = '저장된 검색을 생성할 수 없었습니다.';
$messages['messagedeleted'] = '메시지가 성공적으로 삭제되었습니다.';
$messages['messagemoved'] = '메시지가 성공적으로 이동되었습니다.';
$messages['messagemovedtotrash'] = '메시지를 성공적으로 지운 편지함으로 이동했습니다.';
$messages['messagecopied'] = '메시지가 성공적으로 복사되었습니다.';
$messages['messagemarked'] = '메시지가 성공적으로 선택되었습니다.';
$messages['autocompletechars'] = '자동 완성을 위해 $min개 이상의 문자를 입력하세요.';
$messages['autocompletemore'] = '더 많은 일치하는 입력내용을 찾았습니다. 더 많은 문자를 입력해주세요.';
$messages['namecannotbeempty'] = '이름을 비워둘 수 없습니다.';
$messages['nametoolong'] = '이름이 너무 깁니다.';
$messages['namedotforbidden'] = '폴더명은 마침표로 시작할 수 없습니다.';
$messages['folderupdated'] = '폴더가 성공적으로 업데이트 되었습니다.';
$messages['foldercreated'] = '폴더를 성공적으로 생성함.';
$messages['invalidimageformat'] = '올바른 이미지 형식이 아닙니다.';
$messages['mispellingsfound'] = '메시지에서 맞춤법 오류가 감지되었습니다.';
$messages['parentnotwritable'] = '선택한 상위 폴더로 폴더를 생성/이동할 수 없습니다. 접근 권한이 없습니다.';
$messages['messagetoobig'] = '메시지 부분이 처리하기에는 너무 큽니다.';
$messages['attachmentvalidationerror'] = '이 첨부파일은 메시지에 선언된 유형과 일치하지 않아서 의심스럽습니다. 보낸 사람을 신뢰하지 않는다면, 악의적인 내용이 포함되었을 수 있으므로 브라우저에서 열지 말아야 합니다.<br/><br/><em>예상: $expected, 실제: $detected</em>';
$messages['noscriptwarning'] = '경고: 이 웹메일 서비스는 자바스크립트가 필요합니다! 이 기능을 사용하려면 브라우저 설정에서 자바스크립트를 활성화해주세요.';
$messages['messageissent'] = '메시지를 이미 보냈으나, 아직 저장되지 않았습니다. 지금 저장하시겠습니까?';
$messages['errnotfound'] = '파일을 찾을 수 없음';
$messages['errnotfoundexplain'] = '요청한 리소스를 찾을 수 없습니다!';
$messages['errfailedrequest'] = '실패한 요청';
$messages['errauthorizationfailed'] = '인증을 실패함';
$messages['errunauthorizedexplain'] = '이 서비스에 액세스 할 수있는 권한이 있는지 확인할 수 없었습니다!';
$messages['errrequestcheckfailed'] = '확인 요청을 실패함';
$messages['errcsrfprotectionexplain'] = "보안을 위해 이 리소스에 대한 접근은 CSRF로부터 보호되었습니다.\n 이것이 표시된다면 웹 어플리케이션에서 나가기 전에 로그아웃을 하지 않았을 것입니다.\n\n계속하려면 이제 사용자와의 상호작용이 필요합니다.";
$messages['errcontactserveradmin'] = '서버 관리자에게 문의해주세요.';
$messages['clicktoresumesession'] = '이전 세션을 다시 시작하려면 여기를 클릭하세요.';
$messages['errcomposesession'] = '쓰기 세션 오류';
$messages['errcomposesessionexplain'] = '요청한 쓰기 세션을 찾을 수 없습니다.';
$messages['clicktocompose'] = '새 메시지를 작성하려면 여기를 클릭하세요.';
$messages['nosupporterror'] = '이 기능은 사용자의 웹브라우저에서 지원되지 않습니다.';
$messages['siginserted'] = '서명을 성공적으로 삽입했습니다.';
$messages['responseinserted'] = '응답을 성공적으로 삽입했습니다.';
$messages['noresponsesavailable'] = '사용할 응답이 없음';
$messages['listempty'] = '목록이 비어있습니다.';
$messages['listusebutton'] = '새 문구를 만드려면 추가 버튼을 누르세요.';
$messages['keypaircreatesuccess'] = '$identy 신원에 대한 키 페어를 성공적으로 만들었습니다.';
$messages['emptyattachment'] = '첨부파일이 비어있는 것으로 보입니다.<br>이 이메일의 발송인과 확인해주십시오.';
$messages['oauthloginfailed'] = 'OAuth 로그인에 실패했습니다. 다시 시도해주십시오.';
