<?php

/**
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail Enigma plugin              |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/roundcube/roundcube-webmail/plugin-enigma/
*/

$labels['encryption'] = 'شىفىرلاش';
$labels['enigmacerts'] = 'S/MIME ئىجازەتنامىسى';
$labels['enigmakeys'] = 'PGP ئاچقۇچلىرى';
$labels['keysfromto'] = 'from$دىن to$غا count$ ئاچقۇچلار';
$labels['keyname'] = 'ئىسمى';
$labels['keyid'] = 'ئاچقۇچ نۇمۇرى';
$labels['keyuserid'] = 'ئىشلەتكۈچى نۇمۇرى';
$labels['keytype'] = 'ئاچقۇچ تۈرى';
$labels['fingerprint'] = 'بارماق ئىزى';
$labels['subkeys'] = 'بالا-ئاچقۇچلار';
$labels['keyprops'] = 'ئاچقۇچ خاسلىقلىرى';
$labels['basicinfo'] = 'ئادەتتىكى ئۇچۇر';
$labels['userids'] = 'قۇشۇمچە ئىشلەتكۈچىلەر';
$labels['typepublickey'] = 'ئاممىۋىي ئاچقۇچ';
$labels['typekeypair'] = 'ئاچقۇچ جۈپى';
$labels['keyattfound'] = 'بۇ ئۇچۇرغا PGP ئاچقۇچ(لار)ى قىستۇرۇلغان.';
$labels['keyattimport'] = 'ئاچقۇچ(لار)نى كىرگۈزۈش';
$labels['typesign'] = 'ئىمزا قۇيۇش';
$labels['typeencrypt'] = 'شىفىرلەش';
$labels['typecert'] = 'ئىجازەت بېرىش';
$labels['typeauth'] = 'دەلىللەش';
$labels['subkeyid'] = 'نۇمۇر';
$labels['subkeyalgo'] = 'ئالگىرىزىم';
$labels['subkeycreated'] = 'قۇرۇلدى';
$labels['subkeyexpires'] = 'ۋاقتى ئۆتتى';
$labels['subkeyusage'] = 'ئىشلىتىش';
$labels['expiresnever'] = 'ھەرگىز';
$labels['unknown'] = 'ناتۇنۇش';
$labels['uservalid'] = 'ئىناۋەتلىك';
$labels['userid'] = 'نۇمۇر';
$labels['valid'] = 'ئىناۋەتلىك';
$labels['supportencryption'] = 'ئۇچۇر شىفىرلاشنى بار قىلىش ھەمدە ئىمزا قۇيۇش';
$labels['supportsignatures'] = 'ئۇچۇر ئىمزاسىنى تەكشۈرۈشنى بار قىلىش';
$labels['supportdecryption'] = 'ئۇچۇر شىفىرسىزلەشنى بار قىلىش';
$labels['signdefault'] = 'سۈكۈت ھالەتتە ھەممە ئۇچۇرغا ئىمزا قۇيۇش';
$labels['encryptdefault'] = 'سۈكۈت ھالەتتە ھەممە ئۇچۇرنى شىفىرلاش';
$labels['attachpubkeydefault'] = 'سۈكۈت ھالەتتە مېنىڭ ئاممىۋىي PGP ئاچقۇچۇمنى قىستۇرۇش';
$labels['passwordtime'] = 'شەخسىي ئاچقۇچ مەخپىي نۇمۇرۇمنى ساقلاپ قېلىش';
$labels['nminutes'] = 'm$ مىنۇت(لار)';
$labels['wholesession'] = 'بارلىق باسقۇچ';
$labels['createkeys'] = 'بىر يېڭى ئاچقۇچ جۈپى ياساش';
$labels['importkeys'] = 'ئاچقۇچ(لار)نى كىرگۈزۈش';
$labels['exportkeys'] = 'ئاچقۇچ(لار)نى چىقىرىش';
$labels['keyactions'] = 'ئاچقۇچ ھەركەتلىرى...';
$labels['keyremove'] = 'ئۆچۈرۈش';
$labels['keydisable'] = 'يوق-قىلىش';
$labels['keyrevoke'] = 'تارتىۋېلىش';
$labels['keysend'] = 'ئۇچۇردا ئاممىۋىي ئاچقۇچنى ئەۋەتىش';
$labels['keychpass'] = 'مەخپىي نۇمۇرنى ئۆزگەرتىش';
$labels['keyadd'] = 'ئاچقۇچ قېتىش';
$labels['newkeyident'] = 'كىملىك';
$labels['newkeypass'] = 'مەخپىي نۇمۇر';
$labels['newkeypassconfirm'] = 'مەخپىي نۇمۇرنى جەزىملەشتۈرۈش';
$labels['newkeytype'] = 'ئاچقۇچ تۈرى';
$labels['rsa2048'] = '2048 بىتلىق RSA';
$labels['rsa4096'] = '4096 بىتلىق RSA';
$labels['ecckeypair'] = 'ECC (ئىللىپتىك ياي)';
$labels['keygenerating'] = 'ئاچقۇچلارنى ياساۋاتىدۇ...';
$labels['encryptionoptions'] = 'شىفىرلاش تاللانمىلىرى...';
$labels['encryptmsg'] = 'بۇ ئۇچۇرنى شىفىرلاش';
$labels['signmsg'] = 'بۇ ئۇچۇرغا رەقەملىك ئىمزا قۇيۇش';
$labels['sendunencrypted'] = 'شىفىرسىز ئەۋەتىش';
$labels['enterkeypasstitle'] = 'ئاچقۇچ پارولىنى كىرگۈزۈش';
$labels['enterkeypass'] = 'بۇ ئىشلەتكۈچى ئۈچۈن مەخپىي ئاچقۇچ (keyid$)نى بوشىتىشقا پارول كېرەك بولىدۇ: user$.';
$labels['attachpubkeymsg'] = 'مېنىڭ ئاممىۋىي ئاچقۇچۇمنى قىستۇرۇش';
$labels['keyexportprompt'] = 'سىز مەخپىي ئاچقۇچلارنىڭ ساقلانغان OpenPGP ئاچقۇچ ھۆججىتىدە بۇلىشىنى خالامسىز؟';
$labels['onlypubkeys'] = 'پەقەتلا ئاممىۋىي ئاچقۇچلارنى چىقىرىش';
$labels['withprivkeys'] = 'مەخپىي ئاچقۇچلارنى چىقىرىش';
$labels['findkey'] = 'ئاچقۇچ مۇلازىمېتىر(لار)ىدىن ئىزدەش';
$labels['keyimportlabel'] = 'ھۆججەتتىن كىرگۈزۈش';
$labels['keyimportsearchlabel'] = 'ئاچقۇچ مۇلازىمېتىر(لار)ىدىن ئىزدەش';
$labels['managekeys'] = 'PGP ئاچقۇچلىرىنى باشقۇرۇش';
$labels['identitymatchingprivkeys'] = 'سىزنىڭ ئاچقۇچ زەنجىرىڭىزدە nr$ ماس كىلىدىغان PGP شەخسىي ئاچقۇچلىرىڭىز ساقلانغان:';
$labels['identitynoprivkeys'] = 'بۇ ئەۋەتكۈچىنىڭ كىملىكىدە تېخى سىزنىڭ ئاچقۇچ زەنجىرىڭىزدە ساقلانغان شەخسىيپ PGP ئاچقۇچى يوق.';
$labels['arialabelkeyexportoptions'] = 'ئاچقۇچ چىقىرىش تاللانمىلىرى';
$labels['arialabelkeysearchform'] = 'ئاچقۇچ ئىزدەش جەدىۋېلى';
$labels['arialabelkeyoptions'] = 'ئاچقۇچ تاللانمىلىرى';
$messages['sigvalid'] = 'sender$ نىڭ دەلىللەنگەن ئىمزاسى';
$messages['sigvalidpartial'] = 'sender$ نىڭ دەلىللەنگەن ئىمزاسى، مەزمۇننىڭ بىر قىسمى ئىمزالانمىغان';
$messages['siginvalid'] = 'sender$ نىڭ ئىناۋەتسىز ئىمزاسى بار';
$messages['sigunverified'] = 'دەلىللەنمىگەن ئىمزا. كىنىشكا دەلىللەنمىدى. كىنىشكا نۇمۇرى: keyid$';
$messages['signokey'] = 'دەلىللەنمىگەن ئىمزا. ئاممىۋىي ئاچقۇچ تېپىلمىدى. ئاچقۇچ نۇمۇرى: keyid$.';
$messages['sigerror'] = 'دەلىللەنمىگەن ئىمزا. ئىچكى خاتالىق.';
$messages['decryptok'] = 'ئۇچۇر شىفىرسىزلاندى.';
$messages['decrypterror'] = 'شىفىرسىزلاش مەغلۇپ بولدى.';
$messages['decryptnokey'] = 'شىفىرسىزلاش مەغلۇپ بولدى. شەخسىي ئاچقۇچ تېپىلمىدى. ئاچقۇچ نۇمۇرى: keyid$.';
$messages['decryptnomdc'] = 'شىفىرسىزلاش ئۆتكۈزۈلدى. ئۇچۇر توغرىلىقى قوغدالمىدى.';
$messages['decryptbadpass'] = 'شىفىرسىزلاش مەغلۇپ بولدى. ئىناۋەتسىز مەخپىي نۇمۇر.';
$messages['decryptnopass'] = 'شىفىرسىزلاش مەغلۇپ بولدى. ئاچقۇچ پارولى تەلەپ قىلىندى.';
$messages['decryptpartial'] = 'ئۇچۇر شىفىرسىزلەندى، لىكىن بىر قىسمى شىفىرلانمىغان.';
$messages['signerror'] = 'ئىمزا-قۇيۇش مەغلۇپ بولدى.';
$messages['signnokey'] = 'ئىمزا-قۇيۇش مەغلۇپ بولدى. شەخسىي ئاچقۇچ تېپىلمىدى.';
$messages['signbadpass'] = 'ئىمزا-قۇيۇش مەغلۇپ بولدى. ئىناۋەتسىز مەخپىي نۇمۇر.';
$messages['signnopass'] = 'ئىمزا-قۇيۇش مەغلۇپ بولدى. ئاچقۇچ پارولى تەلەپ قىلىندى.';
$messages['encrypterror'] = 'شىفىرلاش مەغلۇپ بولدى.';
$messages['encryptnokey'] = 'شىفىرلاش مەغلۇپ بولدى. ئاممىۋىي ئاچقۇچ email$ ئۈچۈن تېپىلمىدى.';
$messages['encryptnoprivkey'] = 'شىفىرلاش مەغلۇپ بولدى. شەخسىي ئاچقۇچ تېپىلمىدى.';
$messages['nokeysfound'] = 'ھېچقانداق ئاچقۇچ تېپىلمىدى';
$messages['keynotfound'] = 'ئاچقۇچ تېپىلمىدى!';
$messages['keyopenerror'] = 'ئاچقۇچ ئۇچۇرىغا ئېرىشكىلى بولمىدى! ئىچكىي خاتالىق.';
$messages['keylisterror'] = 'ئاچقۇچلارنى تىزغىلى بولمىدى! ئىچكىي خاتالىق.';
$messages['keysimportfailed'] = 'ئاچقۇچ(لار)نى كىرگۈزگىلى بولمىدى! ئىچكىي خاتالىق.';
$messages['keysimportsuccess'] = 'ئاچقۇچ(لار) مۇۋاپىقىيەتلىك كىرگۈزۈلدى. كىرگۈزدى: new$، ئۆزگەرمىدى: old$.';
$messages['keyremoving'] = 'ئاچقۇچ(لار)نى ئۆچۈرىۋاتىدۇ...';
$messages['keyremoveconfirm'] = 'تاللانغان ئاچقۇچ(لار)نى ئۆچۈرۈشنى جەزىملەشتۈرەمسىز؟';
$messages['keyremovesuccess'] = 'ئاچقۇچ(لار) مۇۋاپىقىيەتلىك ئۆچۈرۈلدى';
$messages['keyremoveerror'] = 'ئاچقۇچ(لار)نى ئۆچۈرۈشكە بولمىدى.';
$messages['keyimporttext'] = 'سىز شەخسىي ھەمدە ئاممىۋىي ئاچقۇچ(لار)نى ياكى ASCII-Armor تىپىدىكى تارتىۋېلىش ئىمزالىرىنى كىرگۈزەلەيسىز.';
$messages['keyimportsearchtext'] = 'سىز ئاممىۋىي ئاچقۇچلارنى ئاچقۇچ بەلگىسى، ئىشلەتكۈچى ئىسمى، ئېلىخەت ئادىرسى بىلەن ئىزدىيەلەيسىز ھەمدە ئۇلارنى بىۋاستە كىرگۈزەلەيسىز.';
$messages['keystoragenotice'] = 'بارلىق ئاممىۋىي ھەمدە شەخسىي ئاچقۇچلار بۇ مۇلازىمېتىردا ساقلىندۇ.';
$messages['formerror'] = 'بۇ جەدىۋەلنى تولدۇرۇڭ. ھەممە كاتەكچىلەر مەجبۇرىي!';
$messages['passwordsdiffer'] = 'مەخپىي نۇمۇرلار ماس كەلمىدى!';
$messages['keygenerateerror'] = 'ئاچقۇچ جۈپىنى ياسىغىلى بولمىدى';
$messages['keygeneratesuccess'] = 'ئاچقۇچ جۈپى مۇۋاپىقىيەتلىك ياسالدى ھەمدە كىرگۈزۈلدى.';
$messages['keygennosupport'] = 'سىزنىڭ تور كۆرگۈچىڭىز شىفىرلاشنى قوللىمايدۇ. ئاچقۇچ جۈپىنى ياسىغىلى بولمىدى!';
$messages['noidentselected'] = 'سىز بۇ ئاچقۇچقا ئەڭ ئاز دىگەندە بىر كىملىكنى تاللىشىڭىز كېرەك!';
$messages['nonameident'] = 'كىملىكتە چۇقۇم بىر ئىشلەتكۈچى ئىسمى بەلگىلەنگەن بۇلىشى كېرەك!';
$labels['newkeysize'] = 'ئاچقۇچ چوڭلۇقى';
$labels['key2048'] = 'سۈكۈت - 2048 بىت';
$labels['key4096'] = 'بەكرەك بىخەتەر - 4096 بىت';
