<div id="layout-sidebar" class="listbox<roundcube:exp expression="!request:_action ? ' selected' : ''"/>" role="navigation" aria-labelledby="aria-label-settingstabs">
	<div class="header">
		<a class="button icon task-menu-button" href="#menu"><span class="inner"><roundcube:label name="menu" /></span></a>
		<span id="aria-label-settingstabs" class="header-title"><roundcube:label name="settings" /></span>
	</div>
	<div class="scroller">
		<ul id="settings-menu" class="listing iconized settings-default-icon<roundcube:exp expression="!request:_action ? ' selection-large-only' : ''"/>">
			<roundcube:object name="settingstabs" class="listitem" tagname="li" />
			<roundcube:container name="tabs" id="settings-menu" />
		</ul>
	</div>
</div>
