<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail Managesieve plugin         |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/plugin-managesieve/
*/


$labels['filters'] = 'Filtros';
$labels['managefilters'] = 'Xestionar os filtros de correo entrante';
$labels['filtername'] = 'Nome do filtro';
$labels['newfilter'] = 'Novo filtro';
$labels['filteradd'] = 'Engadir filtro';
$labels['filterdel'] = 'Eliminar filtro';
$labels['scope'] = 'Alcance';
$labels['moveup'] = 'Mover arriba';
$labels['movedown'] = 'Mover abaixo';
$labels['filterallof'] = 'coincidir con todas as regras seguintes';
$labels['filteranyof'] = 'coincidir con algunha das regras seguintes';
$labels['filterany'] = 'todas as mensaxes';
$labels['filtercontains'] = 'contén';
$labels['filternotcontains'] = 'non contén';
$labels['filteris'] = 'é igual a';
$labels['filterisnot'] = 'non é igual a';
$labels['filterexists'] = 'existe';
$labels['filternotexists'] = 'non existe';
$labels['filtermatches'] = 'casa coa expresión';
$labels['filternotmatches'] = 'non casa coa expresión';
$labels['filterregex'] = 'casa coa expresión regular';
$labels['filternotregex'] = 'non casa coa expresión regular';
$labels['filterunder'] = 'baixo';
$labels['filterover'] = 'sobre';
$labels['addrule'] = 'Engadir regra';
$labels['delrule'] = 'Eliminar regra';
$labels['messagemoveto'] = 'Mover a mensaxe a';
$labels['messageredirect'] = 'Redirixir a mensaxe a';
$labels['messagecopyto'] = 'Copiar a mensaxe a';
$labels['messagesendcopy'] = 'Enviar copia da mensaxe a';
$labels['messagereply'] = 'Respostar con unha mensaxe';
$labels['messagedelete'] = 'Eliminar a mensaxe';
$labels['messagediscard'] = 'Descartar con unha mensaxe';
$labels['messagekeep'] = 'Manter mensaxe na caixa de entrada';
$labels['messagesrules'] = 'Para o correo entrante:';
$labels['messagesactions'] = '... executar as seguintes accións:';
$labels['add'] = 'Engadir';
$labels['del'] = 'Eliminar';
$labels['sender'] = 'Remite';
$labels['recipient'] = 'Persoa destinataria';
$labels['vacationdays'] = 'Cada canto enviar mensaxes (en días):';
$labels['vacationinterval'] = 'Con que frecuencia se van enviar mensaxes:';
$labels['vacationreason'] = 'Corpo da mensaxe (por vacacións):';
$labels['vacationsubject'] = 'Asunto da mensaxe:';
$labels['days'] = 'días';
$labels['seconds'] = 'segundos';
$labels['rulestop'] = 'Parar de avaliar regras';
$labels['enable'] = 'Activar/Desactivar';
$labels['filtersets'] = 'Conxunto de filtros';
$labels['filterdef'] = 'Definición de filtros';
$labels['active'] = 'activo';
$labels['none'] = 'ningún';
$labels['fromset'] = 'de conxunto';
$labels['fromfile'] = 'de arquivo';
$labels['filterdisabled'] = 'Filtro desactivado';
$labels['countisgreaterthan'] = 'a conta é maior que';
$labels['countisgreaterthanequal'] = 'a conta é maior ou igual a';
$labels['countislessthan'] = 'a conta é menor que';
$labels['countislessthanequal'] = 'a conta é menor ou igual a';
$labels['countequals'] = 'a conta é igual a';
$labels['countnotequals'] = 'a conta non é igual a';
$labels['valueisgreaterthan'] = 'o valor é meirande que ';
$labels['valueisgreaterthanequal'] = 'o valor é maior ou igual a';
$labels['valueislessthan'] = 'o valor é menor que';
$labels['valueislessthanequal'] = 'o valor é menor ou igual a';
$labels['valueequals'] = 'o valor é igual a';
$labels['valuenotequals'] = 'o valor non é igual a';
$labels['setflags'] = 'Marcar a mensaxe';
$labels['addflags'] = 'Engadir marcas á mensaxe';
$labels['removeflags'] = 'Desmarcar as mensaxes';
$labels['flagread'] = 'Lidas';
$labels['flagdeleted'] = 'Eliminadas';
$labels['flaganswered'] = 'Respostadas';
$labels['flagflagged'] = 'Marcadas';
$labels['flagdraft'] = 'Borrador';
$labels['setvariable'] = 'Estabelecer variábel';
$labels['setvarname'] = 'Nome da variábel:';
$labels['setvarvalue'] = 'Valor da variábel:';
$labels['setvarmodifiers'] = 'Modificadores:';
$labels['varlower'] = 'minúscula';
$labels['varupper'] = 'maiúscula';
$labels['varlowerfirst'] = 'primeira letra minúscula';
$labels['varupperfirst'] = 'primeira letra maiúscula';
$labels['varquotewildcard'] = 'poñer entre aspas caracteres especiais';
$labels['varlength'] = 'lonxitude';
$labels['notify'] = 'Enviar notificación';
$labels['notifyimportance'] = 'Importancia:';
$labels['notifyimportancelow'] = 'baixa';
$labels['notifyimportancenormal'] = 'normal';
$labels['notifyimportancehigh'] = 'alta';
$labels['notifymethodmailto'] = 'Correo electrónico';
$labels['notifymethodtel'] = 'Teléfono';
$labels['notifymethodsms'] = 'SMS';
$labels['filtercreate'] = 'Crear filtro';
$labels['usedata'] = 'Usar os seguintes datos no filtro:';
$labels['nextstep'] = 'Seguinte paso';
$labels['...'] = '...';
$labels['currdate'] = 'Data actual';
$labels['datetest'] = 'Data';
$labels['dateheader'] = 'cabeceira:';
$labels['year'] = 'ano';
$labels['month'] = 'mes';
$labels['day'] = 'día';
$labels['date'] = 'data (aaaa-mm-dd)';
$labels['julian'] = 'data (xuliano)';
$labels['hour'] = 'hora';
$labels['minute'] = 'minuto';
$labels['second'] = 'segundo';
$labels['time'] = 'tempo (hh:mm:ss)';
$labels['iso8601'] = 'data (ISO8601)';
$labels['std11'] = 'data (RFC2822)';
$labels['zone'] = 'fuso-horario';
$labels['weekday'] = 'día da semana (0-6)';
$labels['advancedopts'] = 'Opcións avanzadas';
$labels['body'] = 'Corpo';
$labels['address'] = 'enderezo';
$labels['envelope'] = 'sobre';
$labels['modifier'] = 'modificador:';
$labels['text'] = 'texto';
$labels['undecoded'] = 'sen codificar (en bruto)';
$labels['contenttype'] = 'tipo de contido';
$labels['modtype'] = 'tipo:';
$labels['allparts'] = 'todos';
$labels['domain'] = 'dominio';
$labels['localpart'] = 'parte local';
$labels['user'] = 'utente';
$labels['detail'] = 'detalle';
$labels['comparator'] = 'comparador:';
$labels['default'] = 'predeterminado';
$labels['octet'] = 'estricto (octeto)';
$labels['asciicasemap'] = 'non sensíbel a maiúsculas/minúsculas (ascii-casemap)';
$labels['asciinumeric'] = 'numérico (ascii-numerico)';
$labels['index'] = 'índice:';
$labels['indexlast'] = 'atrás';
$labels['spamtestequals'] = 'é igual a';
$labels['spamtestnotequals'] = 'non é igual a';
$labels['vacation.reply'] = 'Respostar á mensaxe';
$labels['vacation.advanced'] = 'Opcións avanzadas';
$labels['vacation.subject'] = 'Asunto';
$labels['vacation.body'] = 'Corpo';
$labels['vacation.status'] = 'Estado';
$labels['vacation.on'] = 'Activar';
$labels['vacation.off'] = 'Desactivar';
$labels['vacation.saving'] = 'Gardando datos...';
$labels['vacation.keep'] = 'Manter';
$labels['vacation.discard'] = 'Descartar';
$labels['vacation.redirect'] = 'Redirixir a';
$labels['vacation.copy'] = 'Enviar copia a';
$labels['forward.redirect'] = 'Redirixir a';
$labels['forward.copy'] = 'Enviar copia a';
$labels['forward.on'] = 'Activar';
$labels['forward.off'] = 'Desactivar';
$labels['forward.saving'] = 'Gardando datos...';
$labels['arialabelfilteractions'] = 'Accións de filtrado';
$labels['arialabelfilterform'] = 'Propiedades dos filtros';
$labels['ariasummaryfilterslist'] = 'Lista de filtros';
$labels['duplicate.header'] = 'cabeceira:';
$messages['filterunknownerror'] = 'Erro descoñecido do servidor';
$messages['filterconnerror'] = 'Imposíbel conectar co servidor.';
$messages['filterdeleteerror'] = 'Non se pode eliminar filtro. Produciuse un erro de servidor.';
$messages['filterdeleted'] = 'Filtro borrado con éxito';
$messages['filtersaved'] = 'Filtro gardado con éxito';
$messages['filtersaveerror'] = 'Non se puido gardar filtro. Produciuse un erro de servidor.';
$messages['filterdeleteconfirm'] = 'Realmente queres eliminar o filtro seleccionado?';
$messages['ruledeleteconfirm'] = 'Seguro que queres eliminar a regra seleccionada?';
$messages['actiondeleteconfirm'] = 'Seguro que queres eliminar a acción seleccionada?';
$messages['forbiddenchars'] = 'Caracteres non permitidos no campo';
$messages['cannotbeempty'] = 'O campo non pode estar baleiro';
$messages['ruleexist'] = 'Xa existe un filtro co nome especificado.';
$messages['activateerror'] = 'Non é posíbel activar o(s) filtro(s) seleccionado(s). Produciuse un erro de servidor.';
$messages['deactivateerror'] = 'Incapaz de desactivar filtro(s) seleccionado(s). Produciuse un erro de servidor.';
$messages['deactivated'] = 'Desactiváronse os filtros correctamente.';
$messages['activated'] = 'Activáronse os filtros correctamente';
$messages['moved'] = 'Moveuse correctamente o filtro.';
$messages['moveerror'] = 'Non se pode mover o filtro seleccionado. Produciuse un erro de servidor.';
$messages['nametoolong'] = 'Imposíbel crear o conxunto de filtros. O nome é longo de máis';
$messages['namereserved'] = 'Nome reservado';
$messages['setexist'] = 'Xa existe o conxunto';
$messages['nodata'] = 'É preciso seleccionar polo menos unha posición!';
$messages['invaliddateformat'] = 'Formato de data ou parte dos datos non válidos';
