<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail Archive plugin             |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/plugin-archive/
*/

$labels['buttontext'] = 'Архивирај';
$labels['buttontitle'] = 'Архивирај ову поруку';
$labels['archived'] = 'Успешно архивирано';
$labels['archivedreload'] = 'Успешно архивирано. Поново учитајте страну да видите нове архивиране фасцикле.';
$labels['archiveerror'] = 'Неке поруке се нису могле архивирати';
$labels['archivefolder'] = 'Архива';
$labels['settingstitle'] = 'Архивирање';
$labels['archivetype'] = 'Разврстај архиве по';
$labels['archivetypeyear'] = 'години (нпр. Архива/2015)';
$labels['archivetypemonth'] = 'месецу (нпр. Архива/2015/03)';
$labels['archivetypetbmonth'] = 'месецу - као Тандерберд (нпр. Архива/2012/2012-03)';
$labels['archivetypefolder'] = 'изворној фасцикли';
$labels['archivetypesender'] = 'адреси пошиљаоца';
$labels['unkownsender'] = 'непознато';
$labels['readonarchive'] = 'Поруку означи као прочитану при архивирању';
