<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail Archive plugin             |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/plugin-archive/
*/

$labels['buttontext'] = 'Архіў';
$labels['buttontitle'] = 'Перанесці ў архіў';
$labels['archived'] = 'Паспяхова перанесена ў архіў';
$labels['archivedreload'] = 'Паспяхова перанесена ў архіў. Перагрузіце старонку, каб пабачыць новыя архіўныя каталогі.';
$labels['archiveerror'] = 'Некаторыя лісты немагчыма перанесці ў архіў';
$labels['archivefolder'] = 'Архіў';
$labels['settingstitle'] = 'Архіў';
$labels['archivetype'] = 'Падзяліць архіў паводле';
$labels['archivetypeyear'] = 'года (напрыклад, Архіў/2012)';
$labels['archivetypemonth'] = 'месяца (напрыклад, Архіў/2012/06)';
$labels['archivetypetbmonth'] = 'месяца - сумяшчальнасць з Thunderbird (напрыклад, Архіў/2012/2012-06)';
$labels['archivetypefolder'] = 'зыходнага каталога';
$labels['archivetypefolderyear'] = 'года і зыходнага каталога (напрыклад, Архіў/2012/...)';
$labels['archivetypefoldermonth'] = 'года, месяца і зыходнага каталога (напрыклад, Архіў/2012/06/...)';
$labels['archivetypesender'] = 'Электронная пошта адпраўніка';
$labels['unkownsender'] = 'невядомы';
$labels['readonarchive'] = 'Пазначыць ліст прачытаным у архіве';
