<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail Password plugin            |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/plugin-password/
*/

$labels['changepasswd']  = 'Wachtwurd feroarje';
$labels['curpasswd']  = 'Aktueel wachtwurd:';
$labels['newpasswd']  = 'Nij wachtwurd:';
$labels['confpasswd']  = 'Nij wachtwurd befêstigje:';
$messages['nopassword'] = 'Fier in nij wachtwurd yn.';
$messages['nocurpassword'] = 'Fier aktueel wachtwurd yn:';
$messages['passwordincorrect'] = 'Ferkeard aktueel wachtwurd.';
$messages['passwordinconsistency'] = 'Wachtwurden komme net oerien, besykje it nochris.';
$messages['crypterror'] = 'Koe nij wachtwurd net bewarje. Fersifering funksje ûntbrekt.';
$messages['connecterror'] = 'Koe nij wachtwurd net bewarje. Ferbining flater.';
$messages['internalerror'] = 'Koe nij wachtwurd net bewarje.';
$messages['passwordshort'] = 'Wachtwurd moat op syn minst $length tekens lang.';
$messages['passwordweak'] = 'Wachtwurd moat op syn minst ien nûmer en ien lêstekens karakter befetsje.';
$messages['passwordforbidden'] = 'Wachtwurd befettet ferbeane tekens.';
$messages['firstloginchange'] = 'Dit is jo earste oanmelding. Wizigje asjobleaft jo wachtwurd.';
$messages['disablednotice'] = 'It systeem is op dit stuit ûnder ûnderhâld en wachtwurd feroaring is net mooglik. Alles soe gau werom wêze moatte nei it normale. Sorry foar it ûngemak.';
$messages['passwinhistory'] = 'Dit wachtwurd is al earder brûkt.';
$messages['samepasswd'] = 'Nij wachtwurd moat oars wêze as it âlde.';
$messages['passwdexpirewarning'] = 'Warskôging! Jo wachtwurd sil ynkoarten ferrinne, feroarje it foar $expirationdatetime.';
$messages['passwdexpired'] = 'Jo wachtwurd is ferrûn, jo moatte it no feroarje!';
