<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail Managesieve plugin         |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/plugin-managesieve/
*/


$labels['filters'] = 'അരിപ്പകള്‍';
$labels['managefilters'] = 'അകത്തോട്ടുള്ള ഇമെയില്‍ അരിപ്പകള്‍ ക്രമീകരിക്കുക';
$labels['filtername'] = 'അരിപ്പയുടെ പേര്';
$labels['newfilter'] = 'പുതിയ അരിപ്പ';
$labels['filteradd'] = 'അരിപ്പ ചേര്‍ക്കുക';
$labels['filterdel'] = 'അരിപ്പ നീക്കംചെയ്യുക';
$labels['moveup'] = 'മുകളിലേക്ക് നീക്കുക';
$labels['movedown'] = 'താഴേക്ക് നീക്കുക';
$labels['filterallof'] = 'കീഴ്പറഞ്ഞ എല്ലാ നിയമങ്ങളും പാലിക്കുന്നവ';
$labels['filteranyof'] = 'കീഴ്പറഞ്ഞ ഏതെങ്കിലും നിയമം പാലിക്കുന്നവ';
$labels['filterany'] = 'എല്ലാ സന്ദേശങ്ങളും';
$labels['filtercontains'] = 'അടങ്ങുന്നത്';
$labels['filternotcontains'] = 'ല്‍ അടങ്ങുന്നില്ല';
$labels['filteris'] = 'ന് തുല്യം';
$labels['filterisnot'] = 'ന് തുല്യമല്ല';
$labels['filterexists'] = 'നിലവിലുണ്ട്';
$labels['filternotexists'] = 'നിലവിലില്ല';
$labels['filtermatches'] = 'എക്സ്പ്രഷന്‍ ചേരുന്നുണ്ട്';
$labels['filternotmatches'] = 'എക്സ്പ്രഷന്‍ ചേരുന്നില്ല';
$labels['filterregex'] = 'റെഗുലര്‍ എക്സ്പ്രഷന്‍ ചേരുന്നുണ്ട്';
$labels['filternotregex'] = 'റെഗുലര്‍ എക്സ്പ്രഷന്‍ ചേരുന്നില്ല';
$labels['filterunder'] = 'കീഴില്‍';
$labels['filterover'] = 'മുകളില്‍';
$labels['addrule'] = 'നിയമം ചേര്‍ക്കുക';
$labels['delrule'] = 'നിയമം നീക്കം ചെയ്യുക';
$labels['messagemoveto'] = 'സന്ദേശം നിക്കു :';
$labels['messageredirect'] = 'സന്ദേശം മാറ്റിവിടു :';
$labels['messagecopyto'] = 'സന്ദേശം പകര്‍ത്തു :';
$labels['messagesendcopy'] = 'സന്ദേശത്തിന്റെ പകര്‍പ്പ് അയക്കു :';
$labels['messagereply'] = 'സന്ദേശം വെച്ച് മറുപടി അയക്കു';
$labels['messagedelete'] = 'സന്ദേശം മായ്ക്കു';
$labels['messagediscard'] = 'സന്ദേശത്തോടെ നിരാകരിക്കുക';
$labels['messagekeep'] = 'സന്ദേശം ഇൻബോക്സിൽ സൂക്ഷിക്കുക';
$labels['messagesrules'] = 'ആഗമന സന്ദേശങ്ങള്‍ക്ക്:';
$labels['messagesactions'] = '...ഈ പ്രവര്‍ത്തനങ്ങള്‍ ചെയ്യുക:';
$labels['add'] = 'ചേര്‍ക്കു';
$labels['del'] = 'നീക്കം ചെയ്യുക';
$labels['sender'] = 'അയചയാള്‍';
$labels['recipient'] = 'സ്വീകര്‍ത്താവ്';
$labels['vacationdays'] = 'എത്ര ഭിവസം കൂടുമ്പോള്‍ സന്ദേശം അയക്കണം:';
$labels['vacationinterval'] = 'എത്ര സമയം കൂടുമ്പോൾ സന്ദേശങ്ങൾ അയയ്ക്കണം:';
$labels['vacationreason'] = 'സന്ദേശത്തിന്റെ ഉള്ളടക്കം (അവധിയുടെ കാരണം):';
$labels['vacationsubject'] = 'സന്ദേശത്തിന്റെ വിഷയം:';
$labels['days'] = 'ദിവസങ്ങൾ';
$labels['seconds'] = 'സെക്കന്റുകൾ';
$labels['rulestop'] = 'നിയമങ്ങള്‍ വിലയിരുത്തുന്നത് നിര്‍ത്തുക';
$labels['enable'] = 'പ്രവര്‍ത്തനസജ്ജം/രഹിതം';
$labels['filtersets'] = 'അരിപ്പകളുടെ കൂട്ടങ്ങള്‍';
$labels['filterdef'] = 'അരിപ്പയുടെ നിര്‍വ്വചനം';
$labels['active'] = 'സജീവം';
$labels['none'] = 'ഒന്നുമില്ല';
$labels['fromset'] = 'സെറ്റില്‍ നിന്ന്';
$labels['fromfile'] = 'ഫയലില്‍ നിന്ന്';
$labels['filterdisabled'] = 'അരിപ്പ പ്രവര്‍ത്തനരഹിതമാക്കി';
$labels['countisgreaterthan'] = 'എണ്ണം ഇതിനെക്കാള്‍ കുടുതല്‍';
$labels['countisgreaterthanequal'] = 'എണ്ണം ഇതിനെക്കാള്‍ കൂടുതല്‍ ഇല്ലെങ്കില്‍ സമം';
$labels['countislessthan'] = 'എണ്ണം ഇതിനെക്കാള്‍ കുറവ്';
$labels['countislessthanequal'] = 'എണ്ണം ഇതിനെക്കാള്‍ കൂറവ് ഇല്ലെങ്കില്‍ സമം';
$labels['countequals'] = 'എണ്ണം ഇതിനോട് സമം';
$labels['countnotequals'] = 'എണ്ണം ഇതിനോട് തുല്യമല്ല';
$labels['valueisgreaterthan'] = 'മൂല്യം ഇതിനെക്കാള്‍ കുടുതല്‍';
$labels['valueisgreaterthanequal'] = 'മുല്യം ഇതിനെക്കാള്‍ കൂടുതല്‍ ഇല്ലെങ്കില്‍ സമം';
$labels['valueislessthan'] = 'മൂല്യം ഇതിനെക്കാള്‍ കുറവ്';
$labels['valueislessthanequal'] = 'മൂല്യം ഇതിനെക്കാള്‍ കൂറവ് ഇല്ലെങ്കില്‍ തുല്യം';
$labels['valueequals'] = 'മൂല്യം ഇതിനോട് സമം';
$labels['valuenotequals'] = 'മൂല്യം ഇതിനോട് തുല്യമല്ല';
$labels['setflags'] = 'സന്ദേശത്തില്‍ അടയാളമിടുക';
$labels['addflags'] = 'സന്ദേശത്തില്‍ അടയാളം ചേര്‍ക്കുക';
$labels['removeflags'] = 'സന്ദേശത്തില്‍ നിന്നും അടയാളം മാറ്റുക';
$labels['flagread'] = 'വായിച്ചവ';
$labels['flagdeleted'] = 'നീക്കം ചെയ്തവ';
$labels['flaganswered'] = 'മറുപടി നല്‍കിയവ';
$labels['flagflagged'] = 'അടയാളപ്പെടുത്തിയവ';
$labels['flagdraft'] = 'കരട്';
$labels['setvariable'] = 'വേരിയബിൾ സ്ഥിരപ്പെടുത്തുക';
$labels['setvarname'] = 'വേരിയബിളിന്റെ പേര്';
$labels['setvarvalue'] = 'വേരിയബിളിന്റെ മൂല്യം';
$labels['notifymethodmailto'] = 'ഇമെയില്‍';
$labels['notifymethodtel'] = 'ഫോണ്‍';
$labels['filtercreate'] = 'അരിപ്പ ഉണ്ടാക്കുക';
$labels['usedata'] = 'ഈ വിവരങ്ങള്‍ അരിപ്പയില്‍ ഉപയോഗിക്കുക:';
$labels['nextstep'] = 'അടുത്ത പടി';
$labels['...'] = '...';
$labels['datetest'] = 'തീയതി';
$labels['advancedopts'] = 'വിപുലീക്രിതമായ ക്രമീകരണങ്ങള്‍';
$labels['body'] = 'ഉള്ളടക്കം';
$labels['address'] = 'മേല്‍വിലാസം';
$labels['envelope'] = 'എന്‍വലപ്പ്';
$labels['modifier'] = 'മോഡിഫയര്‍:';
$labels['text'] = 'വാചകം';
$labels['undecoded'] = 'ഡീക്കോഡ് ചെയ്യാത്തത് (റോ)';
$labels['contenttype'] = 'ഉള്ളടക്കത്തിന്റെ തരം';
$labels['modtype'] = 'തരം:';
$labels['allparts'] = 'എല്ലാം';
$labels['domain'] = 'ഡൊമൈന്‍';
$labels['localpart'] = 'പ്രാദേശിക ഭാഗം';
$labels['user'] = 'ഉപയോക്താവു്';
$labels['detail'] = 'വിശദാംശം';
$labels['comparator'] = 'താരതമ്യകന്‍:';
$labels['default'] = 'സഹജമായ';
$labels['octet'] = 'കര്‍ശനം (octet)';
$labels['asciicasemap'] = 'വലിയ-ചെറിയക്ഷരങ്ങള്‍ തമ്മില്‍ വ്യത്യാസമില്ലാത്ത (ascii-casemap)';
$labels['asciinumeric'] = 'സംഖ്യകള്‍ (ascii-numeric)';
$labels['spamtestequals'] = 'ന് തുല്യം';
$labels['spamtestnotequals'] = 'ന് തുല്യമല്ല';
$labels['vacation.subject'] = 'വിഷയം';
$labels['vacation.body'] = 'ഉള്ളടക്കം';
$messages['filterunknownerror'] = 'അജ്ഞാതമായ സെര്‍വ്വര്‍ പിശക്.';
$messages['filterconnerror'] = 'സെര്‍വ്വറുമായി ബന്ധപ്പെടാന്‍ സാധിക്കുന്നില്ല.';
$messages['filterdeleted'] = 'അരിപ്പ വിജകരമായി മായ്ച്ചു.';
$messages['filtersaved'] = 'അരിപ്പ വിജകരമായി സൂക്ഷിച്ചു.';
$messages['filterdeleteconfirm'] = 'തെരഞ്ഞെടുത്ത അരിപ്പ നീക്കം ചെയ്യണമെന്ന് ഉറപ്പാണോ?';
$messages['ruledeleteconfirm'] = 'തെരഞ്ഞെടുത്ത നിയമം നീക്കം ചെയ്യണമെന്ന് ഉറപ്പാണോ?';
$messages['actiondeleteconfirm'] = 'തെരഞ്ഞെടുത്ത പ്രവര്‍ത്തി നീക്കം ചെയ്യണമെന്ന് ഉറപ്പാണോ?';
$messages['forbiddenchars'] = 'ഫില്‍ഡില്‍ സാധുവല്ലാത്ത അക്ഷരങ്ങള്‍.';
$messages['cannotbeempty'] = 'ഫീല്‍ഡ് ശൂന്യമാകാന്‍ പാടില്ല.';
$messages['ruleexist'] = 'ഈ പേരിലുള്ള അരിപ്പ ഇപ്പോള്‍ തന്നെ ഉണ്ട്.';
$messages['deactivated'] = 'അരിപ്പ വിജകരമായി പ്രവര്‍ത്തനസജ്ജമാക്കി.';
$messages['activated'] = 'അരിപ്പകള്‍ നിര്‍വീര്യം ആക്കപ്പെട്ടിരിക്കുന്നു';
$messages['moved'] = 'അരിപ്പ വിജകരമായി മാറ്റി.';
$messages['nametoolong'] = 'പേരിന് നീളം കൂടുതല്‍.';
$messages['namereserved'] = 'നീക്കിവെച്ച വാക്ക്.';
$messages['setexist'] = 'കൂട്ടം നേരത്തെ തന്നെ ഉണ്ട്.';
$messages['nodata'] = 'ഒരു സ്ഥാനമെങ്കിലും തെരഞ്ഞെടുക്കണം!';
