<?php

/*
 +-----------------------------------------------------------------------+
 | localization/ru_RU/csv2vcard.inc                                      |
 |                                                                       |
 | Language file of the Roundcube Webmail client                         |
 | Copyright (C) 2005-2014, The Roundcube Dev Team                       |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 |                                                                       |
 +-----------------------------------------------------------------------+
 | Author: Aleksander Machniak <alec@alec.pl>                            |
 +-----------------------------------------------------------------------+
*/
$map['birth_day'] = "День рождения";
$map['birth_month'] = "Месяц рождения";
$map['birth_year'] = "Год рождения";
$map['display_name'] = "Отображаемое имя";
$map['fax_number'] = "Номер факса";
$map['home_address'] = "Адрес";
$map['home_city_short'] = "Город";
$map['home_state_short'] = "Штат";
$map['home_country'] = "Страна";
$map['home_zipcode'] = "Почтовый индекс";
$map['mobile_number'] = "Номер сотового телефона";
$map['nickname'] = "Псевдоним";
$map['organization'] = "Организация";
$map['pager_number'] = "Номер пейджера";
$map['primary_email'] = "Адрес электронной почты";
$map['secondary_email'] = "Альтернативный адрес электронной почты";
$map['web_page_1'] = "Веб-страница 1";
$map['web_page_2'] = "Веб-страница 2";
$map['web_page'] = "Веб-страница";
$map['notes'] = "Заметки";
$map['work_phone'] = "Рабочий телефон";
$map['work_address'] = "Адрес (раб.)";
$map['work_country'] = "Страна (раб.)";
$map['work_zipcode'] = "Почтовый индекс (раб.)";
$map['last'] = "Фамилия";
$map['first'] = "Имя";
$map['work_city'] = "Город (раб.)";
$map['work_state_short'] = "Штат (раб.)";
