<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail ACL plugin                 |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/plugin-acl/
*/

$labels['sharing'] = 'Sdílení';
$labels['myrights'] = 'Přístupová práva';
$labels['username'] = 'Uživatel:';
$labels['advanced'] = 'Pokročilý režim';
$labels['add'] = 'Přidej';
$labels['newuser'] = 'Přidat záznam';
$labels['editperms'] = 'Upravit oprávnění';
$labels['actions'] = 'Přístupové právo akce ...';
$labels['anyone'] = 'Všichni uživatelé (kdokoli)';
$labels['anonymous'] = 'Hosté (anonymní)';
$labels['identifier'] = 'Identifikátor';
$labels['acll'] = 'Vyhledat';
$labels['aclr'] = 'Číst zprávy';
$labels['acls'] = 'Ponechat stav Přečteno';
$labels['aclw'] = 'Zapsat označení';
$labels['acli'] = 'Vložit (Kopírovat do)';
$labels['aclp'] = 'Odeslat';
$labels['aclc'] = 'Vytvořit podsložky';
$labels['aclk'] = 'Vytvořit podsložky';
$labels['acld'] = 'Smazat zprávy';
$labels['aclt'] = 'Smazat zprávy';
$labels['acle'] = 'Vyprázdnit';
$labels['aclx'] = 'Smazat složku';
$labels['acla'] = 'Spravovat';
$labels['acln'] = 'Označit zprávy poznámkou';
$labels['aclfull'] = 'Plný přístup';
$labels['aclother'] = 'Ostatní';
$labels['aclread'] = 'Číst';
$labels['aclwrite'] = 'Zapsat';
$labels['acldelete'] = 'Smazat';
$labels['shortacll'] = 'Vyhledat';
$labels['shortaclr'] = 'Číst';
$labels['shortacls'] = 'Zachovat';
$labels['shortaclw'] = 'Zapsat';
$labels['shortacli'] = 'Vložit';
$labels['shortaclp'] = 'Odeslat';
$labels['shortaclc'] = 'Vytvořit';
$labels['shortaclk'] = 'Vytvořit';
$labels['shortacld'] = 'Smazat';
$labels['shortaclt'] = 'Smazat';
$labels['shortacle'] = 'Vyprázdnit';
$labels['shortaclx'] = 'Mazat složky';
$labels['shortacla'] = 'Spravovat';
$labels['shortacln'] = 'Označit poznámkou';
$labels['shortaclother'] = 'Ostatní';
$labels['shortaclread'] = 'Číst';
$labels['shortaclwrite'] = 'Zapsat';
$labels['shortacldelete'] = 'Smazat';
$labels['longacll'] = 'Složka je viditelná v seznamu a může být přihlášena';
$labels['longaclr'] = 'Složka může být otevřena pro čtení';
$labels['longacls'] = 'Označená zpráva byla změněna';
$labels['longaclw'] = 'Značky a klíčová slova u zpráv je možné měnit, kromě příznaku Přečteno a Smazáno';
$labels['longacli'] = 'Zpráva může být napsána nebo zkopírována do složky';
$labels['longaclp'] = 'Zpráva může být odeslána do této složky';
$labels['longaclc'] = 'Složka může být vytvořena (nebo přejmenována) přimo v této složce';
$labels['longaclk'] = 'Složka může být vytvořena (nebo přejmenována) přimo v této složce';
$labels['longacld'] = 'Příznak smazané zprávy může být změněn';
$labels['longaclt'] = 'Příznak smazané zprávy může být změněn';
$labels['longacle'] = 'Zpráva může být smazána';
$labels['longaclx'] = 'Složka může být smazána nebo přejmenována';
$labels['longacla'] = 'Přístupová práva složky mohou být změněna';
$labels['longacln'] = 'Zprávamy sdílené metadata (poznámky) mohou být změněny';
$labels['longaclfull'] = 'Plný přístup včetně správy složky';
$labels['longaclread'] = 'Složka může být otevřena pro čtení';
$labels['longaclwrite'] = 'Zpráva může být označena, napsána nebo zkopírována do složky';
$labels['longacldelete'] = 'Zprávy mohou být smazány';
$labels['longaclother'] = 'Jiná přístupová oprávnění';
$labels['ariasummaryacltable'] = 'Seznam oprávnění';
$labels['arialabelaclactions'] = 'Seznam akcí';
$labels['arialabelaclform'] = 'Formulář pro přístupová oprávnění';
$messages['deleting'] = 'Odstraňuji přístupová práva...';
$messages['saving'] = 'Ukládám přístupová práva...';
$messages['updatesuccess'] = 'Přístupová práva byla změněna';
$messages['deletesuccess'] = 'Přístupová práva byla odstraněna';
$messages['createsuccess'] = 'Přístupová práva byla přidána';
$messages['updateerror'] = 'Úprava přístupových práv se nezdařila';
$messages['deleteerror'] = 'Smazání přístupových práv se nezdařilo';
$messages['createerror'] = 'Přidání přístupových práv se nezdařilo';
$messages['deleteconfirm'] = 'Opravdu si přejete odstranit přístupová práva pro vybrané(ho) uživatele?';
$messages['norights'] = 'Nejsou specifikována žádná práva!';
$messages['nouser'] = 'Není specifikováno uživatelské jméno!';
