<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail Archive plugin             |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/plugin-archive/
*/

$labels['buttontext'] = 'Arşîv';
$labels['buttontitle'] = 'vê peyamê arşîv bike';
$labels['archived'] = 'Bi serkeftin hat arşîvkirin';
$labels['archivedreload'] = 'Bi serkeftin hat arşîvkirin. Rûpelê dîsa bar bike da dosyeyên arşîvê yên nû bibînî.';
$labels['archiveerror'] = 'Hin peyam nehatin arşîvkirin.';
$labels['archivefolder'] = 'Arşîv';
$labels['settingstitle'] = 'Arşîv';
$labels['archivetype'] = 'Arşîvê dabeşîne';
$labels['archivetypeyear'] = 'Sal (wek Arşîv/2012)';
$labels['archivetypemonth'] = 'Meh (wek Arşîv/2012/06)';
$labels['archivetypefolder'] = 'Dosyeya resen';
$labels['archivetypesender'] = 'Emaila şandyar';
$labels['unkownsender'] = 'nenas';
