<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail Archive plugin             |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/plugin-archive/
*/

$labels['buttontext'] = 'ארכיון';
$labels['buttontitle'] = 'משלוח ההודעה לארכיב';
$labels['archived'] = 'עדכון הארכיון הצליח';
$labels['archivedreload'] = 'נשמר בהצלחה בארכיב. יש לרענו את הדף כדי לראות את התיקיות החדשות בארכיב.';
$labels['archiveerror'] = 'לא ניתן היה להעביר לארכיב חלק מההודעות';
$labels['archivefolder'] = 'ארכיון';
$labels['settingstitle'] = 'ארכיב';
$labels['archivetype'] = 'לחלק את הארכיב על ידי';
$labels['archivetypeyear'] = 'שנה ( לדוגמה, ארכיב/2012 )';
$labels['archivetypemonth'] = 'חודש ( לדוגמה, ארכיב/2012/06 )';
$labels['archivetypetbmonth'] = 'חודש - תואם תאנדרבירד ( לדוגמה, ארכיב/2012/2012-06 )';
$labels['archivetypefolder'] = 'תיקיה מקורית';
$labels['archivetypefolderyear'] = 'שנה ושם התיקיה המקורית ( לדוגמה, לקוחות/2012 )';
$labels['archivetypefoldermonth'] = 'שנה, חודש ושם התיקיה המקורית (לדוגמה, לקוחות/2012/06/.....)';
$labels['archivetypesender'] = 'שולח ההודעה';
$labels['unkownsender'] = 'לא ידוע';
$labels['readonarchive'] = 'יש לסמן את ההודעה בארכיב כאילו נקראה';
