<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail Managesieve plugin         |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/plugin-managesieve/
*/


$labels['filters'] = 'Filtros';
$labels['managefilters'] = 'Gerir filtros';
$labels['filtername'] = 'Nome do filtro';
$labels['newfilter'] = 'Novo filtro';
$labels['filteradd'] = 'Adicionar filtro';
$labels['filterdel'] = 'Eliminar filtro';
$labels['rules'] = 'Regras';
$labels['actions'] = 'Ações';
$labels['scope'] = 'Âmbito';
$labels['moveup'] = 'Mover para cima';
$labels['movedown'] = 'Mover para baixo';
$labels['filterallof'] = 'corresponde a todas as seguintes regras';
$labels['filteranyof'] = 'corresponde a uma das seguintes regras';
$labels['filterany'] = 'todas as mensagens';
$labels['filtercontains'] = 'contém';
$labels['filternotcontains'] = 'não contém';
$labels['filteris'] = 'é igual a';
$labels['filterisnot'] = 'é diferente de';
$labels['filterexists'] = 'existe';
$labels['filternotexists'] = 'não existe';
$labels['filtermatches'] = 'expressão corresponde';
$labels['filternotmatches'] = 'expressão não corresponde';
$labels['filterregex'] = 'corresponde à expressão';
$labels['filternotregex'] = 'não corresponde à expressão';
$labels['filterunder'] = 'é inferior a';
$labels['filterover'] = 'é superior a';
$labels['mime'] = 'MIME:';
$labels['mimepart'] = 'Parte MIME:';
$labels['mime-message'] = 'mensagem';
$labels['mime-anychild'] = 'qualquer';
$labels['mime-type'] = 'tipo';
$labels['mime-subtype'] = 'subtipo';
$labels['mime-contenttype'] = 'tipo de conteúdo';
$labels['mime-param'] = 'parâmetro';
$labels['addrule'] = 'Adicionar regra';
$labels['delrule'] = 'Eliminar regra';
$labels['messagemoveto'] = 'Mover mensagem para';
$labels['messageredirect'] = 'Redirecionar mensagem para';
$labels['messagecopyto'] = 'Copiar mensagem para';
$labels['messagesendcopy'] = 'Enviar cópia da mensagem para';
$labels['messagereply'] = 'Responder com a mensagem';
$labels['messagedelete'] = 'Eliminar mensagem';
$labels['messagediscard'] = 'Rejeitar mensagem';
$labels['messagekeep'] = 'Manter mensagem na Caixa de entrada';
$labels['messagesrules'] = 'Regras para Filtros';
$labels['messagesactions'] = 'Acções para Filtros';
$labels['add'] = 'Adicionar';
$labels['del'] = 'Eliminar';
$labels['sender'] = 'Remetente';
$labels['recipient'] = 'Destinatário';
$labels['vacationaddr'] = 'Os meus endereços de email:';
$labels['vacationdays'] = 'Enviar mensagens com que frequência (em dias):';
$labels['vacationinterval'] = 'Com que frequência envia mensagens:';
$labels['vacationreason'] = 'Conteúdo da mensagem (motivo da ausência):';
$labels['vacationfrom'] = 'Endereço de resposta do remetente:';
$labels['vacationsubject'] = 'Assunto da mensagem:';
$labels['days'] = 'dias';
$labels['seconds'] = 'segundos';
$labels['rulestop'] = 'Parar de avaliar regras';
$labels['enable'] = 'Activar/Desactivar';
$labels['filterset'] = 'Conjunto de filtros';
$labels['filtersets'] = 'Filtros definidos';
$labels['filtersetadd'] = 'Adicionar conjunto de filtros';
$labels['filtersetdel'] = 'Eliminar conjunto de filtros';
$labels['filtersetact'] = 'Ativar conjunto de filtros atuais';
$labels['filtersetdeact'] = 'Desativar conjunto de filtros atuais';
$labels['filterseteditraw'] = 'Editar conjunto de filtros';
$labels['filtersetswitch'] = 'Ativar/desativar conjunto de filtros';
$labels['filterdef'] = 'Definição de filtros';
$labels['filtersetname'] = 'Nome do conjunto de filtros';
$labels['newfilterset'] = 'Novo conjunto de filtros';
$labels['active'] = 'ativo';
$labels['none'] = 'nehnum';
$labels['fromset'] = 'a partir do conjunto';
$labels['fromfile'] = 'a partir do ficheiro';
$labels['filterdisabled'] = 'Filtro desactivado';
$labels['filterenabled'] = 'Filtro activado';
$labels['countisgreaterthan'] = 'contagem é maior que';
$labels['countisgreaterthanequal'] = 'contagem é maior ou igual a';
$labels['countislessthan'] = 'contagem é menor que';
$labels['countislessthanequal'] = 'contagem é menor ou igual a';
$labels['countequals'] = 'contagem é igual a';
$labels['countnotequals'] = 'a contagem não é igual a';
$labels['valueisgreaterthan'] = 'valor é maior que';
$labels['valueisgreaterthanequal'] = 'valor é maior ou igual a';
$labels['valueislessthan'] = 'valor é menor que';
$labels['valueislessthanequal'] = 'valor é menor ou igual a';
$labels['valueequals'] = 'valor é igual a';
$labels['valuenotequals'] = 'o valor não é igual a';
$labels['setflags'] = 'Definir sinalizadores para a mensagem';
$labels['addflags'] = 'Adicionar sinalizadores à mensagem';
$labels['removeflags'] = 'Eliminar sinalizadores da mensagem';
$labels['flagread'] = 'Lida';
$labels['flagdeleted'] = 'Eliminada';
$labels['flaganswered'] = 'Respondida';
$labels['flagflagged'] = 'Sinalizada';
$labels['flagdraft'] = 'Rascunho';
$labels['addheader'] = 'Adicionar cabeçalho à mensagem';
$labels['deleteheader'] = 'Remover cabeçalho da mensagem';
$labels['headername'] = 'Nome do cabeçalho';
$labels['headervalue'] = 'Valor do cabeçalho';
$labels['headerpos'] = 'Posição do cabeçalho';
$labels['headeratstart'] = 'no início';
$labels['headeratend'] = 'no fim';
$labels['headeroccurrence'] = 'Ocorrência/posição do cabeçalho';
$labels['headerfromstart'] = 'do início';
$labels['headerfromend'] = 'do fim';
$labels['headerpatterns'] = 'Padrões de valor de cabeçalho';
$labels['headermatchtype'] = 'tipo de correspondência:';
$labels['setvariable'] = 'Definir variável';
$labels['setvarname'] = 'Nome da variável:';
$labels['setvarvalue'] = 'Valor da variável:';
$labels['setvarmodifiers'] = 'Modificadores:';
$labels['varlower'] = 'minúscula';
$labels['varupper'] = 'maiúscula';
$labels['varlowerfirst'] = 'primeira letra em minúscula';
$labels['varupperfirst'] = 'primeira letra em maiúscula';
$labels['varquotewildcard'] = 'citar caracteres especiais';
$labels['varlength'] = 'tamanho';
$labels['varencodeurl'] = 'codificado por percentagem (para URLs)';
$labels['notify'] = 'Enviar notificação';
$labels['notifytarget'] = 'Destino da notificação:';
$labels['notifymessage'] = 'Mensagem de notificação (opcional):';
$labels['notifyoptions'] = 'Opções de notificação (opcional):';
$labels['notifyfrom'] = 'Remetente da notificação (opcional):';
$labels['notifyimportance'] = 'Importância:';
$labels['notifyimportancelow'] = 'baixa';
$labels['notifyimportancenormal'] = 'normal';
$labels['notifyimportancehigh'] = 'alta';
$labels['notifymethodmailto'] = 'Email';
$labels['notifymethodtel'] = 'Telefone';
$labels['notifymethodsms'] = 'SMS';
$labels['filtercreate'] = 'Criar filtro';
$labels['usedata'] = 'Usar os seguintes dados no filtro:';
$labels['nextstep'] = 'Passo seguinte';
$labels['...'] = '...';
$labels['string'] = 'Cadeia';
$labels['currdate'] = 'Data atual';
$labels['datetest'] = 'Data';
$labels['dateheader'] = 'cabeçalho:';
$labels['year'] = 'ano';
$labels['month'] = 'mês';
$labels['day'] = 'dia';
$labels['date'] = 'data (yyyy-mm-dd)';
$labels['julian'] = 'data (juliano)';
$labels['hour'] = 'hora';
$labels['minute'] = 'minuto';
$labels['second'] = 'segundo';
$labels['time'] = 'hora (hh:mm:ss)';
$labels['iso8601'] = 'data (ISO8601)';
$labels['std11'] = 'data (RFC2822)';
$labels['zone'] = 'fuso horário';
$labels['weekday'] = 'dia da semana (0-6)';
$labels['advancedopts'] = 'Opções avançadas';
$labels['body'] = 'Corpo';
$labels['address'] = 'endereço';
$labels['envelope'] = 'envelope';
$labels['modifier'] = 'modificador:';
$labels['text'] = 'Texto';
$labels['undecoded'] = 'não descodificado (raw)';
$labels['contenttype'] = 'tipo de conteúdo';
$labels['modtype'] = 'tipo:';
$labels['allparts'] = 'todos';
$labels['domain'] = 'domínio';
$labels['localpart'] = 'parte local';
$labels['user'] = 'utilizador';
$labels['detail'] = 'detalhe';
$labels['comparator'] = 'Comparador';
$labels['default'] = 'predefinido';
$labels['octet'] = 'estrito (octeto)';
$labels['asciicasemap'] = 'não sensível a maiúsculas/minúsculas (caracteres ascii)';
$labels['asciinumeric'] = 'numérico (numérico ascii)';
$labels['index'] = 'índice:';
$labels['indexlast'] = 'retroceder';
$labels['spamtest'] = 'Nível de spam';
$labels['spamtestisgreaterthan'] = 'é maior que';
$labels['spamtestisgreaterthanequal'] = 'é maior ou igual a';
$labels['spamtestislessthan'] = 'é menor que';
$labels['spamtestislessthanequal'] = 'é menor ou igual a';
$labels['spamtestequals'] = 'é igual a';
$labels['spamtestnotequals'] = 'é diferente de';
$labels['spamtestisunknown'] = 'é desconhecido';
$labels['vacation'] = 'Ausente do Escritório';
$labels['vacation.reply'] = 'Mensagem de resposta';
$labels['vacation.advanced'] = 'Definições avançadas';
$labels['vacation.from'] = 'Endereço de resposta do remetente';
$labels['vacation.subject'] = 'Assunto';
$labels['vacation.body'] = 'Corpo da mensagem';
$labels['vacation.start'] = 'Hora de início';
$labels['vacation.end'] = 'Hora de fim';
$labels['vacation.status'] = 'Estado';
$labels['vacation.on'] = 'Ligar';
$labels['vacation.off'] = 'Desligar';
$labels['vacation.addresses'] = 'Os meus endereços de email';
$labels['vacation.interval'] = 'Intervalo de resposta';
$labels['vacation.after'] = 'Colocar a regra Ausente-do-Escritório depois';
$labels['vacation.saving'] = 'A guardar dados...';
$labels['vacation.action'] = 'Acção para mensagem recebida';
$labels['vacation.keep'] = 'Manter';
$labels['vacation.discard'] = 'Rejeitar';
$labels['vacation.redirect'] = 'Redireccionar para';
$labels['vacation.copy'] = 'Enviar cópia para';
$labels['forward'] = 'Reencaminhamento';
$labels['forward.redirect'] = 'Redireccionar para';
$labels['forward.copy'] = 'Enviar cópia para';
$labels['forward.on'] = 'Ligar';
$labels['forward.off'] = 'Desligar';
$labels['forward.status'] = 'Estado:';
$labels['forward.action'] = 'Executar a seguinte ação para os mails recebidos:';
$labels['forward.saving'] = 'A guardar dados...';
$labels['filladdresses'] = 'Preencher com todos os meus endereços';
$labels['arialabelfiltersetactions'] = 'Acções do conjunto de filtros';
$labels['arialabelfilteractions'] = 'Acções dos filtros';
$labels['arialabelfilterform'] = 'Propriedades dos filtro';
$labels['ariasummaryfilterslist'] = 'Lista de filtros';
$labels['ariasummaryfiltersetslist'] = 'Lista de conjuntos de filtros';
$labels['filterstitle'] = 'Editar filtros de mensagens recebidas';
$labels['vacationtitle'] = 'Editar regra de ausência do escritório';
$labels['forwardtitle'] = 'Editar regra de reencaminhamento de mail';
$labels['message'] = 'Mensagem';
$labels['duplicate'] = 'é duplicado';
$labels['notduplicate'] = 'não é duplicado';
$labels['duplicate.handle'] = 'identificador:';
$labels['duplicate.header'] = 'cabeçalho:';
$labels['duplicate.uniqueid'] = 'identificador:';
$labels['duplicate.seconds'] = 'tempo esgotado (segundos):';
$labels['duplicate.last'] = 'relativamente à última execução';
$messages['filterunknownerror'] = 'Erro de servidor desconhecido';
$messages['filterconnerror'] = 'Não é possível ligar ao servidor Sieve';
$messages['filterdeleteerror'] = 'Não foi possível eliminar o filtro.  Ocorreu um erro no servidor.';
$messages['filterdeleted'] = 'Filtro eliminado com sucesso';
$messages['filtersaved'] = 'Filtro guardado com sucesso';
$messages['filtersaveerror'] = 'Não foi possível guardar o filtro.  Ocorreu um erro no servidor.';
$messages['filterformerror'] = 'O formulário de filtro contém erros.';
$messages['filterdeleteconfirm'] = 'Tem a certeza que pretende eliminar este filtro?';
$messages['ruledeleteconfirm'] = 'Tem a certeza que pretende eliminar esta regra?';
$messages['actiondeleteconfirm'] = 'Tem a certeza que pretende eliminar esta acção?';
$messages['forbiddenchars'] = 'Caracteres inválidos no campo.';
$messages['cannotbeempty'] = 'Este campo não pode estar vazio.';
$messages['ruleexist'] = 'Já existe um Filtro com o nome especificado.';
$messages['setactivateerror'] = 'Não foi possível ativar o conjunto de filtros selecionado. Erro do servidor.';
$messages['setdeactivateerror'] = 'Não foi possível desativar o conjunto de filtros selecionado. Erro do servidor.';
$messages['setdeleteerror'] = 'Não foi possível eliminar o conjunto de filtros selecionado. Erro do servidor.';
$messages['setactivated'] = 'Conjunto de filtros ativado com sucesso.';
$messages['setdeactivated'] = 'Conjunto de filtros desativado com sucesso.';
$messages['setdeleted'] = 'Conjunto de filtros eliminado com sucesso.';
$messages['setupdated'] = 'Conjunto de filtros atualizado com sucesso.';
$messages['setdeleteconfirm'] = 'Tem a certeza que pretende eliminar o conjunto de filtros selecionado?';
$messages['setcreateerror'] = 'Não foi possível criar o conjunto de filtros selecionado. Erro do servidor.';
$messages['setcreated'] = 'Conjunto de filtros criado com sucesso.';
$messages['activateerror'] = 'Não foi possível ativar os filtros selecionados. Ocorreu um erro no servidor.';
$messages['deactivateerror'] = 'Não foi possível desativar os filtros selecionados. Ocorreu um erro no servidor.';
$messages['deactivated'] = 'Filtro(s) ativado(s) com sucesso.';
$messages['activated'] = 'Filtro(s) desativado(s) com sucesso.';
$messages['moved'] = 'Filtro movido com sucesso.';
$messages['moveerror'] = 'Não foi possível mover o filtro selecionado. Ocorreu um erro no servidor.';
$messages['nametoolong'] = 'Nome demasiado longo.';
$messages['namereserved'] = 'Nome invertido.';
$messages['setexist'] = 'O conjunto já existe.';
$messages['nodata'] = 'Deve selecionar pelo menos uma posição.';
$messages['invaliddateformat'] = 'Data ou formato de data inválido.';
$messages['saveerror'] = 'Não foi possível guardar os dados. Ocorreu um erro no servidor.';
$messages['vacationsaved'] = 'Regra Ausente-do-Escritório guardada com sucesso.';
$messages['forwardsaved'] = 'Dados de reencaminhamento guardados com sucesso.';
$messages['emptyvacationbody'] = 'É necessário o corpo da mensagem de férias!';
$messages['duplicate.conflict.err'] = 'Ambos, cabeçalho e identificador único, não são permitidos.';
$messages['disabledaction'] = 'Ação não permitida.';
$messages['lastindexempty'] = 'É necessário o índice quando se conta a partir do fim';
$messages['noflagset'] = 'Deve seleccionar pelo menos um sinalizador.';
