<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail client                     |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/messages/
*/

$messages['errortitle']  = 'Si è verificato un errore!';
$messages['loginfailed']  = 'Accesso non riuscito.';
$messages['cookiesdisabled'] = 'Il tuo browser non accetta i cookies.';
$messages['sessionerror'] = 'Sessione non valida o scaduta.';
$messages['cookiesmismatch'] = 'Rilevata una mancata corrispondenza dei cookies. Per favore, cancella i cookies del tuo browser.';
$messages['storageerror'] = 'Impossibile connettersi al server IMAP';
$messages['servererror'] = 'Errore del server!';
$messages['servererrormsg'] = 'Errore del server: $msg';
$messages['accountlocked'] = 'Troppi tentativi di accesso non riusciti. Tenta di nuovo più tardi.';
$messages['connerror'] = 'Errore di connessione (impossibile raggiungere il server)!';
$messages['dberror'] = 'Errore del database!';
$messages['dbconnerror'] = 'Impossibile collegarsi al database!';
$messages['windowopenerror'] = 'La finestra di popup è stata bloccata!';
$messages['requesttimedout'] = 'Richiesta scaduta';
$messages['errorreadonly'] = 'Impossibile eseguire l\'operazione. Cartella in sola lettura';
$messages['errornoperm'] = 'Impossibile eseguire l\'operazione. Permesso negato';
$messages['erroroverquota'] = 'Impossibile eseguire l\'operazione. Spazio su disco non sufficiente.';
$messages['erroroverquotadelete'] = 'Spazio su disco non sufficiente. Utilizza SHIFT+CANC per eliminare un messaggio.';
$messages['invalidrequest'] = 'Richiesta non valida! Nessun dato salvato.';
$messages['invalidhost'] = 'Nome del server non valido.';
$messages['nomessagesfound'] = 'Nessun messaggio trovato in questa cartella';
$messages['loggedout'] = 'Hai correttamente terminato la sessione. A presto!';
$messages['mailboxempty'] = 'La casella di posta è vuota';
$messages['nomessages'] = 'Non ci sono messaggi';
$messages['refreshing'] = 'Aggiornamento...';
$messages['loading'] = 'Caricamento...';
$messages['uploading'] = 'Caricamento file...';
$messages['attaching'] = 'Sto allegando il file...';
$messages['uploadingmany'] = 'Caricamento file...';
$messages['loadingdata'] = 'Caricamento dati...';
$messages['checkingmail'] = 'Controllo nuovi messaggi...';
$messages['sendingmessage'] = 'Invio messaggio in corso...';
$messages['messagesent'] = 'Messaggio inviato correttamente';
$messages['savingmessage'] = 'Salvataggio messaggio...';
$messages['messagesaved'] = 'Messaggio salvato in bozze';
$messages['successfullysaved'] = 'Salvato correttamente.';
$messages['savingresponse'] = 'Salvataggio della risposta...';
$messages['deleteresponseconfirm'] = 'Sei sicuro di voler eliminare questa risposta?';
$messages['nocontactselected'] = 'Non hai ancora selezionato un contatto.';
$messages['addedsuccessfully'] = 'Contatto aggiunto alla rubrica';
$messages['contactexists'] = 'Esiste già un contatto con questo indirizzo email.';
$messages['contactnameexists'] = 'Esiste già un contatto con questo nome';
$messages['blockedimages'] = 'Per proteggere la tua privacy, le immagini remote di questo messaggio sono state bloccate.';
$messages['blockedresources'] = 'Per proteggere la tua privacy le risorse remote sono state bloccate.';
$messages['suspiciousemail'] = 'Questo messaggio contiene indirizzi email sospetti che potrebbero essere fraudolenti.';
$messages['bccemail'] = 'I messaggi inoltrati includono destinatari riservati (Ccn).';
$messages['bouncehint'] = 'Il messaggio verrà inviato senza alcuna modifica, ovvero utilizzando il corpo, le intestazioni e i destinatari originali.';
$messages['encryptedmessage'] = 'Questo messaggio è cifrato e non può essere visualizzato. Spiacenti!';
$messages['externalmessagedecryption'] = 'Questo messaggio è cifrato e può essere decifrato attraverso un\'estensione del browser.';
$messages['nopubkeyfor'] = 'Non è stata trovata una chiave pubblica valida per l\'indirizzo $email';
$messages['nopubkeyforsender'] = 'Non è stata trovata una chiave pubblica valida per la tua identità mittente. Si desidera cifrare il messaggio solo per i destinatari?';
$messages['encryptnoattachments'] = 'Gli allegati già caricati non possono essere cifrati. Si prega di aggiungerli di nuovo all\'editor di cifratura.';
$messages['searchpubkeyservers'] = 'Si desidera effettuare una ricerca di server di chiavi pubbliche per le chiavi mancanti?';
$messages['encryptpubkeysfound'] = 'Sono state trovate le seguenti chiavi pubbliche:';
$messages['keyservererror'] = 'Tentativo non riuscito di ottenere la chiave dal keyserver.';
$messages['keyimportsuccess'] = 'Chiave pubblica $key importata con successo nel tuo portachiavi.';
$messages['nocontactsfound'] = 'Nessun contatto';
$messages['contactnotfound'] = 'Il contatto richiesto non è stato trovato';
$messages['contactsearchonly'] = 'Devi usare un modulo di ricerca per vedere i contatti dalla rubrica selezionata.';
$messages['sendingfailed'] = 'Impossibile inviare il messaggio';
$messages['senttooquickly'] = 'Per favore, attendi $sec secondi prima di inviare questo messaggio';
$messages['errorsavingsent'] = 'Si è verificato un errore nel salvare il messaggio inviato.';
$messages['errorsaving'] = 'Si è verificato un errore nel salvataggio.';
$messages['errormoving'] = 'Impossibile spostare il messaggio';
$messages['errorcopying'] = 'Impossibile copiare il messaggio';
$messages['errordeleting'] = 'Impossibile eliminare il messaggio';
$messages['errormarking'] = 'Impossibile segnare il messaggio';
$messages['alerttitle'] = 'Attenzione';
$messages['confirmationtitle'] = 'Sei sicuro...';
$messages['deletecontactconfirm']  = 'Sei sicuro di voler eliminare i contatti selezionati?';
$messages['deletegroupconfirm']  = 'Sei sicuro di voler eliminare i gruppi selezionati?';
$messages['deletemessagesconfirm'] = 'Sei sicuro di voler eliminare i messaggi selezionati?';
$messages['deletefolderconfirm']  = 'Sei sicuro di voler eliminare la cartella selezionata?';
$messages['movefolderconfirm']  = 'Sei sicuro di voler spostare la cartella selezionata?';
$messages['purgefolderconfirm']  = 'Sei sicuro di voler eliminare tutti i messaggi in questa cartella?';
$messages['contactdeleting'] = 'Eliminazione contatti...';
$messages['groupdeleting'] = 'Eliminazione gruppo...';
$messages['folderdeleting'] = 'Eliminazione cartella...';
$messages['foldermoving'] = 'Spostamento cartella...';
$messages['foldersubscribing'] = 'Sottoscrizione cartella...';
$messages['folderunsubscribing'] = 'Cancellazione sottoscrizione cartella...';
$messages['formincomplete'] = 'Per favore, compila tutti i campi';
$messages['noemailwarning'] = 'Per favore, immetti un indirizzo e-mail valido';
$messages['nonamewarning']  = 'Per favore, immetti un nome';
$messages['nopagesizewarning'] = 'Per favore, immetti il numero di righe per pagina';
$messages['nosenderwarning'] = 'Per favore, inserisci l\'indirizzo email del mittente.';
$messages['recipientsadded'] = 'Destinatari/o aggiunti/o correttamente';
$messages['norecipientwarning'] = 'Per favore, immetti almeno un destinatario';
$messages['disclosedrecipwarning'] = 'Tutti i destinatari vedranno i rispettivi indirizzi di posta elettronica. Per evitare questo e proteggerne la riservatezza puoi usare il campo Ccn.';
$messages['disclosedreciptitle'] = 'Troppi destinatari pubblici';
$messages['nosubjectwarning']  = 'L\'oggetto è vuoto. Vuoi inserirlo adesso?';
$messages['nosubjecttitle']  = 'Nessun oggetto';
$messages['nobodywarning'] = 'Inviare il messaggio senza testo?';
$messages['notsentwarning'] = 'Il messaggio non è stato inviato e ha delle modifiche non salvate. Vuoi annullare le modifiche?';
$messages['restoresavedcomposedata'] = 'E\' stato rilevato un precedente messaggio non inviato.\n\nOggetto: $subject\nSalvato: $date\n\nVuoi ripristinare il messaggio?';
$messages['nosearchname'] = 'Per favore, immetti un nome o un indirizzo e-mail';
$messages['notuploadedwarning'] = 'Non tutti gli allegati sono stati ancora caricati. Prego attendere, oppure cancellare il caricamento.';
$messages['searchsuccessful'] = '$nr messaggi trovati';
$messages['contactsearchsuccessful'] = '$nr contatti trovati';
$messages['searchnomatch'] = 'La ricerca non ha dato nessun risultato';
$messages['searching'] = 'Ricerca...';
$messages['checking'] = 'Controllo...';
$messages['stillsearching'] = 'Ricercando...';
$messages['nospellerrors'] = 'Nessun errore ortografico trovato';
$messages['folderdeleted'] = 'Cartella eliminata';
$messages['foldersubscribed'] = 'Cartella sottoscritta correttamente';
$messages['folderunsubscribed'] = 'Sottoscrizione cartella cancellata correttamente';
$messages['folderpurged'] = 'Cartella svuotata con successo.';
$messages['folderexpunged'] = 'Cartella compattata con successo.';
$messages['deletedsuccessfully'] = 'Eliminato con successo';
$messages['converting'] = 'Rimozione della formattazione dal messaggio...';
$messages['messageopenerror'] = 'Impossibile caricare il messaggio dal server';
$messages['filelinkerror'] = 'L\'inserimento dell\'allegato non è riuscito.';
$messages['fileuploaderror'] = 'Errore durante il caricamento del file';
$messages['csvfilemismatch'] = 'L\'importazione di più file CSV con campi diversi non è supportata.';
$messages['filesizeerror'] = 'Il file da caricare supera il limite massimo di $size';
$messages['filecounterror'] = 'È possibile caricare al massimo $count file alla volta.';
$messages['msgsizeerror'] = 'Errore nell\'allegare un file. Dimensione massima di un messaggio ($size) superata. ';
$messages['msgsizeerrorfwd'] = 'La dimensione massima del messaggio ($size) è stata superata. $num messaggi non sono stati allegati.';
$messages['copysuccess'] = 'Copiati correttamente $nr contatti.';
$messages['movesuccess'] = '$nr contatti spostati correttamente.';
$messages['copyerror'] = 'Impossibile copiare i contatti.';
$messages['moveerror'] = 'Impossibile spostare i contatti.';
$messages['sourceisreadonly'] = 'La rubrica è in sola lettura';
$messages['errorsavingcontact'] = 'Impossibile salvare il contatto';
$messages['movingmessage'] = 'Spostamento del messaggio...';
$messages['copyingmessage'] = 'Copia messaggio(i)...';
$messages['copyingcontact'] = 'Copia contatto(i)...';
$messages['movingcontact'] = 'Spostamento contatto(i)...';
$messages['deletingmessage'] = 'Eliminazione messaggio(i)...';
$messages['markingmessage'] = 'Marca messaggio...';
$messages['addingmember'] = 'Aggiunta contatto al gruppo...';
$messages['removingmember'] = 'Rimozione contatto dal gruppo...';
$messages['receiptsent'] = 'Ricevuta di ritorno inviata con successo';
$messages['errorsendingreceipt'] = 'Impossibile spedire la ricevuta di ritorno';
$messages['deleteidentityconfirm'] = 'Sei sicuro di voler eliminare questo profilo?';
$messages['nodeletelastidentity'] = 'Impossibile eliminare l\'unica identità disponibile';
$messages['forbiddencharacter'] = 'Il nome della cartella contiene un carattere vietato';
$messages['selectimportfile'] = 'Per favore, seleziona il file da caricare';
$messages['addresswriterror'] = 'La rubrica selezionata non è scrivibile';
$messages['contactaddedtogroup'] = 'Contatto aggiunto con successo al gruppo';
$messages['contactremovedfromgroup'] = 'Contatto rimosso con successo dal gruppo';
$messages['nogroupassignmentschanged'] = 'Nessun assegnamento del gruppo è stato cambiato.';
$messages['importwait'] = 'Importazione in corso, attendere...';
$messages['importformaterror'] = 'Importazione non riuscita! Il file caricato non è un file valido per l\'importazione.';
$messages['importconfirm'] = '<b>$inserted contatti importati con successo</b>';
$messages['importconfirmskipped'] = '<b>$skipped ignorati perché esistono già</b>';
$messages['importmessagesuccess'] = 'Importati correttamente $nr messaggi';
$messages['importmessageerror'] = 'Importazione non riuscita! Il file caricato non è un messaggio o una casella postale valida.';
$messages['opnotpermitted'] = 'Operazione non consentita!';
$messages['nofromaddress'] = 'Indirizzo email mancante nell\'identità selezionata.';
$messages['editorwarning'] = 'Cambiare editor potrebbe causare la perdita della formattazione. Si desidera continuare lo stesso?';
$messages['httpreceivedencrypterror'] = 'Errore fatale di configurazione. Contatta l\'amministratore immediatamente. <b>Il tuo messaggio non può essere inviato</b>.';
$messages['smtpconnerror'] = 'Errore SMTP ($code): connessione al server non riuscita.';
$messages['smtpautherror'] = 'Errore SMTP ($code): autenticazione non riuscita.';
$messages['smtpfromerror'] = 'Errore SMTP ($code): impostazione del mittente "$from" non riuscita ($msg)';
$messages['smtptoerror'] = 'Errore SMTP ($code): inserimento del destinatario "$to" non riuscito ($msg)';
$messages['smtprecipientserror'] = 'Errore SMTP: impossibile processare la lista dei destinatari';
$messages['smtputf8error'] = 'Errore SMTP: Il server non supporta i caratteri Unicode nell\'indirizzo email';
$messages['smtpsizeerror'] = 'Errore SMTP: La dimensione del messaggio supera il limite del server ($limit)';
$messages['smtperror'] = 'Errore SMTP: $msg';
$messages['emailformaterror'] = 'Indirizzo email non valido: $email';
$messages['toomanyrecipients'] = 'Numero eccessivo di destinatari, ridurlo a $max';
$messages['maxgroupmembersreached'] = 'Il numero dei membri del gruppo eccede il massimo di $max';
$messages['internalerror'] = 'Si è verificato un errore interno. Riprovare più tardi.';
$messages['contactdelerror'] = 'Impossibile eliminare il/i contatto/i';
$messages['contactdeleted'] = 'Contatto/i correttamente eliminato/i';
$messages['contactrestoreerror'] = 'Impossibile ripristinare il/i contatto/i cancellato/i';
$messages['contactrestored'] = 'Contatto/i ripristinato/i';
$messages['groupdeleted'] = 'Gruppo correttamente eliminato';
$messages['grouprenamed'] = 'Gruppo correttamente rinominato';
$messages['groupcreated'] = 'Gruppo creato correttamente';
$messages['savedsearchdeleted'] = 'Le ricerca salvata è stata eliminata con successo.';
$messages['savedsearchdeleteerror'] = 'Impossibile eliminare la ricerca salvata.';
$messages['savedsearchcreated'] = 'Ricerca salvata creata con successo.';
$messages['savedsearchcreateerror'] = 'Impossibile creare la ricerca salvata.';
$messages['messagedeleted'] = 'Messaggi/o eliminato/i correttamente';
$messages['messagemoved'] = 'Messaggio/i spostato/i correttamente';
$messages['messagemovedtotrash'] = 'Messaggio/i spostato/i correttamente nel cestino.';
$messages['messagecopied'] = 'Messaggi/o copiato/i correttamente';
$messages['messagemarked'] = 'Messaggi/o marcato/i correttamente';
$messages['autocompletechars'] = 'Inserisci almeno $min caratteri per l\'autocompletamento';
$messages['autocompletemore'] = 'Più risultati ottenuti. Inserisci per favore più caratteri.';
$messages['namecannotbeempty'] = 'Il nome non può essere vuoto';
$messages['nametoolong'] = 'Nome troppo lungo';
$messages['namedotforbidden'] = 'Il nome della cartella non può iniziare con un punto';
$messages['folderupdated'] = 'Cartella aggiornata correttamente';
$messages['foldercreated'] = 'Cartella creata correttamente';
$messages['invalidimageformat'] = 'Formato immagine non valido';
$messages['mispellingsfound'] = 'Sono stati riscontrati errori ortografici nel messaggio';
$messages['parentnotwritable'] = 'Impossibile creare o muovere la cartella: accesso negato';
$messages['messagetoobig'] = 'La parte del messaggio è troppo grande per essere processata.';
$messages['attachmentvalidationerror'] = 'Questo allegato è sospetto perché il tipo non corrisponde a quanto dichiarato nel messaggio. Se non ti fidi del mittente, non dovresti aprirlo nel browser perché potrebbe contenere contenuti malevoli.<br/><br/><em>Atteso: $expected; trovato: $detected</em>';
$messages['noscriptwarning'] = 'Attenzione: questo servizio di webmail richiede Javascript! Per utilizzarlo abilita Javascript nelle impostazioni del tuo browser.';
$messages['messageissent'] = 'Questo messaggio è stato già inviato, ma non ancora salvato. Vuoi salvarlo adesso?';
$messages['errnotfound'] = 'File non trovato';
$messages['errnotfoundexplain'] = 'La risorsa richiesta non è stata trovata!';
$messages['errfailedrequest'] = 'Richiesta non riuscita';
$messages['errauthorizationfailed'] = 'Autorizzazione non riuscita';
$messages['errunauthorizedexplain'] = 'Non è stato possibile verificare la tua autorizzazione all\'accesso per questo servizio!';
$messages['errrequestcheckfailed'] = 'Il controllo della richiesta non è riuscito';
$messages['errcsrfprotectionexplain'] = "Per la tua sicurezza, l'accesso a questa risorsa è protetto contro CSRF.\nSe visualizzi questo messaggio, è probabile che non ti sia scollegato prima di lasciare l'applicazione web.\n\nE' richiesta un'azione di una persona per continuare.";
$messages['errcontactserveradmin'] = 'Si prega di contattare l\'amministratore del server.';
$messages['clicktoresumesession'] = 'Clicca qui per riprendere la tua sessione precedente.';
$messages['errcomposesession'] = 'Errore di sessione di composizione';
$messages['errcomposesessionexplain'] = 'Non è stato possibile trovare la sessione di composizione richiesta.';
$messages['clicktocompose'] = 'Cliccare qui per comporre un nuovo messaggio';
$messages['nosupporterror'] = 'La funzione non è supportata dal browser.';
$messages['siginserted'] = 'Firma inserita con successo.';
$messages['responseinserted'] = 'Risposta inserita con successo.';
$messages['noresponsesavailable'] = 'Nessuna risposta disponibile';
$messages['listempty'] = 'Questa lista è vuota';
$messages['listusebutton'] = 'Usa il tasto Crea per aggiungere una nuova voce';
$messages['keypaircreatesuccess'] = 'Una nuova coppia di chiavi è stata creata con successo per $identity.';
$messages['emptyattachment'] = 'Il file allegato risulta vuoto.<br> Verifica con la persona che lo ha inviato.';
$messages['oauthloginfailed'] = 'Accesso OAuth non riuscito. Riprova.';
