<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail Managesieve plugin         |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/plugin-managesieve/
*/


$labels['filters'] = 'Strecureirs';
$labels['messagedelete'] = 'Zeletarh el mensatx';
$labels['del'] = 'Zeletarh';
$labels['days'] = 'ziuas';
$labels['seconds'] = 'secunds';
$labels['active'] = 'actíu';
$labels['flagread'] = 'Lirarh';
$labels['notifymethodmailto'] = 'Telepost';
$labels['...'] = '...';
$labels['datetest'] = 'Däts';
$labels['year'] = 'ar';
$labels['month'] = 'mes';
$labels['day'] = 'ziua';
$labels['date'] = 'däts (aaaa-mm-zz)';
$labels['hour'] = 'þora';
$labels['minute'] = 'míut';
$labels['second'] = 'secund';
$labels['iso8601'] = 'däts (ISO8601)';
$labels['std11'] = 'däts (RFC2822)';
$labels['text'] = 'text';
$labels['domain'] = 'bain';
$labels['user'] = 'uçeir';
$labels['vacation.subject'] = 'Subxhect';
