<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail client                     |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/labels/
*/


$labels['welcome'] = 'ሰናይ ምምጻእ ናብ $product';
$labels['username'] = 'ሽምዓሙና';
$labels['password'] = 'መሐለፊ ቃል';
$labels['server'] = 'ውሃቢ ግልጋሎት';
$labels['login'] = 'ክኣቱ';
$labels['logout'] = 'ክውጽእ';
$labels['mail'] = 'ደብዳበ';
$labels['settings'] = 'ከመንታይ';
$labels['addressbook'] = 'መጽሓፍ አድራሻ';
$labels['inbox'] = 'ሳጹን አታዊ';
$labels['drafts'] = 'ወጡን ጽሑፍ';
$labels['sent'] = 'ዝተለኣኸ';
$labels['trash'] = 'እንዳጉሓፍ';
$labels['junk'] = 'እንዳቅንጠመንጢ';
$labels['subject'] = 'ዋኒን';
$labels['from'] = 'ካብ';
$labels['sender'] = 'ልኣኺ(ት)';
$labels['to'] = 'ናብ';
$labels['cc'] = 'ካኮ';
$labels['bcc'] = 'ሕካኮ';
$labels['replyto'] = 'ተመላሲ ናብ';
$labels['followupto'] = 'ናብ...ዝስዓበ';
$labels['date'] = 'ዕለት';
$labels['size'] = 'መጠን';
$labels['priority'] = 'ህጹጽነት';
$labels['organization'] = 'ውድብ';
$labels['readstatus'] = 'ምንባቡ';
$labels['listoptions'] = 'መማርጽታት ዝርዝር';
$labels['mailboxlist'] = 'ማህዸራት';
$labels['messagesfromto'] = '$countይ መልእኽቲ ካብ $from ናብ $to  ';
$labels['sun'] = 'ሰንበ';
$labels['mon'] = 'ሰኑይ';
$labels['tue'] = 'ሰሉስ';
$labels['wed'] = 'ረቡዕ';
$labels['thu'] = 'ሓሙስ';
$labels['fri'] = 'ዓርቢ';
$labels['sat'] = 'ቀዳም';
$labels['sunday'] = 'ሰንበት';
$labels['monday'] = 'ሰኑይ';
$labels['tuesday'] = 'ሰሉስ';
$labels['wednesday'] = 'ረቡዕ';
$labels['thursday'] = 'ሓሙስ';
$labels['friday'] = 'ዓርቢ ';
$labels['saturday'] = 'ቀዳም';
$labels['isread'] = 'ከንብብ';
$labels['insert'] = 'ይሸጎጥ';
$labels['other'] = 'ካሊእ';
$labels['typeother'] = 'ካሊእ';
$labels['delete'] = 'ይጥፋእ';
$labels['about'] = 'ብዛዕባ';
$labels['folders'] = 'ማህዸራት';
$labels['create'] = 'ይፈጠር';
$labels['license'] = 'ፍቓድ';
