<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail Managesieve plugin         |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/plugin-managesieve/
*/


$labels['filters'] = 'Süzgeçler';
$labels['managefilters'] = 'Gelen e-posta süzgeçleri yönetimi';
$labels['filtername'] = 'Süzgeç adı';
$labels['newfilter'] = 'Yeni süzgeç';
$labels['filteradd'] = 'Süzgeç ekle';
$labels['filterdel'] = 'Süzgeci Sil';
$labels['rules'] = 'Kurallar';
$labels['actions'] = 'İşlemler';
$labels['scope'] = 'Kapsam';
$labels['moveup'] = 'Yukarı taşı';
$labels['movedown'] = 'Aşağı taşı';
$labels['filterallof'] = 'Aşağıdaki kuralların hepsine uyan';
$labels['filteranyof'] = 'Aşağıdaki kuralların herhangi birine uyan';
$labels['filterany'] = 'Tüm iletiler';
$labels['filtercontains'] = 'şunu içeren';
$labels['filternotcontains'] = 'şunu içermeyen';
$labels['filteris'] = 'şuna eşit olan';
$labels['filterisnot'] = 'şuna eşit olmayan';
$labels['filterexists'] = 'şu var olan';
$labels['filternotexists'] = 'şu var olmayan';
$labels['filtermatches'] = 'şu ifadeye uyan';
$labels['filternotmatches'] = 'şu ifadeye uymayan';
$labels['filterregex'] = 'şu kurallı ifadeye uyan';
$labels['filternotregex'] = 'şu kurallı ifadeye uymayan';
$labels['filterunder'] = 'şunun altında';
$labels['filterover'] = 'şunun üzerinde';
$labels['mime'] = 'MIME:';
$labels['mimepart'] = 'MIME parçası:';
$labels['mime-message'] = 'ileti';
$labels['mime-anychild'] = 'tümü';
$labels['mime-type'] = 'tür';
$labels['mime-subtype'] = 'alt tür';
$labels['mime-contenttype'] = 'içerik türü';
$labels['mime-param'] = 'parametre';
$labels['addrule'] = 'Kural ekle';
$labels['delrule'] = 'Kuralı sil';
$labels['messagemoveto'] = 'İletiyi şuraya taşı';
$labels['messageredirect'] = 'İletiyi şuraya yönlendir';
$labels['messagecopyto'] = 'İletiyi şuraya kopyala';
$labels['messagesendcopy'] = 'İletinin kopyasını şuraya gönder';
$labels['messagereply'] = 'İletiyle birlikte yanıtla';
$labels['messagedelete'] = 'İletiyi sil';
$labels['messagediscard'] = 'İletiyi yok say';
$labels['messagekeep'] = 'İleti Gelen kutusunda tutulsun';
$labels['messagesrules'] = 'Gelen iletiler için:';
$labels['messagesactions'] = '...aşağıdaki işlemleri yürüt:';
$labels['add'] = 'Ekle';
$labels['del'] = 'Sil';
$labels['sender'] = 'Gönderici';
$labels['recipient'] = 'Alıcı';
$labels['vacationaddr'] = 'E-posta adreslerim:';
$labels['vacationdays'] = 'İleti gönderme sıklığı (gün):';
$labels['vacationinterval'] = 'İleti gönderme sıklığı:';
$labels['vacationreason'] = 'İleti gövdesi (tatil nedeni):';
$labels['vacationfrom'] = 'Gönderici adresine yanıtla:';
$labels['vacationsubject'] = 'İleti konusu:';
$labels['days'] = 'gün';
$labels['seconds'] = 'saniye';
$labels['rulestop'] = 'Kuralları değerlendirmeyi bitir';
$labels['enable'] = 'Etkinleştir/Devre dışı bırak';
$labels['filterset'] = 'Süzgeç kümesi';
$labels['filtersets'] = 'Süzgeç kümeleri';
$labels['filtersetadd'] = 'Süzgeç kümesi ekle';
$labels['filtersetdel'] = 'Süzgeç kümesini sil';
$labels['filtersetact'] = 'Geçerli süzgeç kümesini etkinleştir';
$labels['filtersetdeact'] = 'Geçerli süzgeç kümesini devre dışı bırak';
$labels['filterseteditraw'] = 'Süzgeç kümesini düzenle';
$labels['filtersetswitch'] = 'Süzgeç kümesini aç/kapat';
$labels['filterdef'] = 'Süzgeç tanımı';
$labels['filtersetname'] = 'Süzgeç kümesi adı';
$labels['newfilterset'] = 'Yeni süzgeç kümesi ';
$labels['active'] = 'etkin';
$labels['none'] = 'hiçbiri';
$labels['fromset'] = 'şu kümeden';
$labels['fromfile'] = 'şu dosyadan';
$labels['filterdisabled'] = 'Süzgeç devre dışı';
$labels['filterenabled'] = 'Süzgeç etkin';
$labels['countisgreaterthan'] = 'sayısı şundan büyük olan';
$labels['countisgreaterthanequal'] = 'sayısı şundan büyük ya da eşit olan';
$labels['countislessthan'] = 'sayısı şundan küçük olan';
$labels['countislessthanequal'] = 'sayısı şundan küçük ya da eşit olan';
$labels['countequals'] = 'sayısı şuna eşit olan';
$labels['countnotequals'] = 'sayısı şuna eşit olmayan';
$labels['valueisgreaterthan'] = 'değeri şundan büyük olan';
$labels['valueisgreaterthanequal'] = 'değeri şundan büyük ya da eşit olan';
$labels['valueislessthan'] = 'değeri şundan küçük olan';
$labels['valueislessthanequal'] = 'değer şundan küçük ya da  eşit olan';
$labels['valueequals'] = 'değeri şuna eşit olan';
$labels['valuenotequals'] = 'değeri şuna eşit olmayan';
$labels['setflags'] = 'İletiyi işaretlerini ayarla';
$labels['addflags'] = 'İletiye işaret ekle';
$labels['removeflags'] = 'İleti işaretlerini kaldır';
$labels['flagread'] = 'Okunmuş';
$labels['flagdeleted'] = 'Silinmiş';
$labels['flaganswered'] = 'Yanıtlanmış';
$labels['flagflagged'] = 'İşaretlenmiş';
$labels['flagdraft'] = 'Taslak';
$labels['addheader'] = 'İletiye üst bilgi ekle';
$labels['deleteheader'] = 'İletideki üst bilgiyi kaldır';
$labels['headername'] = 'Üst bilgi adı';
$labels['headervalue'] = 'Üst bilgi değeri';
$labels['headerpos'] = 'Üst bilgi konumu';
$labels['headeratstart'] = 'üstte';
$labels['headeratend'] = 'altta';
$labels['headeroccurrence'] = 'Üst bilgi görüntülenmesi/konumu';
$labels['headerfromstart'] = 'üstten';
$labels['headerfromend'] = 'alttan';
$labels['headerpatterns'] = 'Üst bilgi değeri düzenleri';
$labels['headermatchtype'] = 'eşleşme türü:';
$labels['setvariable'] = 'Değişken tanımla';
$labels['setvarname'] = 'Değişken adı:';
$labels['setvarvalue'] = 'Değişken değeri:';
$labels['setvarmodifiers'] = 'Alanlar:';
$labels['varlower'] = 'küçük harf';
$labels['varupper'] = 'büyük harf';
$labels['varlowerfirst'] = 'İlk karakter küçük harf';
$labels['varupperfirst'] = 'İlk karakter büyük harf';
$labels['varquotewildcard'] = 'özel karakterleri tırnak içine al';
$labels['varlength'] = 'uzunluk';
$labels['varencodeurl'] = 'yüzde kodlama (adresler için)';
$labels['notify'] = 'Bildirim gönder';
$labels['notifytarget'] = 'Bildirim hedefi:';
$labels['notifymessage'] = 'Bildirim iletisi (isteğe bağlı):';
$labels['notifyoptions'] = 'Bildirim ayarları (isteğe bağlı):';
$labels['notifyfrom'] = 'Bildirim göndericisi (isteğe bağlı):';
$labels['notifyimportance'] = 'Önem derecesi:';
$labels['notifyimportancelow'] = 'düşük';
$labels['notifyimportancenormal'] = 'normal';
$labels['notifyimportancehigh'] = 'yüksek';
$labels['notifymethodmailto'] = 'E-posta';
$labels['notifymethodtel'] = 'Telefon';
$labels['notifymethodsms'] = 'SMS';
$labels['filtercreate'] = 'Süzgeç ekle';
$labels['usedata'] = 'Süzgeçte şu veriler kullanılsın:';
$labels['nextstep'] = 'Sonraki adım';
$labels['...'] = '...';
$labels['string'] = 'Dizge';
$labels['currdate'] = 'Geçerli tarih';
$labels['datetest'] = 'Tarih';
$labels['dateheader'] = 'üst bilgi:';
$labels['year'] = 'yıl';
$labels['month'] = 'ay';
$labels['day'] = 'gün';
$labels['date'] = 'tarih (yyyy-aa-gg)';
$labels['julian'] = 'tarih (julian)';
$labels['hour'] = 'saat';
$labels['minute'] = 'dakika';
$labels['second'] = 'saniye';
$labels['time'] = 'saat (ss:dd:ss)';
$labels['iso8601'] = 'tarih (ISO8601)';
$labels['std11'] = 'tarih (RFC2822)';
$labels['zone'] = 'saat-dilimi';
$labels['weekday'] = 'haftanın günleri (0-6)';
$labels['advancedopts'] = 'Gelişmiş ayarlar';
$labels['body'] = 'Metin';
$labels['address'] = 'adres';
$labels['envelope'] = 'zarf';
$labels['modifier'] = 'alan:';
$labels['text'] = 'metin';
$labels['undecoded'] = 'kodu çözülmemiş (ham)';
$labels['contenttype'] = 'içerik türü';
$labels['modtype'] = 'tür:';
$labels['allparts'] = 'tümü';
$labels['domain'] = 'etki alanı';
$labels['localpart'] = 'yerel parça';
$labels['user'] = 'kullanıcı';
$labels['detail'] = 'ayrıntı';
$labels['comparator'] = 'karşılaştırıcı:';
$labels['default'] = 'varsayılan';
$labels['octet'] = 'sıkı (sekizli)';
$labels['asciicasemap'] = 'büyük küçük harfe duyarsız (ascii-casemap)';
$labels['asciinumeric'] = 'sayı (ascii-numeric)';
$labels['index'] = 'Dizin:';
$labels['indexlast'] = 'geriye yönelik';
$labels['spamtest'] = 'İstenmeyen e-posta düzeyi';
$labels['spamtestisgreaterthan'] = 'şundan büyük olan';
$labels['spamtestisgreaterthanequal'] = 'şundan büyük ve eşit olan';
$labels['spamtestislessthan'] = 'şundan küçük olan';
$labels['spamtestislessthanequal'] = 'şundan küçük ve eşit olan';
$labels['spamtestequals'] = 'şuna eşit olan';
$labels['spamtestnotequals'] = 'şuna eşit olmayan';
$labels['spamtestisunknown'] = 'bilinmeyen';
$labels['vacation'] = 'Ofis dışında';
$labels['vacation.reply'] = 'İletiyi yanıtla';
$labels['vacation.advanced'] = 'Gelişmiş ayarlar';
$labels['vacation.from'] = 'Gönderici adresine yanıtla';
$labels['vacation.subject'] = 'Konu';
$labels['vacation.body'] = 'Metin';
$labels['vacation.start'] = 'Başlangıç saati';
$labels['vacation.end'] = 'Bitiş saati';
$labels['vacation.status'] = 'Durum';
$labels['vacation.on'] = 'Etkin';
$labels['vacation.off'] = 'Devre dışı';
$labels['vacation.addresses'] = 'E-posta adreslerim';
$labels['vacation.interval'] = 'Yanıt aralığı';
$labels['vacation.after'] = 'Ofis dışında kuralını şunun arkasına koy';
$labels['vacation.saving'] = 'Veriler kaydediliyor...';
$labels['vacation.action'] = 'Gelen ileti işlemi';
$labels['vacation.keep'] = 'Koru';
$labels['vacation.discard'] = 'Yok say';
$labels['vacation.redirect'] = 'Şuraya yönlendir';
$labels['vacation.copy'] = 'Şuraya kopya gönder';
$labels['forward'] = 'İletiliyor';
$labels['forward.redirect'] = 'Şuraya yönlendir';
$labels['forward.copy'] = 'Şuraya kopya gönder';
$labels['forward.on'] = 'Etkin';
$labels['forward.off'] = 'Devre dışı';
$labels['forward.status'] = 'Durum:';
$labels['forward.action'] = 'Gelen e-postalar için şu işlem yürütülsün:';
$labels['forward.saving'] = 'Veriler kaydediliyor...';
$labels['filladdresses'] = 'Benim adreslerimle doldur';
$labels['arialabelfiltersetactions'] = 'Süzgeç kümesi işlemleri';
$labels['arialabelfilteractions'] = 'Süzgeç işlemleri';
$labels['arialabelfilterform'] = 'Süzgeç özellikleri';
$labels['ariasummaryfilterslist'] = 'Süzgeç listesi';
$labels['ariasummaryfiltersetslist'] = 'Süzgeç kümesi listesi';
$labels['filterstitle'] = 'Gelen e-posta süzgeçlerini düzenle';
$labels['vacationtitle'] = 'Ofis dışında kuralını düzenle';
$labels['forwardtitle'] = 'Posta iletme kuralını düzenle';
$labels['message'] = 'İleti';
$labels['duplicate'] = 'yinelenen';
$labels['notduplicate'] = 'yinelenmeyen';
$labels['duplicate.handle'] = 'işle:';
$labels['duplicate.header'] = 'üst bilgi:';
$labels['duplicate.uniqueid'] = 'belirteç:';
$labels['duplicate.seconds'] = 'Zaman aşımı (saniye):';
$labels['duplicate.last'] = 'son yapılanlara göre';
$messages['filterunknownerror'] = 'Bilinmeyen sunucu sorunu.';
$messages['filterconnerror'] = 'Sunucu ile bağlantı kurulamadı.';
$messages['filterdeleteerror'] = 'Süzgeç silinemedi. Sunucuda bir sorun çıktı.';
$messages['filterdeleted'] = 'Süzgeç silindi.';
$messages['filtersaved'] = 'Süzgeç kaydedildi.';
$messages['filtersaveerror'] = 'Süzgeç kaydedilemedi. Sunucuda bir sorun çıktı.';
$messages['filterformerror'] = 'Süzgeç formunda sorunlar var.';
$messages['filterdeleteconfirm'] = 'Seçilmiş süzgeçleri silmek istediğinize emin misiniz?';
$messages['ruledeleteconfirm'] = 'Seçilmiş kuralları silmek istediğinize emin misiniz?';
$messages['actiondeleteconfirm'] = 'Seçilmiş işlemleri silmek istediğinize emin misiniz?';
$messages['forbiddenchars'] = 'Alanda izin verilmeyen karakterler var.';
$messages['cannotbeempty'] = 'Alan boş olamaz';
$messages['ruleexist'] = 'Aynı adlı bir süzgeç zaten var.';
$messages['setactivateerror'] = 'Seçilmiş süzgeç kümesi etkinleştirilemedi. Sunucuda bir sorun çıktı.';
$messages['setdeactivateerror'] = 'Seçilmiş süzgeç kümesi devre dışı bırakılamadı. Sunucuda bir sorun çıktı.';
$messages['setdeleteerror'] = 'Seçilmiş süzgeç kümesi silinemedi. Sunucuda bir sorun çıktı.';
$messages['setactivated'] = 'Süzgeç kümesi etkinleştirildi.';
$messages['setdeactivated'] = 'Süzgeç kümesi devre dışı bırakıldı.';
$messages['setdeleted'] = 'Süzgeç kümesi silindi.';
$messages['setupdated'] = 'Süzgeç kümesi güncellendi.';
$messages['setdeleteconfirm'] = 'Seçilmiş süzgeç kümesini silmek istediğinize emin misiniz?';
$messages['setcreateerror'] = 'Süzgeç kümesi eklenemedi. Sunucuda bir sorun çıktı.';
$messages['setcreated'] = 'Süzgeç kümesi eklendi.';
$messages['activateerror'] = 'Seçilmiş süzgeç(ler) etkinleştirilemedi. Sunucuda bir sorun çıktı.';
$messages['deactivateerror'] = 'Seçilmiş süzgeç(ler) devre dışı bırakılamadı. Sunucuda bir sorun çıktı.';
$messages['deactivated'] = 'Süzgeç(ler) devre dışı bırakıldı.';
$messages['activated'] = 'Süzgeç(ler) etkinleştirildi.';
$messages['moved'] = 'Süzgeç taşındı.';
$messages['moveerror'] = 'Seçilmiş süzgeç taşınamadı. Sunucuda bir sorun çıktı.';
$messages['nametoolong'] = 'Ad çok uzun.';
$messages['namereserved'] = 'Bu ad ayırtılmış.';
$messages['setexist'] = 'Küme zaten var.';
$messages['nodata'] = 'En az bir konum seçilmelidir!';
$messages['invaliddateformat'] = 'Tarih ya da tarih biçimi geçersiz';
$messages['saveerror'] = 'Veri kaydedilemedi. Sunucuda bir sorun çıktı.';
$messages['vacationsaved'] = 'Ofis dışında verileri kaydedildi.';
$messages['forwardsaved'] = 'İletim verileri kaydedildi.';
$messages['emptyvacationbody'] = 'Tatil iletisi metnini yazmalısınız!';
$messages['duplicate.conflict.err'] = 'Üst bilgi ve tekil belirteç aynı anda kullanılamaz.';
$messages['disabledaction'] = 'İşleme izin verilmiyor!';
$messages['lastindexempty'] = 'Sondan sayılırken dizin gereklidir';
$messages['noflagset'] = 'En az bir işaret seçilmelidir.';
