<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail Managesieve plugin         |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/plugin-managesieve/
*/


$labels['filters'] = 'Süzgəclər';
$labels['managefilters'] = 'Gələn məktub üçün süzgəclərin idarəsi';
$labels['filtername'] = 'Süzgəcin adı';
$labels['newfilter'] = 'Yeni süzgəc';
$labels['filteradd'] = 'Süzgəc əlavə et';
$labels['filterdel'] = 'Süzgəci sil';
$labels['moveup'] = 'Yuxarı apar';
$labels['movedown'] = 'Aşağı apar';
$labels['filterallof'] = 'göstərilən bütün qaydalara uyur';
$labels['filteranyof'] = 'verilmiş istənilən qaydaya uyur';
$labels['filterany'] = 'bütün məktublar';
$labels['filtercontains'] = 'daxildir';
$labels['filternotcontains'] = 'daxil deyil';
$labels['filteris'] = 'uyğundur';
$labels['filterisnot'] = 'uyğun deyil';
$labels['filterexists'] = 'mövcuddur';
$labels['filternotexists'] = 'mövcud deyil';
$labels['filtermatches'] = 'ifadə ilə üst-üstə düşür';
$labels['filternotmatches'] = 'ifadə ilə üst-üstə düşmür';
$labels['filterregex'] = 'daimi ifadənin nəticəsi ilə üst-üstə düşür';
$labels['filternotregex'] = 'daimi ifadə ilə üst-üstə düşmür';
$labels['filterunder'] = 'altında';
$labels['filterover'] = 'yuxarıda';
$labels['addrule'] = 'Qayda əlavə et';
$labels['delrule'] = 'Qaydanı sil';
$labels['messagemoveto'] = 'Məktubu köçür';
$labels['messageredirect'] = 'Məktubu yolla';
$labels['messagecopyto'] = 'Məktubu kopyala';
$labels['messagesendcopy'] = 'Məktubun kopyasını göndər';
$labels['messagereply'] = 'Məktubla cavab ver';
$labels['messagedelete'] = 'Sil';
$labels['messagediscard'] = 'Məktubla rədd et';
$labels['messagekeep'] = 'Məktubu gələnlərdə saxla';
$labels['messagesrules'] = 'Daxil olan məktub üçün:';
$labels['messagesactions'] = '...növbəti hərəkəti yerinə yetir:';
$labels['add'] = 'Əlavə et';
$labels['del'] = 'Sil';
$labels['sender'] = 'Göndərən';
$labels['recipient'] = 'Qəbul edən';
$labels['vacationdays'] = 'Məktub neçə müddətdən bir göndərilsin (gündə):';
$labels['vacationinterval'] = 'Məktublar nə qədər sıx göndərilsin:';
$labels['vacationreason'] = 'Məktubun mətni (səbəb yoxdur):';
$labels['vacationsubject'] = 'Məktubun mövzusu:';
$labels['days'] = 'günlər';
$labels['seconds'] = 'saniyələr';
$labels['rulestop'] = 'Yerinə yetirməyi dayandır';
$labels['enable'] = 'Yandır/Söndür';
$labels['filtersets'] = 'Süzgəc dəstləri';
$labels['filterdef'] = 'Süzgəcin təsviri';
$labels['active'] = 'aktiv';
$labels['none'] = 'heç biri';
$labels['fromset'] = 'dəstdən';
$labels['fromfile'] = 'fayldan';
$labels['filterdisabled'] = 'Süzgəci söndür';
$labels['countisgreaterthan'] = 'sayı buradan daha çoxdur';
$labels['countisgreaterthanequal'] = 'say çox və ya bərabərdir';
$labels['countislessthan'] = 'say buradan azdır';
$labels['countislessthanequal'] = 'say azdır və ya bərabərdir';
$labels['countequals'] = 'say bərabərdir';
$labels['countnotequals'] = 'say bərabər deyil';
$labels['valueisgreaterthan'] = 'dəyər buradan daha böyükdür';
$labels['valueisgreaterthanequal'] = 'dəyər çoxdur və ya bərabərdir';
$labels['valueislessthan'] = 'dəyər buradan azdır';
$labels['valueislessthanequal'] = 'dəyər azdır və ya bərabərdir';
$labels['valueequals'] = 'dəyər bərabərdir';
$labels['valuenotequals'] = 'dəyər bərabər deyil';
$labels['setflags'] = 'Məktublara flaq quraşdır';
$labels['addflags'] = 'Məktuba flaq əlavə et';
$labels['removeflags'] = 'Məktubdan flaqları sil';
$labels['flagread'] = 'Oxu';
$labels['flagdeleted'] = 'Silindi';
$labels['flaganswered'] = 'Cavab verilmiş';
$labels['flagflagged'] = 'İşarəlilər';
$labels['flagdraft'] = 'Qaralama';
$labels['setvariable'] = 'Dəyişəni təyin et';
$labels['setvarname'] = 'Dəyişənin adı:';
$labels['setvarvalue'] = 'Dəyişənin dəyəri:';
$labels['setvarmodifiers'] = 'Modifikatorlar';
$labels['varlower'] = 'aşağı registr';
$labels['varupper'] = 'yuxarı registr';
$labels['varlowerfirst'] = 'aşağı registrdə birinci simvol';
$labels['varupperfirst'] = 'yuxarı registrdə birinci simvol';
$labels['varquotewildcard'] = 'dırnaq simvolu';
$labels['varlength'] = 'uzunluq';
$labels['notify'] = 'Bildiriş göndər';
$labels['notifyimportance'] = 'Vaciblik';
$labels['notifyimportancelow'] = 'aşağı';
$labels['notifyimportancenormal'] = 'normal';
$labels['notifyimportancehigh'] = 'yuxarı';
$labels['notifymethodmailto'] = 'E-Poçt';
$labels['notifymethodtel'] = 'Telefon';
$labels['filtercreate'] = 'Süzgəc yarat';
$labels['usedata'] = 'Süzgəcdə bu məlumatları istifadə et:';
$labels['nextstep'] = 'Sonrakı';
$labels['...'] = '...';
$labels['currdate'] = 'İndiki tarix';
$labels['datetest'] = 'Tarix';
$labels['dateheader'] = 'başlıq:';
$labels['year'] = 'il';
$labels['month'] = 'ay';
$labels['day'] = 'gün';
$labels['date'] = 'tarix (iiii-aa-gg)';
$labels['julian'] = 'tarix (yulian)';
$labels['hour'] = 'saat';
$labels['minute'] = 'dəqiqə';
$labels['second'] = 'saniyə';
$labels['time'] = 'saat (sa:dd:sn)';
$labels['iso8601'] = 'tarix (ISO8601)';
$labels['std11'] = 'tarix (RFC2822)';
$labels['zone'] = 'saat-zona';
$labels['weekday'] = 'həftənin günü (0-6)';
$labels['advancedopts'] = 'Əlavə ayarlar';
$labels['body'] = 'Məzmun';
$labels['address'] = 'ünvan';
$labels['envelope'] = 'zərf';
$labels['modifier'] = 'modifikator:';
$labels['text'] = 'mətn';
$labels['undecoded'] = 'emal olunmamış (xammal)';
$labels['contenttype'] = 'məzmun növü';
$labels['modtype'] = 'növ:';
$labels['allparts'] = 'hamısı';
$labels['domain'] = 'domen';
$labels['localpart'] = 'lokal hissə';
$labels['user'] = 'istifadəçi';
$labels['detail'] = 'təfsilat';
$labels['comparator'] = 'komparator:';
$labels['default'] = 'ön qurğulu';
$labels['octet'] = 'ciddi (oktet)';
$labels['asciicasemap'] = 'qeydiyyat üzrə müstəqil (ascii-casemap)';
$labels['asciinumeric'] = 'ədədi (ascii-numeric)';
$labels['index'] = 'indeks:';
$labels['indexlast'] = 'arxaya';
$labels['spamtestequals'] = 'uyğundur';
$labels['spamtestnotequals'] = 'uyğun deyil';
$labels['vacation.subject'] = 'Mövzu';
$labels['vacation.body'] = 'Mətn';
$labels['vacation.keep'] = 'Saxla';
$labels['duplicate.header'] = 'başlıq:';
$messages['filterunknownerror'] = 'Serverin naməlum xətası.';
$messages['filterconnerror'] = 'Serverə qoşulmaq alınmır';
$messages['filterdeleteerror'] = 'Süzgəci silmək mümkün deyil. Server xətası.';
$messages['filterdeleted'] = 'Süzgəc uğurla silindi.';
$messages['filtersaved'] = 'Süzgəc uğurla saxlanıldı.';
$messages['filtersaveerror'] = 'Süzgəci saxlamaq mümkün deyil. Server xətası.';
$messages['filterdeleteconfirm'] = 'Siz həqiqətən süzgəci silmək istəyirsiniz?';
$messages['ruledeleteconfirm'] = 'Bu qaydanı silməkdə əminsiniz?';
$messages['actiondeleteconfirm'] = 'Bu hərəkəti silməkdə əminsiniz?';
$messages['forbiddenchars'] = 'Sahədə qadağan edilən işarələr.';
$messages['cannotbeempty'] = 'Sahə boş ola bilməz.';
$messages['ruleexist'] = 'Bu adla süzgəc artıq mövcuddur.';
$messages['activateerror'] = 'Seçilmiş süzgəc(lər)i yandırmaq mümkün deyil. Server xətası.';
$messages['deactivateerror'] = 'Seçilmiş süzgəc(lər)i söndürmək mümkün deyil. Server xətası.';
$messages['deactivated'] = 'Süzgəc(lər) uğurla yandırıldı.';
$messages['activated'] = 'Süzgəc(lər) uğurla söndürüldü.';
$messages['moved'] = 'Süzgəc uğurla köçürüldü.';
$messages['moveerror'] = 'Süzgəci köçürmək mümkün deyil. Server xətası.';
$messages['nametoolong'] = 'Süzgəc dəstini yaratmaq mümkün deyil. Ad çox uzundur.';
$messages['namereserved'] = 'Rezerv edilmiş ad.';
$messages['setexist'] = 'Dəst artıq mövcuddur.';
$messages['nodata'] = 'Heç olmasa bir mövqe tutmaq lazımdır!';
$messages['invaliddateformat'] = 'Tarix və ya tarix formatının bir hissəsi səhvdir';
