<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail client                     |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/labels/
*/


$labels['welcome'] = 'بەخێربێیت بۆ $product';
$labels['username'] = 'ناوی بەکارهێنەر';
$labels['password'] = 'تێپەڕەوشە';
$labels['server'] = 'ڕاژەکار';
$labels['login'] = 'چوونەژوورەوە';
$labels['oauthlogin'] = 'چوونەژوورەوە لەگەڵ $provider';
$labels['menu'] = 'پێڕست';
$labels['logout'] = 'دەرچوون';
$labels['mail'] = 'پۆست';
$labels['settings'] = 'ڕێکخستنەکان';
$labels['addressbook'] = 'پەرتووکی ناونیشان';
$labels['darkmode'] = 'شێوازی تاریک';
$labels['lightmode'] = 'شێوازی ڕووناک';
$labels['inbox'] = 'هاتوو';
$labels['drafts'] = 'ڕه‌شنووسەکان';
$labels['sent'] = 'نێردراو';
$labels['trash'] = 'زبڵدان';
$labels['junk'] = 'بێکه‌ڵک';
$labels['show_real_foldernames'] = 'ناوە ڕاستییەکان پیشانبدە بۆ بوخچە تایبەتەکان';
$labels['subject'] = 'ناونیشان';
$labels['from'] = 'لە';
$labels['sender'] = 'نێردەر';
$labels['to'] = 'بۆ';
$labels['cc'] = 'Cc';
$labels['bcc'] = 'Bcc';
$labels['replyto'] = 'وەڵامدانەوە-بۆ';
$labels['followupto'] = 'بەدواداچوون-بۆ';
$labels['date'] = 'بەروار';
$labels['size'] = 'قەبارە';
$labels['priority'] = 'پێشه‌نگی';
$labels['organization'] = 'ڕێکخراو';
$labels['readstatus'] = 'ڕەوشی خوێندنەوە';
$labels['listoptions'] = 'لیستی هەڵبژاردەکان';
$labels['listoptionstitle'] = 'هەڵبژاردەکانی لیستە';
$labels['mailboxlist'] = 'بوخچەکان';
$labels['messagesfromto'] = 'پەیامەکان $from بۆ $to لە $count';
$labels['messagenrof'] = 'پەیام $nr لە $count';
$labels['fromtoshort'] = '$from – $to لە $count';
$labels['copy'] = 'لەبەرگرتنەوە';
$labels['move'] = 'گواستنەوە';
$labels['moveto'] = 'گواستنەوە بۆ';
$labels['copyto'] = 'گواستنەوە بۆ...';
$labels['download'] = 'داگرتن';
$labels['open'] = 'کردنەوە';
$labels['showattachment'] = 'پیشاندان';
$labels['showanyway'] = 'هەرچۆنێک بێت پیشانیبدە';
$labels['filename'] = 'ناوی پەڕگە';
$labels['filesize'] = 'قەبارەی پەڕگە';
$labels['addtoaddressbook'] = 'زیادیبکە بۆ پەرتووکی ناونیشان';
$labels['sun'] = 'یەکشەممە';
$labels['mon'] = 'دووشەممە';
$labels['tue'] = 'سێشەممە';
$labels['wed'] = 'چوارشەممە';
$labels['thu'] = 'پێنجشەممە';
$labels['fri'] = 'هەینی';
$labels['sat'] = 'شەممە';
$labels['sunday'] = 'یەکشەممە';
$labels['monday'] = 'دووشەممە';
$labels['tuesday'] = 'سێشەممە';
$labels['wednesday'] = 'چوارشەممە';
$labels['thursday'] = 'پێنجشەممە';
$labels['friday'] = 'هەینی';
$labels['saturday'] = 'شەممە';
$labels['jan'] = 'کانوونی دووەم';
$labels['feb'] = 'شوبات';
$labels['mar'] = 'ئادار';
$labels['apr'] = 'نیسان';
$labels['may'] = 'ئایار';
$labels['jun'] = 'حوزەیران';
$labels['jul'] = 'تەمووز';
$labels['aug'] = 'ئاب';
$labels['sep'] = 'ئەیلول';
$labels['oct'] = 'تشرینی یەکەم';
$labels['nov'] = 'تشرینی دووەم';
$labels['dec'] = 'کانوونی یەکەم';
$labels['longjan'] = 'کانوونی دووەم';
$labels['longfeb'] = 'شوبات';
$labels['longmar'] = 'ئادار';
$labels['longapr'] = 'نیسان';
$labels['longmay'] = 'ئایار';
$labels['longjun'] = 'حوزەیران';
$labels['longjul'] = 'تەمووز';
$labels['longaug'] = 'ئاب';
$labels['longsep'] = 'ئەیلول';
$labels['longoct'] = 'تشرینی یەکەم';
$labels['longnov'] = 'تشرینی دووەم';
$labels['longdec'] = 'کانوونی یەکەم';
$labels['today'] = 'ئەمڕۆ';
$labels['refresh'] = 'نوێكردنه‌وه';
$labels['checkmail'] = 'تێڕوانین بۆ نامەی نوێ';
$labels['compose'] = 'پێکهێنان';
$labels['writenewmessage'] = 'درووستکردنی پەیامێکی نوێ';
$labels['reply'] = 'وەڵامدانەوە';
$labels['replytomessage'] = 'وەڵامدانەوەی نێردەر';
$labels['replytoallmessage'] = 'وەڵامدانەوەی لیست یاخوود نێردەر و هەموو وەرگرەکان';
$labels['replyall'] = 'وەڵامدانەوەی هەموو';
$labels['replylist'] = 'وەڵامدانەوەی لیست';
$labels['forward'] = 'بینێره‌ بۆ';
$labels['deletemessage'] = 'سڕینەوەی پەیام';
$labels['movemessagetotrash'] = 'پەیام بگوازەرەوە بۆ زبڵدان';
$labels['printmessage'] = 'ئەم پەیامە چاپ بکە';
$labels['folders-all'] = 'هەموو بوخچەکان';
$labels['more'] = 'زیاتر';
$labels['back'] = 'گەڕانەوە';
$labels['options'] = 'هەڵبژاردەکان';
$labels['composeoptions'] = 'هەڵبژاردەکانی پێکهێنان';
$labels['optionsandattachments'] = 'هەڵبژاردەکان و پاشکۆکان';
$labels['actions'] = 'کردارەکان';
$labels['first'] = 'یەکەم';
$labels['last'] = 'کۆتایی';
$labels['previous'] = 'پێشتر';
$labels['next'] = 'دواتر';
$labels['select'] = 'هەڵبژاردن';
$labels['all'] = 'هەمووی';
$labels['none'] = 'هیچ';
$labels['currpage'] = 'پەڕی ئێستا';
$labels['list'] = 'لیست';
$labels['fromto'] = 'لە/بۆ';
$labels['attachment'] = 'هاوپێچ';
$labels['nonesort'] = 'هیچ';
$labels['sentdate'] = 'بەرواری ناردن';
$labels['arrival'] = 'بەرواری گەیشتن';
$labels['layoutlist'] = 'لیست';
$labels['empty'] = 'بەتاڵ';
$labels['unknown'] = 'نەناسراو';
$labels['unlimited'] = 'بێ سنوور';
$labels['quotatotal'] = 'سنوور';
$labels['quotaused'] = 'بەکارهاتوو';
$labels['namex'] = 'ناو';
$labels['allfolders'] = 'هەموو بوخچەکان';
$labels['send'] = 'ناردن';
$labels['responsename'] = 'ناو';
$labels['attach'] = 'هاوپێچ';
$labels['attachments'] = 'هاوپێچەکان';
$labels['upload'] = 'بارکردن';
$labels['close'] = 'داخستن';
$labels['nickname'] = 'نازناو';
$labels['jobtitle'] = 'ناونیشانی کار';
$labels['department'] = 'بەش';
$labels['gender'] = 'ڕەگەز';
$labels['phone'] = 'تەلەفۆن';
$labels['address'] = 'ناونیشان';
$labels['street'] = 'شەقام';
$labels['locality'] = 'شار';
$labels['country'] = 'وڵات';
$labels['birthday'] = 'ڕۆژی لەدایکبوون';
$labels['website'] = 'ماڵپەڕ';
$labels['notes'] = 'تێبینییەکان';
$labels['male'] = 'نێر';
$labels['female'] = 'مێ';
$labels['manager'] = 'بەڕێوەبەر';
$labels['allfields'] = 'هەموو خانەکان';
$labels['search'] = 'گەڕان';
$labels['searchresult'] = 'ئەنجامی گەڕان';
$labels['advsearch'] = 'گەڕانی پێشکەوتوو';
$labels['advanced'] = 'پێشکەوتوو';
$labels['typehome'] = 'ماڵ';
$labels['typework'] = 'کار';
$labels['typemobile'] = 'مۆبایل';
$labels['typemain'] = 'سەرەکی';
$labels['delete'] = 'سڕینەوە';
$labels['about'] = 'دەربارە';
$labels['folders'] = 'بوخچەکان';
$labels['create'] = 'دروستکردن';
$labels['license'] = 'مۆڵەت';
